@@ -16,7 +16,7 @@
 
 /** Qt */
 #include <qregexp.h>
- 
+
  /** KDE Libs */
 #include <kaction.h>
 #include <kdebug.h>
@@ -27,11 +27,13 @@
 /** KDevelop */
 #include "autodetailsview.h"
 
+#include "kdevappfrontend.h"
 #include "kdevcore.h"
 #include "kdevmainwindow.h"
 #include "kdevpartcontroller.h"
 #include "kdevcreatefile.h"
 #include "kdevlanguagesupport.h"
+#include "kdevmakefrontend.h"
 
 #include "domutil.h"
 
@@ -59,6 +61,7 @@ AutoDetailsView::AutoDetailsView(AutoProjectWidget* widget, AutoProjectPart* par
 	QDomDocument &dom = *(m_part->projectDom());
 	m_subclasslist = DomUtil::readPairListEntry(dom,"/kdevautoproject/subclassing" ,
                                                     "subclass","sourcefile", "uifile");
+						    
 }
 
 
@@ -87,6 +90,9 @@ void AutoDetailsView::initActions()
 	                                 this, SLOT( slotBuildTarget() ), actions, "build target" );
     buildTargetAction->setWhatsThis(i18n("<b>Build target</b><p>Constructs a series of make commands to build the selected target. "
                                          "Also builds dependent targets."));
+	executeTargetAction = new KAction( i18n( "Execute Target..." ), "exec", 0,
+	                                 this, SLOT( slotExecuteTarget() ), actions, "execute target" );
+    executeTargetAction->setWhatsThis(i18n("<b>Execute target</b><p>Executes the target and tries to build in case it isn't."));					 
 	setActiveTargetAction = new KAction( i18n( "Make Target Active" ), "", 0,
 	                                     this, SLOT( slotSetActiveTarget() ), actions, "set active target" );
     setActiveTargetAction->setWhatsThis(i18n("<b>Make target active</b><p>Marks the currently selected target as 'active'. New files and classes by default go to an active target. "
@@ -106,13 +112,13 @@ void AutoDetailsView::initActions()
 QString AutoDetailsView::getUiFileLink(const QString &relpath, const QString& filename)
 {
 	DomUtil::PairList::iterator it;
-	
+
 	for (it=m_subclasslist.begin();it != m_subclasslist.end(); ++it)
 	{
 		if ((*it).first==QString("/")+relpath+filename)
 			return (*it).second;
 	}
-	
+
 	return QString ("");
 }
 
@@ -137,7 +143,7 @@ void AutoDetailsView::slotAddNewFile()
 		return ;
 
 	KDevCreateFile * createFileSupport = m_part->createFileSupport();
-	if (createFileSupport) 
+	if (createFileSupport)
 	{
 		KDevCreateFile::CreatedFile crFile =
 			createFileSupport->createNewFile(QString::null, m_widget->selectedSubproject()->path);
@@ -156,7 +162,7 @@ void AutoDetailsView::slotAddNewFile()
 			caption = i18n ( "%1 in %2" ).arg ( titem->primary ).arg ( titem->prefix );
 		else
 			caption = titem->name;
-		
+
 		dlg.setCaption ( i18n ( "Add New File to '%1'" ).arg ( caption ) );
 
 		if ( dlg.exec() )
@@ -211,10 +217,25 @@ void AutoDetailsView::slotBuildTarget()
 
 	QString relpath = m_widget->selectedSubproject()->path.mid( m_part->projectDirectory().length() );
 	m_part->buildTarget(relpath, titem);
-
-	m_part->mainWindow()->lowerView( m_widget );
 }
 
+void AutoDetailsView::slotExecuteTarget()
+{
+	ProjectItem * pvitem = static_cast<ProjectItem*>( selectedItem() );
+
+	if ( !pvitem )
+		return;
+
+	TargetItem* titem = 0;
+
+	if ( pvitem->type() == ProjectItem::File )
+		titem = static_cast <TargetItem*> ( pvitem->parent() );
+	else
+		titem = static_cast <TargetItem*> ( selectedItem() );
+		
+	
+	m_part->executeTarget(m_widget->selectedSubproject()->path, titem);
+}
 
 void AutoDetailsView::slotRemoveDetail()
 {
@@ -223,6 +244,12 @@ void AutoDetailsView::slotRemoveDetail()
 	if ( pvitem && ( pvitem->type() == ProjectItem::File ) )
 	{
 		FileItem * fitem = static_cast <FileItem*> ( selectedItem() );
+		if(fitem && fitem->is_subst)
+		{
+			fitem->changeMakefileEntry("");
+			return;
+		}
+
 		QListViewItem* sibling = fitem->nextSibling();
 
 		if ( !fitem )
@@ -244,7 +271,7 @@ void AutoDetailsView::slotRemoveDetail()
 		if ( dlg.exec() )
 		{
 			emit selectionChanged( titem );
-			
+
 			if ( sibling)
 			{
 				setSelected ( sibling, true );
@@ -271,7 +298,7 @@ void AutoDetailsView::slotRemoveDetail()
 			//details->takeItem ( titem );
 
 			m_widget->slotOverviewSelectionChanged ( m_widget->selectedSubproject() );
-			
+
 			if ( sibling)
 			{
 				setSelected ( sibling, true );
@@ -311,6 +338,8 @@ void AutoDetailsView::slotDetailsContextMenu( KListView *, QListViewItem *item,
 			setActiveTargetAction->plug( &popup );
 			popup.insertSeparator();
 			buildTargetAction->plug( &popup );
+			if( titem->primary == "PROGRAMS")
+				executeTargetAction->plug( &popup );
 		}
 		else if ( titem->primary == "KDEDOCS" )
 		{
@@ -348,20 +377,20 @@ void AutoDetailsView::slotDetailsContextMenu( KListView *, QListViewItem *item,
 		removeDetailAction->plug( &popup );
 		FileContext context( m_widget->selectedSubproject()->path + "/" + fitem->name, false );
 
-		int idSubclassWidget = popup.insertItem(SmallIconSet("qmake_subclass.png"),i18n("Subclass Widget...") );
+		int idSubclassWidget = popup.insertItem(SmallIconSet("qmake_subclass"),i18n("Subclassing Wizard...") );
         popup.setWhatsThis(idSubclassWidget, i18n("<b>Subclass widget</b><p>Launches <b>Subclassing</b> wizard. "
                            "It allows to create a subclass from the class defined in .ui file. "
                            "There is also possibility to implement slots and functions defined in the base class."));
-        int idUISubclasses = popup.insertItem(SmallIconSet("qmake_subclass.png"),i18n("List of Subclasses..."));
+        int idUISubclasses = popup.insertItem(SmallIconSet("qmake_subclass"),i18n("List of Subclasses..."));
         popup.setWhatsThis(idUISubclasses, i18n("<b>List of subclasses</b><p>Shows subclasses list editor. "
                            "There is possibility to add or remove subclasses from the list."));
-		int idUpdateWidgetclass = popup.insertItem(SmallIconSet("qmake_subclass.png"),i18n("Edit ui-Subclass..."));
+		int idUpdateWidgetclass = popup.insertItem(SmallIconSet("qmake_subclass"),i18n("Edit ui-Subclass..."));
         popup.setWhatsThis(idUpdateWidgetclass, i18n("<b>Edit ui-subclass</b><p>Launches <b>Subclassing</b> wizard "
                            "and prompts to implement missing in childclass slots and functions."));
-		int idViewUIH = popup.insertItem(SmallIconSet("qmake_ui_h.png"),i18n("Open ui.h File"));
-        popup.setWhatsThis(idViewUIH, i18n("<b>Open ui.h file</b><p>Opens .ui.h file assotiated with the selected .ui."));
+		int idViewUIH = popup.insertItem(SmallIconSet("qmake_ui_h"),i18n("Open ui.h File"));
+        popup.setWhatsThis(idViewUIH, i18n("<b>Open ui.h file</b><p>Opens .ui.h file associated with the selected .ui."));
 
-		if (!fitem->name.contains(QRegExp("ui$")))
+		if (!fitem->name.contains(QRegExp("ui$")) || fitem->is_subst == true)
 		{
             popup.removeItem(idUISubclasses);
 			popup.removeItem(idViewUIH);
@@ -372,6 +401,7 @@ void AutoDetailsView::slotDetailsContextMenu( KListView *, QListViewItem *item,
 			popup.removeItem(idUpdateWidgetclass);
 		}
 
+		if(fitem->is_subst == false)
 		m_part->core()->fillContextMenu( &popup, &context );
 
 		int r = popup.exec( p );
@@ -408,19 +438,19 @@ void AutoDetailsView::slotDetailsContextMenu( KListView *, QListViewItem *item,
 		else if (r == idUpdateWidgetclass)
 		{
 			QString noext = m_widget->selectedSubproject()->path + "/" + fitem->name;
-			
+
 			if (noext.findRev('.')>-1)
 				noext = noext.left(noext.findRev('.'));
-			
+
 			QStringList dummy;
 			QString uifile = fitem->uiFileLink;
-			
+
 			if (uifile.findRev('/')>-1)
 			{
 				QStringList uisplit = QStringList::split('/',uifile);
 				uifile=uisplit[uisplit.count()-1];
 			}
-			
+
 			m_part->languageSupport()->updateWidget(m_widget->selectedSubproject()->path + "/" + uifile, noext);
 		}
         else if (r == idUISubclasses)
@@ -430,16 +460,16 @@ void AutoDetailsView::slotDetailsContextMenu( KListView *, QListViewItem *item,
                                                     "subclass","sourcefile", "uifile");
             SubclassesDlg *sbdlg = new SubclassesDlg( QString(m_widget->selectedSubproject()->path + "/" + fitem->name).remove(0,m_part->projectDirectory().length()),
                 list, m_part->projectDirectory());
-                
+
             if (sbdlg->exec())
             {
                 QDomElement el = DomUtil::elementByPath( dom,  "/kdevautoproject");
                 QDomElement el2 = DomUtil::elementByPath( dom,  "/kdevautoproject/subclassing");
-                if ( (!el.isNull()) && (!el2.isNull()) ) 
+                if ( (!el.isNull()) && (!el2.isNull()) )
                 {
                     el.removeChild(el2);
                 }
-                
+
                 DomUtil::writePairListEntry(dom, "/kdevautoproject/subclassing", "subclass", "sourcefile", "uifile", list);
 
                 m_subclasslist = DomUtil::readPairListEntry(dom,"/kdevautoproject/subclassing" ,
@@ -461,12 +491,16 @@ void AutoDetailsView::slotDetailsExecuted( QListViewItem *item )
 
 	if ( !m_widget->selectedSubproject() )
 		return;
-		
+
 	QString dirName = m_widget->selectedSubproject()->path;
 	FileItem *fitem = static_cast<FileItem*>( item );
+	if(fitem->is_subst)
+	{
+		fitem->changeSubstitution();
+		return;
+	}
 	
-	m_part->partController() ->editDocument( KURL( dirName + "/" + fitem->name ) );
-	m_part->mainWindow()->lowerView( m_widget );
+	m_part->partController()->editDocument( KURL( dirName + "/" + fitem->name ) );
 }
 
 void AutoDetailsView::slotSetActiveTarget()
@@ -482,4 +516,9 @@ void AutoDetailsView::slotSetActiveTarget()
 	DomUtil::writeEntry( dom, "/kdevautoproject/general/activetarget", targetPath );
 }
 
+void AutoDetailsView::focusOutEvent(QFocusEvent */*e*/)
+{
+    m_widget->setLastFocusedView(AutoProjectWidget::DetailsView);
+}
+
 #include "autodetailsview.moc"
