@@ -61,7 +61,7 @@ static const KAboutData data("kdevautoproject", I18N_NOOP("Automake Manager"), "
 K_EXPORT_COMPONENT_FACTORY( libkdevautoproject, AutoProjectFactory( &data ) )
 
 AutoProjectPart::AutoProjectPart(QObject *parent, const char *name, const QStringList &args)
-    : KDevProject("AutoProject", "autoproject", parent, name ? name : "AutoProjectPart")
+    : KDevProject("AutoProject", "make", parent, name ? name : "AutoProjectPart")
     , m_lastCompilationFailed(false)
 {
     setInstance(AutoProjectFactory::instance());
@@ -73,7 +73,7 @@ AutoProjectPart::AutoProjectPart(QObject *parent, const char *name, const QStrin
     m_needMakefileCvs = false;
 
     m_widget = new AutoProjectWidget(this, m_isKDE);
-    m_widget->setIcon(SmallIcon("make"));
+	m_widget->setIcon(SmallIcon( icon() ));
     m_widget->setCaption(i18n("Automake Manager"));
     QWhatsThis::add(m_widget, i18n("<b>Automake manager</b><p>"
                                    "The project tree consists of two parts. The 'overview' "
@@ -222,9 +222,9 @@ AutoProjectPart::AutoProjectPart(QObject *parent, const char *name, const QStrin
 //    connect( core(), SIGNAL(projectConfigWidget(KDialogBase*)), this, SLOT(projectConfigWidget(KDialogBase*)) );
 
 	_configProxy = new ConfigWidgetProxy( core() );
-	_configProxy->createProjectConfigPage( i18n("Configure Options"), CONFIGURE_OPTIONS );
-	_configProxy->createProjectConfigPage( i18n("Run Options"), RUN_OPTIONS );
-	_configProxy->createProjectConfigPage( i18n("Make Options"), MAKE_OPTIONS );
+	_configProxy->createProjectConfigPage( i18n("Configure Options"), CONFIGURE_OPTIONS, icon() );
+	_configProxy->createProjectConfigPage( i18n("Run Options"), RUN_OPTIONS, icon() );
+	_configProxy->createProjectConfigPage( i18n("Make Options"), MAKE_OPTIONS, icon() );
 	connect( _configProxy, SIGNAL(insertConfigWidget(const KDialogBase*, QWidget*, unsigned int )), this, SLOT(insertConfigWidget(const KDialogBase*, QWidget*, unsigned int )) );
 
 
@@ -280,7 +280,7 @@ void AutoProjectPart::insertConfigWidget( const KDialogBase* dlg, QWidget * page
 			connect( dlg, SIGNAL(okClicked()), w2, SLOT(accept()) );
 		}
 		break;
-		
+
 		case RUN_OPTIONS:
 		{
 			QDomDocument &dom = *projectDom();
@@ -292,7 +292,7 @@ void AutoProjectPart::insertConfigWidget( const KDialogBase* dlg, QWidget * page
 			}
 		}
 		break;
-		
+
 		case MAKE_OPTIONS:
 		{
 			MakeOptionsWidget *w4 = new MakeOptionsWidget(*projectDom(), "/kdevautoproject", page );
@@ -319,7 +319,7 @@ void AutoProjectPart::openProject(const QString &dirName, const QString &project
     if (!DomUtil::readBoolEntry(dom, "/kdevautoproject/run/disable_default") && DomUtil::readEntry(dom, "/kdevautoproject/run/directoryradio") == "" ) {
         DomUtil::writeEntry(dom, "/kdevautoproject/run/directoryradio", "executable");
     }
-    
+
     KDevProject::openProject( dirName, projectName );
 }
 
@@ -552,7 +552,7 @@ void AutoProjectPart::addFiles ( const QStringList& fileList )
 		{
 			if ( !messageBoxShown )
 			{
-				KMessageBox::information(m_widget, i18n("The directory you selected is not the active directory!\n"
+				KMessageBox::information(m_widget, i18n("The directory you selected is not the active directory.\n"
 														"You should 'activate' the target you're currently working on in Automake Manager.\n"
 														"Just right-click a target and choose 'Make Target Active'."),
 														i18n ( "No Active Target Found" ), "No automake manager active target warning" );
@@ -667,6 +667,13 @@ QString AutoProjectPart::constructMakeCommandLine(const QString &dir, const QStr
     QDomDocument &dom = *projectDom();
 
     QString cmdline = DomUtil::readEntry(dom, "/kdevautoproject/make/makebin");
+    int prio = DomUtil::readIntEntry(dom, "/kdevautoproject/make/prio");
+    QString nice;
+    kdDebug(9020) << "constructMakeCommandLine() nice = " << prio<< endl;
+    if (prio != 0) {
+        nice = QString("nice -n%1 ").arg(prio);
+    }
+
     if (cmdline.isEmpty())
         cmdline = MAKE_COMMAND;
     if (!DomUtil::readBoolEntry(dom, "/kdevautoproject/make/abortonerror"))
@@ -681,11 +688,12 @@ QString AutoProjectPart::constructMakeCommandLine(const QString &dir, const QStr
 
     cmdline += " ";
     cmdline += target;
+    cmdline.prepend(nice);
     cmdline.prepend(makeEnvironment());
 
-    QString dircmd = "cd \"";
-    dircmd += dir;
-    dircmd += "\" && ";
+    QString dircmd = "cd ";
+    dircmd += KProcess::quote(dir);
+    dircmd += " && ";
 
     return preCommand + dircmd + cmdline;
 }
@@ -830,9 +838,6 @@ void AutoProjectPart::slotBuildActiveTarget()
 
   // build it
   buildTarget(activeDirectory(), titem);
-
-  // hide the autoproject toolbar (if not sticky)
-  mainWindow()->lowerView( m_widget );
 }
 
 
@@ -901,20 +906,33 @@ QString AutoProjectPart::configureCommand() const
         cmdline += configargs;
     }
 
+   DomUtil::PairList envvars =
+        DomUtil::readPairListEntry(*projectDom(), prefix + "envvars", "envvar", "name", "value");
+
+    QString environstr;
+    DomUtil::PairList::ConstIterator it;
+    for (it = envvars.begin(); it != envvars.end(); ++it) {
+        environstr += (*it).first;
+        environstr += "=";
+        environstr += EnvVarTools::quote((*it).second);
+        environstr += " ";
+    }
+    cmdline.prepend(environstr);
+
     QString builddir = buildDirectory();
     QString dircmd;
 
     // if the build directory doesn't exist, add it's creation to the configureCommand
     if ( !QFile::exists(builddir)) {
-        dircmd = "mkdir \"";
-        dircmd += builddir;
-        dircmd += "\" && ";
+        dircmd = "mkdir ";
+        dircmd += KProcess::quote(builddir);
+        dircmd += " && ";
     }
 
     // add "cd into the build directory" to the configureCommand
-    dircmd += "cd \"";
-    dircmd += builddir;
-    dircmd += "\" && ";
+    dircmd += "cd ";
+    dircmd += KProcess::quote(builddir);
+    dircmd += " && ";
 
     return dircmd + cmdline;
 }
@@ -934,6 +952,13 @@ QString AutoProjectPart::makefileCvsCommand() const
     if (cmdline.isEmpty())
         cmdline = MAKE_COMMAND;
 
+    int prio = DomUtil::readIntEntry(*projectDom(), "/kdevautoproject/make/prio");
+    QString nice;
+    kdDebug(9020) << "makefileCvsCommand() nice = " << prio<< endl;
+    if (prio != 0) {
+        nice = QString("nice -n%1 ").arg(prio);
+    }
+
     if (QFile::exists(topsourceDirectory() + "/Makefile.cvs"))
         cmdline += " -f Makefile.cvs";
     else if (QFile::exists(topsourceDirectory() + "/Makefile.dist"))
@@ -946,11 +971,12 @@ QString AutoProjectPart::makefileCvsCommand() const
         return QString::null;
     }
 
+    cmdline.prepend(nice);
     cmdline.prepend(makeEnvironment());
 
-    QString dircmd = "cd \"";
-    dircmd += topsourceDirectory();
-    dircmd += "\" && ";
+    QString dircmd = "cd ";
+    dircmd += KProcess::quote(topsourceDirectory());
+    dircmd += " && ";
 
     return dircmd + cmdline;
 }
@@ -1033,6 +1059,89 @@ void AutoProjectPart::slotExecute()
     slotExecute2();
 }
 
+void AutoProjectPart::executeTarget(const QDir& dir, const TargetItem* titem)
+{
+	partController()->saveAllFiles();
+	
+	bool is_dirty = false;
+	QDateTime t = QFileInfo(dir , titem->name ).lastModified();	
+	QPtrListIterator<FileItem> it( titem->sources );
+	for( ; it.current() ; ++it )
+	{
+		if( t < QFileInfo(dir , (*it)->name).lastModified())
+			is_dirty = true;
+	}
+	
+	
+	if( DomUtil::readBoolEntry(*projectDom(), "/kdevautoproject/run/autocompile", true) && is_dirty )
+	{	
+		connect( makeFrontend(), SIGNAL(commandFinished(const QString&)), this, SLOT(slotExecuteTargetAfterBuild(const QString&)) );
+		connect( makeFrontend(), SIGNAL(commandFailed(const QString&)), this, SLOT(slotNotExecuteTargetAfterBuildFailed(const QString&)) );		
+		m_executeTargetAfterBuild.first = dir;
+		m_executeTargetAfterBuild.second = const_cast<TargetItem*>(titem);
+		
+		QString relpath = dir.path().mid( projectDirectory().length() );
+		buildTarget(relpath, const_cast<TargetItem*>(titem));
+		return;	
+	}
+	
+	
+	bool inTerminal = DomUtil::readBoolEntry(*projectDom(), "/kdevautoproject/run/terminal");
+	
+	QString program = environString();
+	if(titem->name.startsWith("/"))
+	  program += "./";
+	program += titem->name;	
+	
+	QString args = DomUtil::readEntry(*projectDom(), "/kdevautoproject/run/runarguments/" + titem->name);
+	
+	program += " " + args;
+	
+	appFrontend()->startAppCommand(dir.path(), program ,inTerminal);
+
+}
+
+void AutoProjectPart::slotExecuteTargetAfterBuild(const QString& command)
+{
+
+if ( constructMakeCommandLine(m_executeTargetAfterBuild.first.path(), m_executeTargetAfterBuild.second->name) == command )
+{
+	disconnect( makeFrontend(), SIGNAL(commandFinished(const QString&)), this, SLOT(slotExecuteAfterTargetBuild()) );
+	disconnect( makeFrontend(), SIGNAL(commandFailed(const QString&)), this, SLOT(slotExecuteAfterTargetBuildFailed()) );
+	executeTarget(m_executeTargetAfterBuild.first, m_executeTargetAfterBuild.second);
+}
+
+}
+
+void AutoProjectPart::slotNotExecuteTargetAfterBuildFailed(const QString& command)
+{
+
+if ( constructMakeCommandLine(m_executeTargetAfterBuild.first.path(), m_executeTargetAfterBuild.second->name) == command )
+{
+	disconnect( makeFrontend(), SIGNAL(commandFinished(const QString&)), this, SLOT(slotExecuteTargetAfterBuild()) );
+	disconnect( makeFrontend(), SIGNAL(commandFailed(const QString&)), this, SLOT(slotNotExecuteTargetAfterBuildFailed()) );	
+}
+
+}
+
+
+/* Get the run environment variables pairs into the environstr string
+ * in the form of: "ENV_VARIABLE=ENV_VALUE"
+ * Note that we quote the variable value due to the possibility of
+ * embedded spaces. */
+QString AutoProjectPart::environString() const
+{
+    DomUtil::PairList envvars = runEnvironmentVars();
+    QString environstr;
+    DomUtil::PairList::ConstIterator it;
+    for (it = envvars.begin(); it != envvars.end(); ++it) {
+        environstr += (*it).first;
+        environstr += "=";
+        environstr += EnvVarTools::quote((*it).second);
+        environstr += " ";
+    }
+ return environstr;
+}
 
 /** Executes the currently selected main program.
   * If no main Program was selected in the Run Options dialog
@@ -1042,32 +1151,11 @@ void AutoProjectPart::slotExecute2()
 {
     disconnect(appFrontend(), SIGNAL(processExited()), this, SLOT(slotExecute2()));
 
-    // Get the run environment variables pairs into the environstr string
-    // in the form of: "ENV_VARIABLE=ENV_VALUE"
-    // Note that we quote the variable value due to the possibility of
-    // embedded spaces
-    DomUtil::PairList envvars = runEnvironmentVars();
-    QString environstr;
-    DomUtil::PairList::ConstIterator it;
-    for (it = envvars.begin(); it != envvars.end(); ++it) {
-        environstr += (*it).first;
-        environstr += "=";
-/*
-#if (KDE_VERSION > 305)
-        environstr += KProcess::quote((*it).second);
-#else
-        environstr += KShellProcess::quote((*it).second);
-#endif
-*/
-        environstr += EnvVarTools::quote((*it).second);
-        environstr += " ";
-    }
-
     if (mainProgram(true).isEmpty())
     // Do not execute non executable targets
         return;
 
-    QString program = environstr;
+    QString program = environString();
     // Adds the ./ that is necessary to execute the program in bash shells
     if (!mainProgram(true).startsWith("/"))
         program += "./";
@@ -1077,7 +1165,7 @@ void AutoProjectPart::slotExecute2()
     bool inTerminal = DomUtil::readBoolEntry(*projectDom(), "/kdevautoproject/run/terminal");
 
     kdDebug(9020) << "runDirectory: <" << runDirectory() << ">" <<endl;
-    kdDebug(9020) << "environstr  : <" << environstr << ">" <<endl;
+    kdDebug(9020) << "environstr  : <" << environString() << ">" <<endl;
     kdDebug(9020) << "mainProgram : <" << mainProgram(true) << ">" <<endl;
     kdDebug(9020) << "runArguments: <" << runArguments() << ">" <<endl;
 
@@ -1202,4 +1290,59 @@ KDevProject::Options AutoProjectPart::options() const
     return UsesAutotoolsBuildSystem;
 }
 
+QStringList recursiveATFind( const QString &currDir, const QString &baseDir )
+{
+	kdDebug() << "Dir " << currDir << endl;
+	QStringList fileList;
+
+	if( !currDir.contains( "/..") && !currDir.contains("/.") )
+	{
+		QDir dir(currDir);
+		QStringList dirList = dir.entryList(QDir::Dirs );
+		QStringList::Iterator idx = dirList.begin();
+		for( ; idx != dirList.end(); ++idx )
+		{
+			fileList += recursiveATFind( currDir + "/" + (*idx),baseDir );
+		}
+		QStringList newFiles = dir.entryList("*.am *.in");
+		idx = newFiles.begin();
+		for( ; idx != newFiles.end(); ++idx )
+		{
+			QString file = currDir + "/" + (*idx);
+			fileList.append( file.remove( baseDir ) );
+		}
+	}
+
+
+	return fileList;
+}
+
+/*!
+    \fn AutoProjectPart::distFiles() const
+ */
+QStringList AutoProjectPart::distFiles() const
+{
+	QStringList sourceList = allFiles();
+	// Scan current source directory for any .pro files.
+	QString projectDir = projectDirectory();
+	QDir dir(projectDir);
+	QDir admin(projectDir +"/admin");
+	QStringList files = dir.entryList( "Makefile.cvs Makefile.am configure* INSTALL README NEWS TODO ChangeLog COPYING AUTHORS stamp-h.in");
+	QStringList adminFiles = admin.entryList(QDir::Files);
+	QStringList::Iterator idx = adminFiles.begin();
+	for( ; idx != adminFiles.end(); ++idx)
+	{
+		files.append( "admin/" + (*idx) );
+	}
+	QStringList srcDirs = dir.entryList(QDir::Dirs);
+	idx = srcDirs.begin();
+	for(; idx != srcDirs.end(); ++idx)
+	{
+		sourceList += recursiveATFind( projectDirectory() + "/" + (*idx), projectDirectory());
+	}
+	return sourceList + files;
+}
 #include "autoprojectpart.moc"
+
+
+
