@@ -189,6 +189,12 @@ void AutoProjectWidget::initDetailview ( QWidget* parent )
 		( buildTargetButton, i18n( "Build" ) );
     QWhatsThis::add(buildTargetButton, i18n("<b>Build target</b><p>Constructs a series of make commands to build the selected target. "
                                             "Also builds dependent targets."));
+					    
+	executeTargetButton = new QToolButton( targetButtonBox );
+	executeTargetButton->setPixmap( SmallIcon( "exec") );
+	QToolTip::add
+		( executeTargetButton, i18n( "Execute" ) );
+    QWhatsThis::add(executeTargetButton, i18n("<b>Execute target</b><p> Executes target, if it's a program. Tries to build it, if that's not yet done."));					    
 
 	QWidget *spacer2 = new QWidget( targetButtonBox );
 	targetButtonBox->setStretchFactor( spacer2, 1 );
@@ -206,6 +212,7 @@ void AutoProjectWidget::initDetailview ( QWidget* parent )
 	addExistingFileButton->setEnabled( false );
 	removeButton->setEnabled( true );
 	buildTargetButton->setEnabled( true );
+	executeTargetButton->setEnabled( true );	
 
 	m_detailView = new AutoDetailsView( this, m_part, targetBox, "project details widget" );
 	m_detailView->setRootIsDecorated( true );
@@ -230,6 +237,7 @@ void AutoProjectWidget::initActions()
 	connect( addExistingFileButton, SIGNAL( clicked() ), m_detailView, SLOT( slotAddExistingFile() ) );
 	connect( removeButton , SIGNAL( clicked() ), m_detailView, SLOT( slotRemoveDetail() ) );
 	connect( buildTargetButton, SIGNAL( clicked() ), m_detailView, SLOT( slotBuildTarget() ) );
+	connect( executeTargetButton, SIGNAL( clicked() ), m_detailView, SLOT( slotExecuteTarget() ) );	
 
 	connect( m_subprojectView, SIGNAL( selectionChanged( QListViewItem* ) ),
 	         this, SLOT( slotOverviewSelectionChanged( QListViewItem* ) ) );
@@ -256,6 +264,7 @@ void AutoProjectWidget::openProject( const QString &dirName )
 
 void AutoProjectWidget::closeProject()
 {
+	m_shownSubproject = 0;
 	m_subprojectView->clear();
 	m_detailView->clear();
 }
@@ -396,6 +405,9 @@ QStringList AutoProjectWidget::allFiles()
 			QPtrListIterator<FileItem> fit( tit.current() ->sources );
 			for ( ; fit.current(); ++fit ){
 
+				if((*fit)->is_subst)
+					continue;
+				
 				QFileInfo fileInfo( (*fit)->name );
 				if( fileInfo.extension() == "ui" ){
 				    dict.insert( relPath + fileInfo.baseName() + ".h", true );
@@ -672,6 +684,7 @@ void AutoProjectWidget::slotOverviewSelectionChanged( QListViewItem *item )
 	addExistingFileButton->setEnabled ( false );
 	removeButton->setEnabled ( false );
 	buildTargetButton->setEnabled ( false );
+	executeTargetButton->setEnabled ( false );	
 }
 
 
@@ -680,6 +693,7 @@ void AutoProjectWidget::slotDetailsSelectionChanged( QListViewItem *item )
 	bool isTarget = false;
 	bool isRegularTarget = false;
 	bool isFile = false;
+	bool isProgram = false;
 
 	if ( item )
 	{
@@ -711,6 +725,8 @@ void AutoProjectWidget::slotDetailsSelectionChanged( QListViewItem *item )
 		        || primary == "LTLIBRARIES" || primary == "JAVA" )
 			isRegularTarget = true; // not a data group
 
+		if ( primary == "PROGRAMS" )
+			isProgram = true;
 		/*		if ( isRegularTarget && pvitem->type() == ProjectItem::File )
 				{
 					isRegularFile = true;
@@ -723,9 +739,18 @@ void AutoProjectWidget::slotDetailsSelectionChanged( QListViewItem *item )
 	removeButton->setEnabled ( true );
 
 	if ( isRegularTarget && isFile || isRegularTarget )
+	{
 		buildTargetButton->setEnabled ( true );
+		if( isProgram )
+			executeTargetButton->setEnabled ( true );
+	}
 	else
+	{
 		buildTargetButton->setEnabled ( false );
+		executeTargetButton->setEnabled ( false );		
+	}
+			
+	
 }
 
 TargetItem *AutoProjectWidget::selectedTarget()
@@ -791,7 +816,13 @@ TargetItem *AutoProjectWidget::createTargetItem( const QString &name,
 
 FileItem *AutoProjectWidget::createFileItem( const QString &name, SubprojectItem *subproject )
 {
-	FileItem * fitem = new FileItem( m_subprojectView, name );
+        bool is_subst;
+	if(name.find("$(") == 0 || name.find("${") == 0)
+	is_subst = true;
+	else
+	is_subst = false;
+	
+	FileItem * fitem = new FileItem( m_subprojectView, name, is_subst );
 	fitem->uiFileLink = m_detailView->getUiFileLink(subproject->relativePath()+"/", name );
 	m_subprojectView->takeItem( fitem );
 	fitem->name = name;
@@ -854,5 +885,22 @@ void AutoProjectWidget::setActiveSubproject( SubprojectItem * spitem )
     m_activeSubproject = spitem;
 }
 
+void AutoProjectWidget::focusInEvent( QFocusEvent */*e*/ )
+{
+    switch (m_lastFocusedView)
+    {
+        case DetailsView:
+            m_detailView->setFocus();
+            break;
+        case SubprojectView:
+        default:
+            m_subprojectView->setFocus();
+    }
+}
+
+void AutoProjectWidget::setLastFocusedView( AutoProjectView view )
+{
+    m_lastFocusedView = view;
+}
 
 #include "autoprojectwidget.moc"
