@@ -48,6 +48,7 @@
 #include "custommakeconfigwidget.h"
 #include "config.h"
 #include "envvartools.h"
+#include "urlutil.h"
 
 
 typedef KDevGenericFactory<CustomProjectPart> CustomProjectFactory;
@@ -106,7 +107,7 @@ CustomProjectPart::CustomProjectPart(QObject *parent, const char *name, const QS
 
     m_makeEnvironmentsSelector = new KSelectAction( i18n("Make &Environment"),0,
                             actionCollection(), "build_make_environment" );
-    m_makeEnvironmentsSelector->setToolTip(i18n("Make Environment"));
+    m_makeEnvironmentsSelector->setToolTip(i18n("Make environment"));
     m_makeEnvironmentsSelector->setWhatsThis(i18n("<b>Make Environment</b><p> Choose the set of environment variables to be passed on to make.<br>"
                             "Environment variables can be specified in the project "
                             "settings dialog, <b>Build Options</b> tab."));
@@ -173,40 +174,81 @@ void CustomProjectPart::contextMenu(QPopupMenu *popup, const Context *context)
         "like the <i>New Class</i> wizard."));
         return;
     }
+    m_contextAddFiles.clear();
+    m_contextRemoveFiles.clear();
 
-    m_contextFileName = fcontext->fileName();
-    bool inProject = project()->allFiles().contains(m_contextFileName.mid ( project()->projectDirectory().length() + 1 ));
-    QString popupstr = QFileInfo(m_contextFileName).fileName();
-    if (m_contextFileName.startsWith(projectDirectory()+ "/"))
-        m_contextFileName.remove(0, projectDirectory().length()+1);
-
-    popup->insertSeparator();
-    if (inProject)
+    if( fcontext->urls().size() == 1 )
     {
-        int id = popup->insertItem( i18n("Remove %1 From Project").arg(popupstr),
-                           this, SLOT(slotRemoveFromProject()) );
-        popup->setWhatsThis(id, i18n("<b>Remove from project</b><p>Removes current file from the list of files in project. "
-            "Note that the file should be manually excluded from corresponding makefile or build.xml."));
+        QString contextFileName = URLUtil::canonicalPath(fcontext->fileName());
+        bool inProject = project()->isProjectFile(contextFileName);
+        QString popupstr = QFileInfo(contextFileName).fileName();
+        if (contextFileName.startsWith(projectDirectory()+ "/"))
+            contextFileName.remove(0, projectDirectory().length()+1);
+
+        popup->insertSeparator();
+        if (inProject)
+        {
+	    m_contextRemoveFiles << contextFileName;
+            int id = popup->insertItem( i18n("Remove %1 From Project").arg(popupstr),
+                               this, SLOT(slotRemoveFromProject()) );
+            popup->setWhatsThis(id, i18n("<b>Remove from project</b><p>Removes current file from the list of files in project. "
+                "Note that the file should be manually excluded from corresponding makefile or build.xml."));
+        }
+        else
+        {
+	    m_contextAddFiles << contextFileName;
+            int id = popup->insertItem( i18n("Add %1 to Project").arg(popupstr),
+                               this, SLOT(slotAddToProject()) );
+            popup->setWhatsThis(id, i18n("<b>Add to project</b><p>Adds current file to the list of files in project. "
+                "Note that the file should be manually added to corresponding makefile or build.xml."));
+        }
     }
-    else
+    else   // more than one file
     {
-        int id = popup->insertItem( i18n("Add %1 to Project").arg(popupstr),
-                           this, SLOT(slotAddToProject()) );
-        popup->setWhatsThis(id, i18n("<b>Add to project</b><p>Adds current file to the list of files in project. "
-            "Note that the file should be manually added to corresponding makefile or build.xml."));
+        const KURL::List urls = fcontext->urls();
+	for (KURL::List::ConstIterator it = urls.begin(); it != urls.end(); ++it)
+	{
+	    if ((*it).isLocalFile())
+	    {
+	    	QString path(URLUtil::canonicalPath((*it).path()));
+		QString relPath( path );
+                if (relPath.startsWith(projectDirectory()+ "/"))
+                    relPath.remove(0, projectDirectory().length()+1);
+		if (project()->isProjectFile(path))
+		    m_contextRemoveFiles << relPath;
+		else
+		    m_contextAddFiles << relPath;
+	    }
+	}
+
+        if (m_contextAddFiles.size() > 0)
+	{
+            int id = popup->insertItem( i18n("Add Selected Files to Project"),
+                               this, SLOT(slotAddToProject()) );
+            popup->setWhatsThis(id, i18n("<b>Add to project</b><p>Adds selected files to the list of files in project. "
+                "Note that the files should be manually added to corresponding makefile or build.xml."));
+	}
+
+	if (m_contextRemoveFiles.size() > 0)
+	{
+            int id = popup->insertItem( i18n("Remove Selected Files From Project"),
+                               this, SLOT(slotRemoveFromProject()) );
+            popup->setWhatsThis(id, i18n("<b>Remove from project</b><p>Removes selected files from the list of files in project. "
+                "Note that the files should be manually excluded from corresponding makefile or build.xml."));
+	}
     }
 }
 
 
 void CustomProjectPart::slotAddToProject()
 {
-    addFile(m_contextFileName);
+    addFiles(m_contextAddFiles);
 }
 
 
 void CustomProjectPart::slotRemoveFromProject()
 {
-    removeFile(m_contextFileName);
+    removeFiles(m_contextRemoveFiles);
 }
 
 
@@ -228,7 +270,15 @@ void CustomProjectPart::openProject(const QString &dirName, const QString &proje
         DomUtil::writeEntry(dom, "/kdevcustomproject/run/directoryradio", "executable");
     }
 
-    QFile f(dirName + "/" + projectName + ".filelist");
+    /*this entry is currently only created by the cmake kdevelop3 project generator
+     in order to support completely-out-of-source builds, where nothing, not
+     even the kdevelop project files are created in the source directory, Alex <neundorf@kde.org>
+     */
+    QString filelistDir=DomUtil::readEntry(dom, "/kdevcustomproject/filelistdirectory");
+    if (filelistDir.isEmpty())
+       filelistDir=dirName;
+
+    QFile f(filelistDir + "/" + projectName + ".filelist");
     if (f.open(IO_ReadOnly)) {
         QTextStream stream(&f);
         while (!stream.atEnd()) {
@@ -285,7 +335,7 @@ void CustomProjectPart::populateProject()
                     s.push(path);
                 }
                 else {
-                    kdDebug(9025) << "Adding: " << path << endl;
+                        kdDebug(9025) << "Adding: " << path << endl;
                     m_sourceFiles.append(path.mid(prefixlen));
                 }
             }
@@ -297,6 +347,11 @@ void CustomProjectPart::populateProject()
 
 
 void CustomProjectPart::closeProject()
+{
+    saveProject();
+}
+
+void CustomProjectPart::saveProject()
 {
     QFile f(m_projectDirectory + "/" + m_projectName + ".filelist");
     if (!f.open(IO_WriteOnly))
@@ -444,6 +499,8 @@ void CustomProjectPart::addFiles ( const QStringList& fileList )
 	{
 		m_sourceFiles.append ( *it );
 	}
+	
+	saveProject();
 
 	kdDebug(9025) << "Emitting addedFilesToProject" << endl;
 	emit addedFilesToProject ( fileList );
@@ -468,6 +525,8 @@ void CustomProjectPart::removeFiles ( const QStringList& fileList )
 	{
 		m_sourceFiles.remove ( *it );
 	}
+	
+	saveProject();
 }
 
 QString CustomProjectPart::buildDirectory() const
@@ -521,15 +580,23 @@ void CustomProjectPart::startMakeCommand(const QString &dir, const QString &targ
         }
         if (DomUtil::readBoolEntry(dom, "/kdevcustomproject/make/dontact"))
             cmdline += " -n";
+        cmdline += " " + DomUtil::readEntry(dom, "/kdevcustomproject/make/makeoptions");
     }
 
     cmdline += " ";
     cmdline += target;
 
     QString dircmd = "cd ";
-    dircmd += dir;
+    dircmd += KProcess::quote(dir);
     dircmd += " && ";
 
+    int prio = DomUtil::readIntEntry(dom, "/kdevcustomproject/make/prio");
+    QString nice;
+    if (prio != 0) {
+        nice = QString("nice -n%1 ").arg(prio);
+    }
+
+    cmdline.prepend(nice);
     cmdline.prepend(makeEnvironment());
     m_buildCommand = dircmd + cmdline;
     makeFrontend()->queueCommand(dir, dircmd + cmdline);
@@ -672,11 +739,14 @@ void CustomProjectPart::updateTargetMenu()
             //}
             if (re.search(str) != -1)
             {
-	        kdDebug(9025) << "Adding target: " << re.cap(1) << endl;
-		m_targets += re.cap(1).simplifyWhiteSpace();
+                QString tmpTarget=re.cap(1).simplifyWhiteSpace();
+	        kdDebug(9025) << "Adding target: " << tmpTarget << endl;
+                if (m_targets.find(tmpTarget)==m_targets.end())
+                   m_targets += tmpTarget;
             }
         }
         f.close();
+        m_targets.sort();
     }
 
     int id = 0;
@@ -813,3 +883,17 @@ QString CustomProjectPart::currentMakeEnvironment() const
 
 
 #include "customprojectpart.moc"
+
+
+/*!
+    \fn CustomProjectPart::distFiles() const
+ */
+QStringList CustomProjectPart::distFiles() const
+{
+   	QStringList sourceList = allFiles();
+	// Scan current source directory for any .pro files.
+	QString projectDir = projectDirectory();
+	QDir dir(projectDir);
+	QStringList files = dir.entryList( "*README*");
+	return sourceList + files;
+}
