@@ -164,8 +164,8 @@ QString HaskellProjectPart::mainProgram( bool relative ) const
 	   			return( mainProgram );
 	    	}
 	  	}
-	}      
-	return QString::fromLatin1("");
+	}
+	return QString::null;      
 }
 
 QString HaskellProjectPart::runDirectory() const
@@ -287,7 +287,7 @@ QString HaskellProjectPart::createCmdLine( QString srcFile)
   	QString cmdLine = _compilerExec + " " + createPackageString() + " " + srcFile + " "
    									+ _compilerOpts + " -o " + mainProgram();
   	QString dirCmd = "cd ";
-  	dirCmd += buildDirectory();
+  	dirCmd += KProcess::quote(buildDirectory());
   	dirCmd += " && ";
 	return dirCmd + cmdLine;
 }
@@ -466,3 +466,19 @@ QString HaskellProjectPart::mainProgram()
     else
         return QDir::cleanDirPath(projectDirectory() + "/" + configMainProg);
 }
+
+
+/*!
+    \fn HaskellProjectPart::distFiles() const
+ */
+QStringList HaskellProjectPart::distFiles() const
+{
+   	QStringList sourceList = allFiles();
+	// Scan current source directory for any .pro files.
+	QString projectDir = projectDirectory();
+	QDir dir(projectDir);
+	QStringList files = dir.entryList( "*README*");
+	return sourceList + files;
+}
+
+#include "haskellproject_part.moc"
