@@ -221,7 +221,7 @@ void TrollProjectPart::projectConfigWidget(KDialogBase *dlg)
     QVBox *vbox;
     vbox = dlg->addVBoxPage(i18n("Run Options"));
     RunOptionsWidget *optdlg = new RunOptionsWidget(*projectDom(), "/kdevtrollproject", buildDirectory(), vbox);
-    
+
     vbox = dlg->addVBoxPage(i18n("Make Options"));
     MakeOptionsWidget *w4 = new MakeOptionsWidget(*projectDom(), "/kdevtrollproject", vbox);
     connect( dlg, SIGNAL(okClicked()), w4, SLOT(accept()) );
@@ -240,8 +240,8 @@ void TrollProjectPart::openProject(const QString &dirName, const QString &projec
     if (DomUtil::readEntry(dom, "/kdevtrollproject/run/directoryradio") == "" ) {
         DomUtil::writeEntry(dom, "/kdevtrollproject/run/directoryradio", "executable");
     }
-    
-    KDevProject::openProject( dirName, projectName );    
+
+    KDevProject::openProject( dirName, projectName );
 }
 
 
@@ -382,7 +382,8 @@ void TrollProjectPart::addFiles ( const QStringList &fileList )
     QStringList files = fileList;
     for (QStringList::iterator it = files.begin(); it != files.end(); ++it)
 //        if (!(*it).contains(projectDirectory()))
-        *it = projectDirectory() + "/" + (*it);
+        if (!isProjectFile(projectDirectory() + "/" + (*it)))
+            *it = projectDirectory() + "/" + (*it);
 
     m_widget->addFiles(files);
 
@@ -394,15 +395,15 @@ void TrollProjectPart::removeFile(const QString & /* fileName */)
     /// \FIXME
 /*	QStringList fileList;
 	fileList.append ( fileName );
-	
+
 	this->removeFiles ( fileList );*/
 }
 
 void TrollProjectPart::removeFiles ( const QStringList& fileList )
 {
 /// \FIXME missing remove files functionality
-// 	QStringList::ConstIterator it;	
-// 	
+// 	QStringList::ConstIterator it;
+//
 // 	it = fileList.begin();
 //
 // 	for ( ; it != fileList.end(); ++it )
@@ -478,7 +479,7 @@ void TrollProjectPart::startQMakeCommand(const QString &dir)
 //    cmdline += QString::fromLatin1( " -o Makefile" );
 
     QString dircmd = "cd ";
-    dircmd += dir;
+    dircmd += KProcess::quote(dir);
     dircmd += " && ";
 
     cmdline.prepend(makeEnvironment());
@@ -535,7 +536,7 @@ bool TrollProjectPart::isDirty()
     return false;
 }
 
-KDevProject::Options TrollProjectPart::options( )
+KDevProject::Options TrollProjectPart::options( ) const
 {
     return UsesQMakeBuildSystem;
 }
@@ -562,4 +563,46 @@ QStringList TrollProjectPart::availableQtDirList() const
     return lst;
 }
 
+QStringList recursiveProFind( const QString &currDir, const QString &baseDir )
+{
+	kdDebug() << "Dir " << currDir << endl;
+	QStringList fileList;
+
+	if( !currDir.contains( "/..") && !currDir.contains("/.") )
+	{
+		QDir dir(currDir);
+		QStringList dirList = dir.entryList(QDir::Dirs );
+		QStringList::Iterator idx = dirList.begin();
+		for( ; idx != dirList.end(); ++idx )
+		{
+			fileList += recursiveProFind( currDir + "/" + (*idx),baseDir );
+		}
+		QStringList newFiles = dir.entryList("*.pro *.PRO");
+		idx = newFiles.begin();
+		for( ; idx != newFiles.end(); ++idx )
+		{
+			QString file = currDir + "/" + (*idx);
+			fileList.append( file.remove( baseDir ) );
+		}
+	}
+
+
+	return fileList;
+}
+
+/*!
+    \fn TrollProjectPart::distFiles() const
+ */
+QStringList TrollProjectPart::distFiles() const
+{
+	QStringList sourceList = allFiles();
+	// Scan current source directory for any .pro files.
+	QString projectDir = projectDirectory();
+	QStringList files = recursiveProFind( projectDir, projectDir + "/" );
+	return sourceList + files;
+}
+
 #include "trollprojectpart.moc"
+
+
+
