@@ -37,7 +37,8 @@ public:
 
     bool isTMakeProject() const { return m_tmakeProject; }
     bool isDirty();
-    virtual Options options();
+    virtual Options options() const;
+    QStringList distFiles() const;
 
 protected:
     virtual void openProject(const QString &dirName, const QString &projectName);
