@@ -32,7 +32,7 @@ EditorChooserPart::~EditorChooserPart()
 
 void EditorChooserPart::configWidget(KDialogBase *dlg)
 {
-  QVBox *vbox = dlg->addVBoxPage(i18n("Editor"));
+  QVBox *vbox = dlg->addVBoxPage(i18n("Editor"), i18n("Editor"), BarIcon("kate", KIcon::SizeMedium) );
   EditorChooserWidget *w = new EditorChooserWidget(vbox);
   connect(dlg, SIGNAL(okClicked()), w, SLOT(accept()));
 }
