@@ -1,4 +1,4 @@
-/* $Id: qeditor_part.cpp,v 1.58.2.1 2004/02/02 18:09:24 aclu Exp $
+/* $Id: qeditor_part.cpp,v 1.60 2004/02/22 23:53:43 mueller Exp $
  *
  *  Copyright (C) 2001 Roberto Raggi (roberto@kdevelop.org)
  *
@@ -247,7 +247,7 @@ void QEditorPart::fileOpen()
     QString file_name = KFileDialog::getOpenFileName();
 
     if (file_name.isEmpty() == false)
-        openURL(file_name);
+        openURL(KURL::fromPathOrURL( file_name ));
 }
 
 void QEditorPart::fileSaveAs()
@@ -255,7 +255,7 @@ void QEditorPart::fileSaveAs()
     // this slot is called whenever the File->Save As menu is selected,
     QString file_name = KFileDialog::getSaveFileName();
     if (file_name.isEmpty() == false)
-        saveAs(file_name);
+        saveAs(KURL::fromPathOrURL( file_name ));
 }
 
 // -- EditInterface Implementation -- START -------------------------------------------------------------
