@@ -1,4 +1,4 @@
-/* $Id: qeditor_view.cpp,v 1.48 2003/11/06 21:19:11 dagerbo Exp $
+/* $Id: qeditor_view.cpp,v 1.51 2004/03/04 05:20:42 cunz Exp $
  *
  *  Copyright (C) 2001 Roberto Raggi (roberto@kdevelop.org)
  *
@@ -157,6 +157,7 @@ void QEditorView::setMarkerWidgetVisible( bool b )
 {
     if( b ){
 	m_markerWidget->show();
+	m_markerWidget->doRepaint();
     } else {
 	m_markerWidget->hide();
     }
@@ -171,6 +172,7 @@ void QEditorView::setLineNumberWidgetVisible( bool b )
 {
     if( b ){
 	m_lineNumberWidget->show();
+	m_lineNumberWidget->doRepaint();
     } else {
 	m_lineNumberWidget->hide();
     }
@@ -185,6 +187,7 @@ void QEditorView::setLevelWidgetVisible( bool b )
 {
     if( b ){
 	m_levelWidget->show();
+	m_levelWidget->doRepaint();
     } else {
 	m_levelWidget->hide();
     }
@@ -472,7 +475,7 @@ bool QEditorView::find_real( QTextParagraph* firstParagraph, int firstIndex,
 
 void QEditorView::doFind()
 {
-    m_findDialog->m_find->setEditURL(m_editor->selectedText());
+    m_findDialog->m_find->setEditURL(KURL( m_editor->selectedText() ));
 
     if( m_findDialog->exec() ){
         m_options = m_findDialog->options();
@@ -492,7 +495,7 @@ void QEditorView::doFind()
 
 void QEditorView::doReplace()
 {
-    m_replaceDialog->m_find->setEditURL(m_editor->selectedText());
+    m_replaceDialog->m_find->setEditURL(KURL( m_editor->selectedText() ));
 
     if( m_replaceDialog->exec() ){
         m_options = m_replaceDialog->options();
@@ -702,7 +705,7 @@ void QEditorView::setupActions()
     action = KStdAction::gotoLine( this, SLOT(gotoLine()), actionCollection() );
     action->setWhatsThis(i18n("Opens a dialog and lets you choose a line that you want the cursor to move to."));
     action = KStdAction::find( this, SLOT(doFind()), actionCollection() );
-    action->setWhatsThis(i18n("Looks up the first occurence of a piece of text or regular expression."));
+    action->setWhatsThis(i18n("Looks up the first occurrence of a piece of text or regular expression."));
     action = KStdAction::replace( this, SLOT(doReplace()), actionCollection() );
     action->setWhatsThis(i18n("Looks up a piece of text or regular expression and replace the result with some given text."));
 
