@@ -1,4 +1,4 @@
-// $Id: adasupportpart.h,v 1.3 2003/10/04 20:21:44 dymo Exp $
+// $Id: adasupportpart.h,v 1.4 2004/06/21 17:36:29 tobgle Exp $
 //
 #ifndef __ADASUPPORTPART_H__
 #define __ADASUPPORTPART_H__
@@ -34,7 +34,7 @@ private slots:
     void changedFilesInProject( const QStringList &fileList );
 
     void initialParse ();
-    void savedFile (const QString&);
+    void savedFile (const KURL&);
 
 private:
     void maybeParse (const QString &fileName);
