@@ -60,7 +60,7 @@ public:
     void removeAllFiles();
 
     TranslationUnitAST* translationUnit( const QString& fileName );
-    QValueList<Problem> problems( const QString& fileName );
+    QValueList<Problem> problems( const QString& fileName , bool readFromDisk = false, bool forceParse = false );
     void updateParserConfiguration();
 
     void close();
