@@ -5,6 +5,8 @@
  *   bernd@kdevelop.org                                                    *
  *   Copyright (C) 2002-2003 by Roberto Raggi                              *
  *   roberto@kdevelop.org                                                  *
+ *   Copyright (C) 2003-2004 by Alexander Dymo                             *
+ *   adymo@mksat.net                                                       *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -39,6 +41,9 @@
 #include "addmethoddialog.h"
 #include "addattributedialog.h"
 
+// designer integration
+#include "qtdesignerintegration.h"
+
 #include <qheader.h>
 #include <qdir.h>
 #include <qdom.h>
@@ -96,7 +101,7 @@
 #include <domutil.h>
 #include <config.h>
 
-enum { KDEV_DB_VERSION = 5 };
+enum { KDEV_DB_VERSION = 6 };
 enum { KDEV_PCS_VERSION = 5 };
 
 QStringList CppSupportPart::m_sourceMimeTypes = QStringList() << "text/x-csrc" << "text/x-c++src";
@@ -104,7 +109,7 @@ QStringList CppSupportPart::m_headerMimeTypes = QStringList() << "text/x-chdr" <
 
 QStringList CppSupportPart::m_sourceExtensions = QStringList::split( ",", "c,C,cc,cpp,c++,cxx,m,mm,M" );
 QStringList CppSupportPart::m_headerExtensions = QStringList::split( ",", "h,H,hh,hxx,hpp,inl,tlh,diff,ui.h" );
-    
+
 class CppDriver: public KDevDriver
 {
 public:
@@ -143,7 +148,7 @@ public:
 };
 
 CppSupportPart::CppSupportPart(QObject *parent, const char *name, const QStringList &args)
-    : KDevLanguageSupport("CppSupport", "cpp", parent, name ? name : "KDevCppSupport"),
+    : KDevLanguageSupport("CppSupport", "source_cpp", parent, name ? name : "KDevCppSupport"),
       m_activeDocument( 0 ), m_activeView( 0 ), m_activeSelection( 0 ), m_activeEditor( 0 ),
       m_activeViewCursor( 0 ), m_projectClosed( true ), m_valid( false )
 {
@@ -152,12 +157,12 @@ CppSupportPart::CppSupportPart(QObject *parent, const char *name, const QStringL
     m_pCompletionConfig = new CppCodeCompletionConfig( this, projectDom() );
     connect( m_pCompletionConfig, SIGNAL(stored()), this, SLOT(codeCompletionConfigStored()) );
 
-    m_driver = new CppDriver( this );    
+    m_driver = new CppDriver( this );
     m_problemReporter = 0;
 
     m_functionHintTimer = new QTimer( this );
-    connect( m_functionHintTimer, SIGNAL(timeout()), this, SLOT(slotFunctionHint()) );
-    
+//    connect( m_functionHintTimer, SIGNAL(timeout()), this, SLOT(slotFunctionHint()) );
+
     setXMLFile( "kdevcppsupport.rc" );
 
     m_catalogList.setAutoDelete( true );
@@ -165,8 +170,8 @@ CppSupportPart::CppSupportPart(QObject *parent, const char *name, const QStringL
     connect( core(), SIGNAL(projectOpened()), this, SLOT(projectOpened()) );
     connect( core(), SIGNAL(projectClosed()), this, SLOT(projectClosed()) );
     connect( core(), SIGNAL(languageChanged()), this, SLOT(projectOpened()) );
-    connect( partController(), SIGNAL(savedFile(const QString&)),
-             this, SLOT(savedFile(const QString&)) );
+    connect( partController(), SIGNAL(savedFile(const KURL&)),
+             this, SLOT(savedFile(const KURL&)) );
     connect( core(), SIGNAL(contextMenu(QPopupMenu *, const Context *)),
              this, SLOT(contextMenu(QPopupMenu *, const Context *)) );
     connect( partController(), SIGNAL(activePartChanged(KParts::Part*)),
@@ -205,7 +210,7 @@ CppSupportPart::CppSupportPart(QObject *parent, const char *name, const QStringL
     action->setToolTip(i18n("Make member"));
     action->setWhatsThis(i18n("<b>Make member</b><p>Creates a class member function in implementation file "
                               "based on the member declaration at the current line."));
-    action->setEnabled(false);
+    action->plug(new QWidget());
 
     action = new KAction(i18n("New Class..."), "classnew", 0,
                          this, SLOT(slotNewClass()),
@@ -230,7 +235,7 @@ CppSupportPart::CppSupportPart(QObject *parent, const char *name, const QStringL
 
 CppSupportPart::~CppSupportPart()
 {
-    if (project())
+    if ( !m_projectClosed )
       projectClosed();
 
     delete( m_driver );
@@ -238,7 +243,7 @@ CppSupportPart::~CppSupportPart()
 
     if( m_backgroundParser ){
 	m_backgroundParser->close();
-	m_backgroundParser->wait();
+//	m_backgroundParser->wait();
 	delete m_backgroundParser;
 	m_backgroundParser = 0;
     }
@@ -258,6 +263,11 @@ CppSupportPart::~CppSupportPart()
 
     m_pCompletion = 0;
     m_problemReporter = 0;
+
+	delete _jd;
+	_jd = 0;
+
+	kdDebug(9007) << k_funcinfo << endl;
 }
 
 void CppSupportPart::customEvent( QCustomEvent* ev )
@@ -266,7 +276,7 @@ void CppSupportPart::customEvent( QCustomEvent* ev )
 
     QTime t;
     t.start();
-    
+
     if( ev->type() == int(Event_FileParsed) ){
 	FileParsedEvent* event = (FileParsedEvent*) ev;
 	QString fileName = event->fileName();
@@ -295,14 +305,14 @@ void CppSupportPart::projectConfigWidget( KDialogBase* dlg )
 {
     QVBox* vbox = 0;
 
-    vbox = dlg->addVBoxPage( i18n( "C++ Specific" ) );
+	vbox = dlg->addVBoxPage( i18n( "C++ Specific" ), i18n( "C++ Specific" ), BarIcon( icon(), KIcon::SizeMedium) );
     CCConfigWidget* w = new CCConfigWidget( this, vbox );
     connect( dlg, SIGNAL( okClicked( ) ), w, SLOT( accept( ) ) );
 }
 
 void CppSupportPart::configWidget(KDialogBase *dlg)
 {
-  QVBox *vbox = dlg->addVBoxPage(i18n("C++ New Class Generator"));
+	QVBox *vbox = dlg->addVBoxPage(i18n("C++ Class Generator"), i18n( "C++ Class Generator" ), BarIcon( icon(), KIcon::SizeMedium) );
   ClassGeneratorConfig *w = new ClassGeneratorConfig(vbox, "classgenerator config widget");
   connect(dlg, SIGNAL(okClicked()), w, SLOT(storeConfig()));
 }
@@ -314,12 +324,12 @@ void CppSupportPart::activePartChanged(KParts::Part *part)
     bool enabled = false;
 
     m_functionHintTimer->stop();
-    
+
     if( m_activeView )
     {
 	disconnect( m_activeView, SIGNAL(cursorPositionChanged()), this, SLOT(slotCursorPositionChanged()) );
     }
-    
+
     m_activeDocument = dynamic_cast<KTextEditor::Document*>( part );
     m_activeView = part ? dynamic_cast<KTextEditor::View*>( part->widget() ) : 0;
     m_activeEditor = dynamic_cast<KTextEditor::EditInterface*>( part );
@@ -335,7 +345,7 @@ void CppSupportPart::activePartChanged(KParts::Part *part)
         if( isSource(m_activeFileName) || isHeader(m_activeFileName) )
 	    enabled = true;
     }
-    
+
     actionCollection()->action( "edit_switchheader" )->setEnabled( enabled );
     actionCollection()->action( "edit_complete_text" )->setEnabled( enabled );
     actionCollection()->action( "edit_make_member" )->setEnabled( enabled );
@@ -345,13 +355,13 @@ void CppSupportPart::activePartChanged(KParts::Part *part)
 
     if( !m_activeView )
 	return;
- 
+
     if( m_activeViewCursor )
     {
 	connect( m_activeView, SIGNAL(cursorPositionChanged()),
 		 this, SLOT(slotCursorPositionChanged()) );
     }
-        
+
 #if 0
     KTextEditor::TextHintInterface* textHintIface = dynamic_cast<KTextEditor::TextHintInterface*>( m_activeView );
     if( !textHintIface )
@@ -368,10 +378,10 @@ void CppSupportPart::activePartChanged(KParts::Part *part)
 void CppSupportPart::projectOpened( )
 {
     kdDebug( 9007 ) << "projectOpened( )" << endl;
-    
+
     m_backgroundParser = new BackgroundParser( this, &m_eventConsumed );
     m_backgroundParser->start();
-    
+
     // setup the driver
     QString conf_file_name = specialHeaderName();
     if( QFile::exists(conf_file_name) )
@@ -384,6 +394,7 @@ void CppSupportPart::projectOpened( )
 
     m_problemReporter = new ProblemReporter( this );
     m_problemReporter->setIcon( SmallIcon("info") );
+    m_problemReporter->setCaption( i18n("Problem Reporter") );
     mainWindow( )->embedOutputView( m_problemReporter, i18n("Problems"), i18n("Problem reporter"));
 
     connect( core(), SIGNAL(configWidget(KDialogBase*)),
@@ -423,10 +434,20 @@ void CppSupportPart::projectClosed( )
     }
     DomUtil::writeListEntry( *project()->projectDom(), "kdevcppsupport/references", "pcs", enabledPCSs );
 
+    for (QMap<KInterfaceDesigner::DesignerType, KDevDesignerIntegration*>::const_iterator it =  m_designers.begin();
+        it != m_designers.end(); ++it)
+    {
+        kdDebug() << "calling save settings fro designer integration" << endl;
+        it.data()->saveSettings(*project()->projectDom(), "kdevcppsupport/designerintegration");
+    }
+    
     saveProjectSourceInfo();
 
     m_pCompletionConfig->store();
 
+    delete _jd;
+    _jd = 0;
+
     delete m_pCompletion;
     m_pCompletion = 0;
     m_projectClosed = true;
@@ -456,25 +477,50 @@ void CppSupportPart::contextMenu(QPopupMenu *popup, const Context *context)
     m_activeVariable = 0;
 
     if( context->hasType(Context::EditorContext) ){
-        popup->insertSeparator();
-        int id = popup->insertItem( i18n( "Switch Header/Implementation"),
-                this, SLOT( slotSwitchHeader() ) );
-        popup->setWhatsThis( id, i18n("<b>Switch Header/Implementation</b><p>"
-                                      "If you are currently looking at a header file, this "
-                                      "brings you to the corresponding implementation file. "
-                                      "If you are looking at an implementation file (.cpp etc.), "
-                                      "this brings you to the corresponding header file.") );
+        int id;
+	
+	//Cache some values that are constant in this function
+	bool is_header, is_source;
+	QString source_header_candidate;
+		
+	is_header = isHeader(m_activeFileName);
+	is_source = isSource(m_activeFileName);	
+	
+        QString text;
+        int atline, atcol;
+        MakeMemberHelper(text,atline,atcol);
+        if(!text.isEmpty())
+        {
+         id = popup->insertItem( i18n( "Make Member"),
+                this, SLOT( slotMakeMember() ) );
+         popup->setWhatsThis( id, i18n("<b>Make member</b><p>Creates a class member function in implementation file "
+                              "based on the member declaration at the current line."));
+        }
+        
+	if((source_header_candidate = sourceOrHeaderCandidate()) != QString::null)
+	{
+	
+	 
+	}
 
        kdDebug(9007) << "======> code model has the file: " << m_activeFileName << " = " << codeModel()->hasFile( m_activeFileName ) << endl;
        if( codeModel()->hasFile(m_activeFileName) ){
            kdDebug() << "CppSupportPart::contextMenu 1" << endl;
            QString candidate;
-           if (isSource(m_activeFileName))
-               candidate = sourceOrHeaderCandidate();
+           if (is_source)
+               candidate = source_header_candidate;
            else
                candidate = m_activeFileName;
+	       
+		unsigned int curLine = 0, curCol = 0;
+		if (m_activeViewCursor != 0)
+			m_activeViewCursor->cursorPosition(&curLine, &curCol);
+		
+		FunctionDom currentFunction = 0;
+		bool hasDeclAndDef = false;//indicate wether a matfching declaration/definition has been found
+		bool fileExists = !candidate.isEmpty() && codeModel()->hasFile(candidate);
 //           kdDebug() << "CppSupportPart::contextMenu 2: candidate: " << candidate << endl;
-           if (!candidate.isEmpty() && codeModel()->hasFile(candidate) )
+           if (fileExists )
            {
                 QPopupMenu* m2 = new QPopupMenu( popup );
                 id = popup->insertItem( i18n("Go to Declaration"), m2 );
@@ -491,26 +537,33 @@ void CppSupportPart::contextMenu(QPopupMenu *popup, const Context *context)
 		    if( !text.isEmpty() )
 			text += "::";
 		    text += formatModelItem( *it, true );
-#if QT_VERSION >= 0x030100
-        text = text.replace( QString::fromLatin1("&"), QString::fromLatin1("&&") );
-#else
-        text = text.replace( QRegExp(QString::fromLatin1("&")), QString::fromLatin1("&&") );
-#endif
+		    text = text.replace( QString::fromLatin1("&"), QString::fromLatin1("&&") );
 		    int id = m2->insertItem( text, this, SLOT(gotoDeclarationLine(int)) );
-		    int line, column;
+		    int line, column, endLine, endColumn;
 		    (*it)->getStartPosition( &line, &column );
+			(*it)->getStartPosition( &line, &column );
+			(*it)->getEndPosition(&endLine, &endColumn);
 		    m2->setItemParameter( id, line );
+		    if (m_activeViewCursor)
+			if (curLine >= line && curLine <= endLine)//@todo currently column isn't checked, should be sufficient this way
+				currentFunction = *it;
                 }
+			if(m2->count() == 0)
+				popup->removeItem(id);
 //                kdDebug() << "CppSupportPart::contextMenu 4" << endl;
            }
 
            QString candidate1;
-           if (isHeader(m_activeFileName))
-               candidate1 = sourceOrHeaderCandidate();
+           if (is_header)
+               candidate1 = source_header_candidate;
            else
                candidate1 = m_activeFileName;
 //           kdDebug() << "CppSupportPart::go to definition in " << candidate1 << endl;
 
+		FunctionDefinitionDom currentFunctionDefintion = 0;
+		QString curFuncDefText;
+		CodeModelUtils::PredDefinitionMatchesDeclaration comparator(currentFunction);
+		
            if( codeModel()->hasFile(candidate1) ){
                QPopupMenu* m = new QPopupMenu( popup );
                id = popup->insertItem( i18n("Go to Definition"), m );
@@ -525,17 +578,69 @@ void CppSupportPart::contextMenu(QPopupMenu *popup, const Context *context)
 	           if( !text.isEmpty() )
 		       text += "::";
 	           text += formatModelItem( *it, true );
-#if QT_VERSION >= 0x030100
-       text = text.replace( QString::fromLatin1("&"), QString::fromLatin1("&&") );
-#else
-		   text = text.replace( QRegExp(QString::fromLatin1("&")), QString::fromLatin1("&&") );
-#endif
+	           text = text.replace( QString::fromLatin1("&"), QString::fromLatin1("&&") );
                    int id = m->insertItem( text, this, SLOT(gotoLine(int)) );
-	           int line, column;
+	           int line, column, endLine, endColumn;
 	           (*it)->getStartPosition( &line, &column );
+		   (*it)->getEndPosition(&endLine, &endColumn);
 	           m->setItemParameter( id, line );
-               }
+			if (currentFunction == 0)
+			{
+				if (curLine >= line && curLine <=endLine)//cursor is currently above function defintion, find matching declaration later
+				{//@todo currently column isn't checked, should be sufficient this way
+					currentFunctionDefintion = *it;
+					curFuncDefText= text;
+				}
+			} else
+			{
+				if ( comparator(*it) ) //functiondefintion found for declaration the cursor is currently above
+				{
+					int tmpId = popup->insertItem(i18n("Go to Definition of This Function")/* + text*/, this, SLOT(gotoLine(int))); 
+					int linel, coll;
+					(*it)->getStartPosition(&linel, &coll);
+					popup->setItemParameter(tmpId, linel);
+					hasDeclAndDef = true;
+				}
+			}
+		   
+				}
+				if(m->count() == 0)
+					popup->removeItem(id);
+			   
            }
+		if (fileExists && currentFunction == 0 && currentFunctionDefintion != 0)//cursor is above a functiondefintion, find matching  declaration
+		{
+			FileDom file2 = codeModel()->fileByName( candidate );
+			FunctionList functionList2 = CodeModelUtils::allFunctions(file2);
+			for( FunctionList::ConstIterator it=functionList2.begin(); it!=functionList2.end(); ++it )
+				if (CodeModelUtils::compareDeclarationToDefinition(*it, currentFunctionDefintion))
+				{
+					int tmpId = popup->insertItem(i18n("Go to Declaration of This Function")/* + curFuncDefText*/, this, SLOT(gotoDeclarationLine(int))); 
+					int linel, coll;
+					(*it)->getStartPosition(&linel, &coll);
+					popup->setItemParameter(tmpId, linel);
+					hasDeclAndDef = true;
+				}
+		}
+		if (!hasDeclAndDef)
+		{
+			QString tmp;
+	 		if(is_source)
+	  			tmp = i18n("Switch To Header");
+	 		else if(is_header)
+	  			tmp = i18n("Switch To Implementation");
+	  
+	 		if(!tmp.isEmpty())
+	 		{
+          			id = popup->insertItem( tmp,
+                		this, SLOT( slotSwitchHeader() ) );
+          			popup->setWhatsThis( id, i18n("<b>Switch Header/Implementation</b><p>"
+                                      "If you are currently looking at a header file, this "
+                                      "brings you to the corresponding implementation file. "
+                                      "If you are looking at an implementation file (.cpp etc.), "
+                                      "this brings you to the corresponding header file.") );
+	 		}
+		}
        }
 
 	const EditorContext *econtext = static_cast<const EditorContext*>(context);
@@ -568,6 +673,17 @@ void CppSupportPart::contextMenu(QPopupMenu *popup, const Context *context)
 	    m_activeFunction = (FunctionModel*) mcontext->item();
 	}
     }
+    else if (context->hasType(Context::FileContext)){
+        const FileContext *fc = static_cast<const FileContext*>(context);
+        //this is a .ui file and only selection contains only one such file
+        kdDebug() << "file context with " << fc->fileName() << endl;
+        if (fc->fileName().endsWith(".ui"))
+        {
+            m_contextFileName = fc->fileName();
+            int id = popup->insertItem(i18n("Create or Select Implementation..."), this, SLOT(slotCreateSubclass()));
+            popup->setWhatsThis(id, i18n("<b>Create or select implementation</b><p>Creates or selects a subclass of selected form for use with integrated KDevDesigner."));
+        }
+    }
 }
 
 
@@ -630,9 +746,9 @@ void CppSupportPart::changedFilesInProject( const QStringList & fileList )
     }
 }
 
-void CppSupportPart::savedFile(const QString &fileName)
+void CppSupportPart::savedFile(const KURL &fileName)
 {
-    Q_UNUSED( fileName );
+    Q_UNUSED( fileName.path() );
 
 #if 0  // not needed anymore
     kdDebug(9007) << "savedFile(): " << fileName.mid ( m_projectDirectory.length() + 1 ) << endl;
@@ -720,13 +836,13 @@ QString CppSupportPart::sourceOrHeaderCandidate()
 
 void CppSupportPart::slotSwitchHeader()
 {
-    partController()->editDocument(sourceOrHeaderCandidate());
+    partController()->editDocument(KURL( sourceOrHeaderCandidate() ));
 }
 
 void CppSupportPart::slotGotoIncludeFile()
 {
     if (!m_contextFileName.isEmpty())
-        partController()->editDocument(m_contextFileName, 0);
+        partController()->editDocument(KURL( m_contextFileName ), 0);
 
 }
 
@@ -741,12 +857,14 @@ KDevLanguageSupport::Features CppSupportPart::features()
 
 QString CppSupportPart::formatClassName(const QString &name)
 {
-    return name;
+    QString n = name;
+    return n.replace(".", "::");
 }
 
 QString CppSupportPart::unformatClassName(const QString &name)
 {
-    return name;
+    QString n = name;
+    return n.replace("::", ".");
 }
 
 void CppSupportPart::slotNewClass()
@@ -758,7 +876,7 @@ void CppSupportPart::slotNewClass()
 void CppSupportPart::addMethod( ClassDom klass )
 {
     if( !klass ){
-	KMessageBox::error(0,i18n("Please select a class!"),i18n("Error"));
+	KMessageBox::error(0,i18n("Please select a class."),i18n("Error"));
 	return;
     }
 
@@ -769,7 +887,7 @@ void CppSupportPart::addMethod( ClassDom klass )
 void CppSupportPart::addAttribute( ClassDom klass )
 {
     if( !klass ){
-	KMessageBox::error(0,i18n("Please select a class!"),i18n("Error"));
+	KMessageBox::error(0,i18n("Please select a class."),i18n("Error"));
 	return;
     }
 
@@ -797,7 +915,6 @@ void CppSupportPart::initialParse( )
     }
 
     parseProject( );
-    emit updatedSourceInfo();
     m_valid = true;
     return;
 }
@@ -824,117 +941,124 @@ uint toTime_t(QDateTime t)
 bool
 CppSupportPart::parseProject( bool force )
 {
-    //QLabel* label = new QLabel( "", mainWindow( )->statusBar( ) );
-    //label->setMinimumWidth( 600 );
-    //mainWindow( )->statusBar( )->addWidget( label );
-    //label->show( );
-
+        kdDebug( 9007 ) << "CppSupportPart::parseProject 1" << endl;
     mainWindow()->statusBar()->message( i18n("Updating...") );
 
-    kapp->processEvents( );
     kapp->setOverrideCursor( waitCursor );
 
-    QStringList files = reorder( modifiedFileList() );
+	_jd = new JobData;
+	_jd->file.setName( project()->projectDirectory() + "/" + project()->projectName() + ".pcs" );
 
-    QProgressBar* bar = new QProgressBar( files.count( ), mainWindow( )->statusBar( ) );
+	QString skip_file_name = project()->projectDirectory() + "/" + project()->projectName() + ".ignore_pcs";
+
+    if( !force && !QFile::exists( skip_file_name ) && _jd->file.open(IO_ReadOnly) )
+	{
+		_jd->stream.setDevice( &(_jd->file) );
+	
+		createIgnorePCSFile();
+	
+		QString sig;
+		int pcs_version = 0;
+		_jd->stream >> sig >> pcs_version;
+		if( sig == "PCS" && pcs_version == KDEV_PCS_VERSION ){
+	
+			int numFiles = 0;
+			_jd->stream >> numFiles;
+	
+			for( int i=0; i<numFiles; ++i ){
+			QString fn;
+			uint ts;
+			/*Q_LONG*/ uint offset;
+	
+			_jd->stream >> fn >> ts >> offset;
+			_jd->pcs[ fn ] = qMakePair( ts, offset );
+			}
+		}
+    }
+        kdDebug( 9007 ) << "CppSupportPart::parseProject 2" << endl;
+
+	_jd->files = reorder( modifiedFileList() );
+        kdDebug( 9007 ) << "CppSupportPart::parseProject 3" << endl;
+
+    QProgressBar* bar = new QProgressBar( _jd->files.count( ), mainWindow( )->statusBar( ) );
     bar->setMinimumWidth( 120 );
     bar->setCenterIndicator( true );
     mainWindow( )->statusBar( )->addWidget( bar );
     bar->show( );
+        kdDebug( 9007 ) << "CppSupportPart::parseProject 4" << endl;
+	
+	_jd->progressBar = bar;
+	_jd->dir.setPath( m_projectDirectory );
+	_jd->it = _jd->files.begin();
 
-    QDir d( m_projectDirectory );
+        kdDebug( 9007 ) << "CppSupportPart::parseProject 5" << endl;
+	QTimer::singleShot( 0, this, SLOT(slotParseFiles()) );
+	
+	return true;
+}
 
-    QDataStream stream;
-    QMap< QString, QPair<uint, Q_LONG> > pcs;
-
-    QString skip_file_name = project()->projectDirectory() + "/" + project()->projectName() + ".ignore_pcs";
-    
-    QFile f( project()->projectDirectory() + "/" + project()->projectName() + ".pcs" );
-    if( !force && !QFile::exists( skip_file_name ) && f.open(IO_ReadOnly) ){
-	stream.setDevice( &f );
- 
-        createIgnorePCSFile();
-
-	QString sig;
-	int pcs_version = 0;
-	stream >> sig >> pcs_version;
-	if( sig == "PCS" && pcs_version == KDEV_PCS_VERSION ){
-
-	    int numFiles = 0;
-	    stream >> numFiles;
-
-	    for( int i=0; i<numFiles; ++i ){
-		QString fn;
-		uint ts;
-		Q_LONG offset;
-
-		stream >> fn >> ts >> offset;
-		pcs[ fn ] = qMakePair( ts, offset );
-	    }
-	}
-    }
-
-    int n = 0;
-    for( QStringList::Iterator it = files.begin( ); it != files.end( ); ++it ) {
-        bar->setProgress( n++ );
-	QFileInfo fileInfo( d, *it );
-
-        if( fileInfo.exists() && fileInfo.isFile() && fileInfo.isReadable() ){
-            QString absFilePath = URLUtil::canonicalPath(fileInfo.absFilePath() );
-
-	    if( (n%5) == 0 ){
-	        kapp->processEvents();
-
-		if( m_projectClosed ){
-		    delete( bar );
-		    return false;
+void CppSupportPart::slotParseFiles()
+{
+	// NOTE: The checking for m_projectClosed is actually (currently) not needed.
+	// When the project is closed, the language support plugin is destroyed
+	// and as a consequence, the timer job signal never arrives at this method
+	
+	if ( !m_projectClosed && _jd->it != _jd->files.end() )
+	{
+		_jd->progressBar->setProgress( _jd->progressBar->progress() +1 );
+		
+		QFileInfo fileInfo( _jd->dir, *(_jd->it) );
+		
+		if( fileInfo.exists() && fileInfo.isFile() && fileInfo.isReadable() )
+		{
+			QString absFilePath = URLUtil::canonicalPath(fileInfo.absFilePath() );
+		
+			if( isValidSource(absFilePath) )
+			{
+				QDateTime t = fileInfo.lastModified();
+				if( ! (m_timestamp.contains(absFilePath) && m_timestamp[absFilePath] == t ) )
+				{	
+					if( _jd->pcs.contains(absFilePath) && t.toTime_t() == _jd->pcs[absFilePath].first )
+					{
+						_jd->stream.device()->at( _jd->pcs[absFilePath].second );
+						FileDom file = codeModel()->create<FileModel>();
+						file->read( _jd->stream );
+						codeModel()->addFile( file );
+					} 
+					else 
+					{
+						kdDebug(9007) << "newly parsing: " << absFilePath << endl;
+						m_driver->parseFile( absFilePath );
+					}
+			
+					m_timestamp[ absFilePath ] = t;
+				}
+			}
 		}
-	    }
-
-	    if( isValidSource(absFilePath) ){
-		QDateTime t = fileInfo.lastModified();
-		if( m_timestamp.contains(absFilePath) && m_timestamp[absFilePath] == t )
-		    continue;
-
-#if QT_VERSION >= 0x030100
-		if( pcs.contains(absFilePath) && t.toTime_t() == pcs[absFilePath].first ){
-#else
-		if( pcs.contains(absFilePath) && toTime_t(t) == pcs[absFilePath].first ){
-#endif
-		    stream.device()->at( pcs[absFilePath].second );
-		    FileDom file = codeModel()->create<FileModel>();
-		    file->read( stream );
-		    codeModel()->addFile( file );
-		} else {
-                    kdDebug(9007) << "newly parsing(" << absFilePath << ")..." << endl;
-		    m_driver->parseFile( absFilePath );
+		
+		++(_jd->it);
+		QTimer::singleShot( 0, this, SLOT(slotParseFiles()) );
+	}
+	else // finished or interrupted
+	{
+		kapp->restoreOverrideCursor( );
+		mainWindow( )->statusBar( )->removeWidget( _jd->progressBar );
+			
+		if ( !m_projectClosed )
+		{
+			kdDebug( 9007 ) << "updating sourceinfo" << endl;
+			emit updatedSourceInfo();
+			mainWindow( )->statusBar( )->message( i18n( "Done" ), 2000 );
+			QFile::remove( project()->projectDirectory() + "/" + project()->projectName() + ".ignore_pcs" );
 		}
-
-		m_timestamp[ absFilePath ] = t;
-	    }
-        }
-
-	if( m_projectClosed ){
-	    kdDebug(9007) << "ABORT" << endl;
-            kapp->restoreOverrideCursor( );
-	    return false;
+		else
+		{
+			kdDebug(9007) << "ABORT" << endl;
+		}
+		
+		delete _jd;
+		_jd = 0;
 	}
-    }
-
-    kdDebug( 9007 ) << "updating sourceinfo" << endl;
-    emit updatedSourceInfo();
-
-    mainWindow( )->statusBar( )->removeWidget( bar );
-    delete bar;
-    //mainWindow( )->statusBar( )->removeWidget( label );
-    //delete label;
-
-    kapp->restoreOverrideCursor( );
-    mainWindow( )->statusBar( )->message( i18n( "Done" ), 2000 );
-    
-    QFile::remove( skip_file_name );
-
-    return true;
 }
 
 void CppSupportPart::maybeParse( const QString& fileName )
@@ -988,13 +1112,11 @@ void CppSupportPart::slotNeedTextHint( int line, int column, QString& textHint )
     m_backgroundParser->unlock();
 }
 
-void CppSupportPart::slotMakeMember()
+void CppSupportPart::MakeMemberHelper(QString& text, int& atLine, int& atColumn)
 {
     if( !m_activeViewCursor || !m_valid )
         return;
 
-    QString text;
-
     m_backgroundParser->lock();
     TranslationUnitAST* translationUnit = m_backgroundParser->translationUnit( m_activeFileName );
     if( translationUnit ){
@@ -1048,34 +1170,54 @@ void CppSupportPart::slotMakeMember()
 
 	    text += declStr + "\n{\n}";
 	}
-
-	m_backgroundParser->unlock();
-
-	QString implFile = findSourceFile();
-
-	if( !text.isEmpty() && !implFile.isEmpty() ){
-	    partController()->editDocument( implFile );
-	    kapp->processEvents( 500 );
-	}
-
-	m_backgroundParser->lock();
-	translationUnit = m_backgroundParser->translationUnit( m_activeFileName );
-	int atLine, atColumn;
+ 
+        m_backgroundParser->unlock();
+        
+        QString implFile = findSourceFile();
+        
+        m_backgroundParser->lock();
+	translationUnit = m_backgroundParser->translationUnit( implFile );
 	if( translationUnit ){
 	    translationUnit->getEndPosition( &atLine, &atColumn );
 	} else {
-	    atLine = m_activeEditor->numLines() - 1;
+	    atLine = -2;
 	    atColumn = 0;
 	}
-
-	if( m_activeEditor )
-	    m_activeEditor->insertText( atLine, atColumn, text );
-	if( m_activeViewCursor )
-	    m_activeViewCursor->setCursorPositionReal( atLine+3, 1 );
+         kdDebug() << "at line in mm: " << atLine << endl;
     }
     m_backgroundParser->unlock();
 }
 
+void CppSupportPart::slotMakeMember()
+{
+QString text;
+int atColumn, atLine;
+MakeMemberHelper(text,atLine,atColumn);
+
+if(!text.isEmpty())
+{ 
+ QString implFile = findSourceFile();
+
+ if(!implFile.isEmpty() ){
+    partController()->editDocument( KURL( implFile ) );
+    kapp->processEvents( 500 );
+ }
+ if (atLine == -2)
+    atLine = m_activeEditor->numLines() - 1;
+
+ m_backgroundParser->lock();
+
+         kdDebug() << "at line in mm: " << atLine  << " atCol: " << atColumn << endl;
+         kdDebug() << "text: " << text << endl;
+ if( m_activeEditor )
+  m_activeEditor->insertText( atLine, atColumn, text );
+ if( m_activeViewCursor )
+  m_activeViewCursor->setCursorPositionReal( atLine+3, 1 );
+
+ m_backgroundParser->unlock();
+ }
+}
+
 QStringList CppSupportPart::subclassWidget(const QString& formName)
 {
     QStringList newFileNames;
@@ -1126,7 +1268,7 @@ QStringList CppSupportPart::modifiedFileList()
 
 	QFileInfo fileInfo( m_projectDirectory, fileName );
 	QString path = URLUtil::canonicalPath(fileInfo.absFilePath());
-	
+
 	if( !(isSource(path) || isHeader(path)) )
 	    continue;
 
@@ -1216,14 +1358,14 @@ KMimeType::List CppSupportPart::mimeTypes( )
     QStringList mimeList;
     mimeList += m_headerMimeTypes;
     mimeList += m_sourceMimeTypes;
-    
+
     KMimeType::List list;
     for( QStringList::Iterator it=mimeList.begin(); it!=mimeList.end(); ++it )
     {
 	if( KMimeType::Ptr mime = KMimeType::mimeType(*it) )
 	    list << mime;
     }
-    
+
     return list;
 }
 
@@ -1294,8 +1436,8 @@ bool CppSupportPart::isValidSource( const QString& fileName ) const
 {
     QFileInfo fileInfo( fileName );
     QString path = URLUtil::canonicalPath( fileInfo.absFilePath() );
- 
-    return project()->isProjectFile( path )
+
+    return project() && project()->isProjectFile( path )
 	&& (isSource( path ) || isHeader( path ))
 	&& !QFile::exists(fileInfo.dirPath(true) + "/.kdev_ignore");
 }
@@ -1354,15 +1496,15 @@ void CppSupportPart::saveProjectSourceInfo( )
 
     if( !project() || fileList.isEmpty() )
 	return;
-    
+
     QFile f( project()->projectDirectory() + "/" + project()->projectName() + ".pcs" );
     if( !f.open( IO_WriteOnly ) )
 	return;
-    
-    createIgnorePCSFile();    
+
+    createIgnorePCSFile();
 
     QDataStream stream( &f );
-    QMap<QString, Q_ULONG> offsets;
+    QMap<QString, uint> offsets;
 
     QString pcs( "PCS" );
     stream << pcs << KDEV_PCS_VERSION;
@@ -1376,7 +1518,7 @@ void CppSupportPart::saveProjectSourceInfo( )
   stream << dom->name() << toTime_t(m_timestamp[ dom->name() ]);
 #endif
 	offsets.insert( dom->name(), stream.device()->at() );
-	stream << (Q_ULONG)0; // dummy offset
+	stream << (uint)0; // dummy offset
     }
 
     for( FileList::ConstIterator it=fileList.begin(); it!=fileList.end(); ++it ){
@@ -1391,7 +1533,7 @@ void CppSupportPart::saveProjectSourceInfo( )
 	stream << offset;
 	stream.device()->at( end );
     }
-    
+
     QString skip_file_name = project()->projectDirectory() + "/" + project()->projectName() + ".ignore_pcs";
     QFile::remove( skip_file_name );
 }
@@ -1511,7 +1653,7 @@ bool CppSupportPart::isHeader( const QString& fileName ) const
     KMimeType::Ptr ptr = KMimeType::findByPath( fileName );
     if( ptr && m_headerMimeTypes.contains( ptr->name() ) )
 	return true;
-    
+
     return m_headerExtensions.contains( QFileInfo(fileName).extension() );
 }
 
@@ -1520,7 +1662,7 @@ bool CppSupportPart::isSource( const QString& fileName ) const
     KMimeType::Ptr ptr = KMimeType::findByPath( fileName );
     if( ptr && m_sourceMimeTypes.contains( ptr->name() ) )
 	return true;
-    
+
     return m_sourceExtensions.contains( QFileInfo(fileName).extension() );
 }
 
@@ -1579,7 +1721,7 @@ FunctionDefinitionDom CppSupportPart::functionDefinitionAt( int line, int column
 {
     if( !codeModel()->hasFile(m_activeFileName) )
 	return FunctionDefinitionDom();
-    
+
     FileDom file = codeModel()->fileByName( m_activeFileName );
     return functionDefinitionAt( model_cast<NamespaceDom>(file), line, column );
 }
@@ -1588,7 +1730,7 @@ FunctionDefinitionDom CppSupportPart::currentFunctionDefinition( )
 {
     if( !this->m_activeViewCursor )
 	return FunctionDefinitionDom();
-    
+
     unsigned int line, column;
     this->m_activeViewCursor->cursorPositionReal( &line, &column );
     return functionDefinitionAt( line, column );
@@ -1602,21 +1744,21 @@ FunctionDefinitionDom CppSupportPart::functionDefinitionAt( NamespaceDom ns, int
 	if( FunctionDefinitionDom def = functionDefinitionAt(*it, line, column) )
 	    return def;
     }
-    
+
     ClassList classList = ns->classList();
     for( ClassList::Iterator it=classList.begin(); it!=classList.end(); ++it )
     {
 	if( FunctionDefinitionDom def = functionDefinitionAt(*it, line, column) )
 	    return def;
     }
-    
+
     FunctionDefinitionList functionDefinitionList = ns->functionDefinitionList();
     for( FunctionDefinitionList::Iterator it=functionDefinitionList.begin(); it!=functionDefinitionList.end(); ++it )
     {
 	if( FunctionDefinitionDom def = functionDefinitionAt(*it, line, column) )
 	    return def;
     }
-    
+
     return FunctionDefinitionDom();
 }
 
@@ -1628,14 +1770,14 @@ FunctionDefinitionDom CppSupportPart::functionDefinitionAt( ClassDom klass, int
 	if( FunctionDefinitionDom def = functionDefinitionAt(*it, line, column) )
 	    return def;
     }
-    
+
     FunctionDefinitionList functionDefinitionList = klass->functionDefinitionList();
     for( FunctionDefinitionList::Iterator it=functionDefinitionList.begin(); it!=functionDefinitionList.end(); ++it )
     {
 	if( FunctionDefinitionDom def = functionDefinitionAt(*it, line, column) )
 	    return def;
     }
-    
+
     return FunctionDefinitionDom();
 }
 
@@ -1643,25 +1785,25 @@ FunctionDefinitionDom CppSupportPart::functionDefinitionAt( FunctionDefinitionDo
 {
     int startLine, startColumn;
     int endLine, endColumn;
-    
+
     fun->getStartPosition( &startLine, &startColumn );
     fun->getEndPosition( &endLine, &endColumn );
-    
+
     if( ! (line >= startLine && line <= endLine) )
 	return FunctionDefinitionDom();
-    
+
     if( line == startLine && column < startColumn )
 	return FunctionDefinitionDom();
-    
+
     if( line == endLine && column > endColumn )
 	return FunctionDefinitionDom();
-    
+
     return fun;
 }
 
 void CppSupportPart::slotCursorPositionChanged()
 {
-    m_functionHintTimer->changeInterval( 1000 );
+//    m_functionHintTimer->changeInterval( 1000 );
 }
 
 void CppSupportPart::slotFunctionHint( )
@@ -1674,9 +1816,9 @@ void CppSupportPart::slotFunctionHint( )
 	QString funName = scope.join( "::" );
 	if( !funName.isEmpty() )
 	    funName += "::";
-	
+
 	funName += formatModelItem( fun, true );
-	
+
 	mainWindow()->statusBar()->message( funName, 2000 );
     }
 }
@@ -1684,7 +1826,7 @@ void CppSupportPart::slotFunctionHint( )
 void CppSupportPart::createIgnorePCSFile( )
 {
     static QCString skip_me( "ignore me\n" );
-    
+
     QString skip_file_name = project()->projectDirectory() + "/" + project()->projectName() + ".ignore_pcs";
     QFile skip_pcs_file( skip_file_name );
     if( skip_pcs_file.open(IO_WriteOnly) )
@@ -1698,20 +1840,51 @@ QString CppSupportPart::specialHeaderName( bool local ) const
 {
 	if( local )
 		return ::locateLocal( "data", "kdevcppsupport/configuration", CppSupportFactory::instance() );
-	
+
 	return ::locate( "data", "kdevcppsupport/configuration", CppSupportFactory::instance() );
 }
 
 void CppSupportPart::updateParserConfiguration()
 {
 	m_backgroundParser->updateParserConfiguration();
-	
+
 	QString conf_file_name = specialHeaderName();
 	m_driver->removeAllMacrosInFile( conf_file_name );
-	
+
 	m_driver->parseFile( conf_file_name, true );
-	
+
 	parseProject( true );
 }
 
+KDevDesignerIntegration * CppSupportPart::designer( KInterfaceDesigner::DesignerType type )
+{
+    KDevDesignerIntegration *des = 0;
+    switch (type)
+    {
+        case KInterfaceDesigner::QtDesigner:
+            des = m_designers[type];
+            if (des == 0)
+            {
+                des = new QtDesignerIntegration(this);
+                kdDebug() << "1" << endl;
+                des->loadSettings(*project()->projectDom(), "kdevcppsupport/designerintegration");
+                kdDebug() << "2" << endl;
+                m_designers[type] = des;
+            }
+            break;
+    }
+    kdDebug() << "3" << endl;
+    return des;
+}
+
+void CppSupportPart::slotCreateSubclass()
+{
+    QFileInfo fi(m_contextFileName);
+    if (fi.extension(false) != "ui")
+        return;
+    QtDesignerIntegration *des = dynamic_cast<QtDesignerIntegration*>(designer(KInterfaceDesigner::QtDesigner));
+    if (des)
+        des->selectImplementation(m_contextFileName);
+}
+
 #include "cppsupportpart.moc"
