@@ -5,6 +5,8 @@
  *   bernd@kdevelop.org                                                    *
  *   Copyright (C) 2002-2003 by Roberto Raggi                              *
  *   roberto@kdevelop.org                                                  *
+ *   Copyright (C) 2003-2004 by Alexander Dymo                             *
+ *   adymo@mksat.net                                                       *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -24,6 +26,8 @@
 #include <qstring.h>
 #include <qwaitcondition.h>
 #include <qdatetime.h>
+#include <qdir.h>
+#include <qprogressbar.h>
 
 class Context;
 class CppCodeCompletion;
@@ -62,7 +66,11 @@ public:
     QString specialHeaderName( bool local=false ) const;
     void updateParserConfiguration();
 
-    ProblemReporter* problemReporter() { return isValid() ? (ProblemReporter*)m_problemReporter : 0; }
+	// @fixme - isValid is used to avoid using the problem reporter
+	// when a project is first parsed. This because the problem reporter
+	// is currently a great slowdown for large projects (see bug #73671)
+    ProblemReporter* problemReporter() { return isValid() ? static_cast<ProblemReporter *>(m_problemReporter) : 0; }
+    
     BackgroundParser* backgroundParser() { return m_backgroundParser; }
     CppCodeCompletion* codeCompletion() { return m_pCompletion; }
     CppCodeCompletionConfig* codeCompletionConfig() { return m_pCompletionConfig; }
@@ -97,6 +105,8 @@ public:
     bool isHeader(const QString& fileName) const;
     bool isSource(const QString& fileName) const;
 
+    virtual KDevDesignerIntegration *designer(KInterfaceDesigner::DesignerType type);
+    
 signals:
     void fileParsed( const QString& fileName );
 
@@ -113,7 +123,7 @@ private slots:
     void partRemoved( KParts::Part* part );
     void projectOpened();
     void projectClosed();
-    void savedFile(const QString &fileName);
+    void savedFile(const KURL &fileName);
     void configWidget(KDialogBase *dlg);
     void projectConfigWidget(KDialogBase *dlg);
     void contextMenu(QPopupMenu *popup, const Context *context);
@@ -135,6 +145,8 @@ private slots:
     void gotoLine( int line );
     void gotoDeclarationLine( int line );
     void emitFileParsed();
+    void slotParseFiles();
+    void slotCreateSubclass();
 
     void slotNeedTextHint( int, int, QString& );
 
@@ -157,6 +169,8 @@ private:
     void removeWithReferences( const QString& fileName );
     void createIgnorePCSFile();
 
+    void MakeMemberHelper(QString& text, int& atline, int& atcol);
+
     QString sourceOrHeaderCandidate();
 
     QStringList modifiedFileList();
@@ -183,6 +197,8 @@ private:
     KTextEditor::EditInterface* m_activeEditor;
     KTextEditor::ViewCursorInterface* m_activeViewCursor;
     QString m_activeFileName;
+    
+    QMap<KInterfaceDesigner::DesignerType, KDevDesignerIntegration*> m_designers;
 
     QWaitCondition m_eventConsumed;
     bool m_projectClosed;
@@ -209,6 +225,24 @@ private:
     
     friend class KDevCppSupportIface;
     friend class CppDriver;
+
+	struct JobData
+	{
+		QDir dir;
+		QProgressBar * progressBar;
+		QStringList::Iterator it;
+		QStringList files;
+		QMap< QString, QPair<uint, uint> > pcs;
+		QDataStream stream;
+		QFile file;
+		
+		~JobData()
+		{
+			delete progressBar;
+		}
+	};
+	
+	JobData * _jd;
 };
 
 #endif
