@@ -30,6 +30,7 @@
 #include <kapplication.h>
 #include <dcopclient.h>
 #include <qtimer.h>
+#include <kstringhandler.h>
 
 #include "kdevcore.h"
 #include "kdevproject.h"
@@ -80,7 +81,7 @@ DebuggerPart::DebuggerPart( QObject *parent, const char *name, const QStringList
     statusBarIndicator->show();
 
     // Setup widgets and dbgcontroller
-    variableWidget = new VariableWidget();
+    variableWidget = new VariableWidget( 0, "variablewidget");
     variableWidget->setEnabled(false);
     variableWidget->setIcon(SmallIcon("math_brace"));
     variableWidget->setCaption(i18n("Variable Tree"));
@@ -89,17 +90,17 @@ DebuggerPart::DebuggerPart( QObject *parent, const char *name, const QStringList
                               "The variable tree allows you to see "
                               "the variable values as you step "
                               "through your program using the internal "
-                              "debugger. Click the RMB on items in "
+                              "debugger. Click the right mouse button on items in "
                               "this view to get a popup menu.\n"
                               "To speed up stepping through your code "
                               "leave the tree items closed and add the "
                               "variable(s) to the watch section.\n"
                               "To change a variable value in your "
-                              "running app use a watch variable (eg a=5)."));
+                              "running app use a watch variable (&eg; a=5)."));
     mainWindow()->embedSelectView(variableWidget, i18n("Variables / Watch"), i18n("Debugger variable-view"));
-    mainWindow()->setViewAvailable(variableWidget, false);
+//    mainWindow()->setViewAvailable(variableWidget, false);
 
-    gdbBreakpointWidget = new GDBBreakpointWidget();
+    gdbBreakpointWidget = new GDBBreakpointWidget( 0, "gdbBreakpointWidget" );
     gdbBreakpointWidget->setCaption(i18n("Breakpoint List"));
     QWhatsThis::add
         (gdbBreakpointWidget, i18n("<b>Breakpoint list</b><p>"
@@ -111,7 +112,7 @@ DebuggerPart::DebuggerPart( QObject *parent, const char *name, const QStringList
     gdbBreakpointWidget->setIcon( SmallIcon("stop") );
     mainWindow()->embedOutputView(gdbBreakpointWidget, i18n("Breakpoints"), i18n("Debugger breakpoints"));
 
-    framestackWidget = new FramestackWidget();
+    framestackWidget = new FramestackWidget( 0, "framestackWidget" );
     framestackWidget->setEnabled(false);
     framestackWidget->setCaption(i18n("Frame Stack"));
     QWhatsThis::add
@@ -127,7 +128,7 @@ DebuggerPart::DebuggerPart( QObject *parent, const char *name, const QStringList
     mainWindow()->embedOutputView(framestackWidget, i18n("Frame Stack"), i18n("Debugger function call stack"));
     mainWindow()->setViewAvailable(framestackWidget, false);
 
-    disassembleWidget = new DisassembleWidget();
+    disassembleWidget = new DisassembleWidget( 0, "disassembleWidget" );
     disassembleWidget->setEnabled(false);
     disassembleWidget->setCaption(i18n("Machine Code Display"));
     QWhatsThis::add
@@ -143,9 +144,10 @@ DebuggerPart::DebuggerPart( QObject *parent, const char *name, const QStringList
                                   i18n("Debugger disassemble view"));
     mainWindow()->setViewAvailable(disassembleWidget, false);
 
-    gdbOutputWidget = new GDBOutputWidget;
+    gdbOutputWidget = new GDBOutputWidget( 0, "gdbOutputWidget" );
     gdbOutputWidget->setEnabled(false);
     gdbOutputWidget->setIcon( SmallIcon("inline_image") );
+    gdbOutputWidget->setCaption(i18n("GDB Output"));
     QWhatsThis::add
         (gdbOutputWidget, i18n("<b>GDB output</b><p>"
                                  "Shows all gdb commands being executed. "
@@ -171,7 +173,8 @@ DebuggerPart::DebuggerPart( QObject *parent, const char *name, const QStringList
     // Now setup the actions
     KAction *action;
 
-    action = new KAction(i18n("&Start"), "1rightarrow", CTRL+SHIFT+Key_F9,
+//    action = new KAction(i18n("&Start"), "1rightarrow", CTRL+SHIFT+Key_F9,
+    action = new KAction(i18n("&Start"), "dbgrun", CTRL+SHIFT+Key_F9,
                          this, SLOT(slotRun()),
                          actionCollection(), "debug_run");
     action->setToolTip( i18n("Start in debugger") );
@@ -259,7 +262,7 @@ DebuggerPart::DebuggerPart( QObject *parent, const char *name, const QStringList
         "<b>Libraries</b>"));
 
 
-    action = new KAction(i18n("Examine Core File"), "core", 0,
+    action = new KAction(i18n("Examine Core File..."), "core", 0,
                          this, SLOT(slotExamineCore()),
                          actionCollection(), "debug_core");
     action->setToolTip( i18n("Examine core file") );
@@ -289,8 +292,8 @@ DebuggerPart::DebuggerPart( QObject *parent, const char *name, const QStringList
     connect( core(), SIGNAL(projectConfigWidget(KDialogBase*)),
              this, SLOT(projectConfigWidget(KDialogBase*)) );
 
-    connect( partController(), SIGNAL(loadedFile(const QString &)),
-             gdbBreakpointWidget, SLOT(slotRefreshBP(const QString &)) );
+    connect( partController(), SIGNAL(loadedFile(const KURL &)),
+             gdbBreakpointWidget, SLOT(slotRefreshBP(const KURL &)) );
     connect( debugger(), SIGNAL(toggledBreakpoint(const QString &, int)),
              gdbBreakpointWidget, SLOT(slotToggleBreakpoint(const QString &, int)) );
     connect( debugger(), SIGNAL(editedBreakpoint(const QString &, int)),
@@ -441,7 +444,8 @@ void DebuggerPart::contextMenu(QPopupMenu *popup, const Context *context)
     }
     if (!m_contextIdent.isEmpty())
     {
-        int id = popup->insertItem( i18n("Watch: %1").arg(m_contextIdent), this, SLOT(contextWatch()) );
+        QString squeezed = KStringHandler::csqueeze(m_contextIdent, 30);
+        int id = popup->insertItem( i18n("Watch: %1").arg(squeezed), this, SLOT(contextWatch()) );
         popup->setWhatsThis(id, i18n("<b>Toggle breakpoint</b><p>Adds an expression under the cursor to the Variables/Watch list."));
     }
 }
@@ -472,7 +476,7 @@ void DebuggerPart::contextWatch()
 
 void DebuggerPart::projectConfigWidget(KDialogBase *dlg)
 {
-    QVBox *vbox = dlg->addVBoxPage(i18n("Debugger"));
+	QVBox *vbox = dlg->addVBoxPage(i18n("Debugger"), i18n("Debugger"), BarIcon( icon(), KIcon::SizeMedium) );
     DebuggerConfigWidget *w = new DebuggerConfigWidget(this, vbox, "debugger config widget");
     connect( dlg, SIGNAL(okClicked()), w, SLOT(accept()) );
     connect( dlg, SIGNAL(finished()), controller, SLOT(configure()) );
@@ -591,7 +595,7 @@ bool DebuggerPart::startDebugger()
             KMessageBox::error(
                 mainWindow()->main(),
                 i18n("Could not locate the debugging shell '%1'.").arg( shell ),
-                i18n("Debugging shell not found.") );
+                i18n("Debugging Shell Not Found") );
             return false;
         }
     }
@@ -602,7 +606,7 @@ bool DebuggerPart::startDebugger()
 
     KActionCollection *ac = actionCollection();
     ac->action("debug_run")->setText( i18n("&Continue") );
-    ac->action("debug_run")->setIcon( "dbgrun" );
+//    ac->action("debug_run")->setIcon( "dbgrun" );
     ac->action("debug_run")->setStatusText( i18n("Continues the application execution") );
     ac->action("debug_run")->setWhatsThis( i18n("Continue application execution\n\n"
                                            "Continues the execution of your application in the "
@@ -611,7 +615,7 @@ bool DebuggerPart::startDebugger()
                                            "been activated or the interrupt was pressed).") );
 
 
-    mainWindow()->setViewAvailable(variableWidget, true);
+//    mainWindow()->setViewAvailable(variableWidget, true);
     mainWindow()->setViewAvailable(framestackWidget, true);
     mainWindow()->setViewAvailable(disassembleWidget, true);
     mainWindow()->setViewAvailable(gdbOutputWidget, true);
@@ -652,14 +656,14 @@ void DebuggerPart::slotStopDebugger()
     disassembleWidget->setEnabled(false);
     gdbOutputWidget->setEnabled(false);
 
-    mainWindow()->setViewAvailable(variableWidget, false);
+//    mainWindow()->setViewAvailable(variableWidget, false);
     mainWindow()->setViewAvailable(framestackWidget, false);
     mainWindow()->setViewAvailable(disassembleWidget, false);
     mainWindow()->setViewAvailable(gdbOutputWidget, false);
 
     KActionCollection *ac = actionCollection();
     ac->action("debug_run")->setText( i18n("&Start") );
-    ac->action("debug_run")->setIcon( "1rightarrow" );
+//    ac->action("debug_run")->setIcon( "1rightarrow" );
     ac->action("debug_run")->setStatusText( i18n("Runs the program in the debugger") );
     ac->action("debug_run")->setWhatsThis( i18n("Start in debugger\n\n"
                                            "Starts the debugger with the project's main "
@@ -689,6 +693,15 @@ void DebuggerPart::slotRun()
     }
     else
     {
+        KActionCollection *ac = actionCollection();
+        ac->action("debug_run")->setText( i18n("&Continue") );
+        ac->action("debug_run")->setStatusText( i18n("Continues the application execution") );
+        ac->action("debug_run")->setWhatsThis( i18n("Continue application execution\n\n"
+            "Continues the execution of your application in the "
+            "debugger. This only takes effect when the application "
+            "has been halted by the debugger (i.e. a breakpoint has "
+            "been activated or the interrupt was pressed).") );
+
         mainWindow()->statusBar()->message(i18n("Continuing program"), 1000);
     }
     controller->slotRun();
@@ -857,7 +870,7 @@ void DebuggerPart::slotStatus(const QString &msg, int state)
         stateChanged( QString("stopped") );
         KActionCollection *ac = actionCollection();
         ac->action("debug_run")->setText( i18n("Restart") );
-        ac->action("debug_run")->setIcon( "1rightarrow" );
+//        ac->action("debug_run")->setIcon( "1rightarrow" );
         ac->action("debug_run")->setStatusText( i18n("Restart the program in the debugger") );
         ac->action("debug_run")->setWhatsThis( i18n("Restart in debugger\n\n"
                                            "Restarts the program in the debugger") );
@@ -884,7 +897,7 @@ void DebuggerPart::slotShowStep(const QString &fileName, int lineNum)
     if ( ! fileName.isEmpty() )
     {
         // Debugger counts lines from 1
-        debugger()->gotoExecutionPoint(fileName, lineNum-1);
+        debugger()->gotoExecutionPoint(KURL( fileName ), lineNum-1);
     }
 }
 
@@ -892,7 +905,7 @@ void DebuggerPart::slotShowStep(const QString &fileName, int lineNum)
 void DebuggerPart::slotGotoSource(const QString &fileName, int lineNum)
 {
     if ( ! fileName.isEmpty() )
-        partController()->editDocument(fileName, lineNum);
+        partController()->editDocument(KURL( fileName ), lineNum);
 }
 
 
