@@ -23,6 +23,7 @@
 #include <kiconloader.h>
 #include <klocale.h>
 #include <kpopupmenu.h>
+#include <kurl.h>
 
 #include <qvbuttongroup.h>
 #include <qfileinfo.h>
@@ -183,8 +184,8 @@ GDBBreakpointWidget::GDBBreakpointWidget(QWidget *parent, const char *name) :
     m_add       = new QToolButton( toolbar, "add breakpoint" );
     m_add->setPixmap ( SmallIcon ( "breakpoint_add" ) );
     QToolTip::add ( m_add, i18n ( "Add empty breakpoint" ) + I18N_NOOP(" <Alt+A>"));
-    QWhatsThis::add( m_add, i18n("<b>Add empty breakpoint</b><p>Shows a popup menu that allows to choose "
-        "the type of breakpoint. Then adds a breakpoint of selected type to the breakpoints list."));
+    QWhatsThis::add( m_add, i18n("<b>Add empty breakpoint</b><p>Shows a popup menu that allows you to choose "
+        "the type of breakpoint, then adds a breakpoint of the selected type to the breakpoints list."));
 
     m_delete    = new QToolButton( toolbar, "delete breakpoint" );
     m_delete->setPixmap ( SmallIcon ( "breakpoint_delete" ) );
@@ -292,7 +293,7 @@ void GDBBreakpointWidget::reset()
 
 // When a file is loaded then we need to tell the editor (display window)
 // which lines contain a breakpoint.
-void GDBBreakpointWidget::slotRefreshBP(const QString &filename)
+void GDBBreakpointWidget::slotRefreshBP(const KURL &filename)
 {
     for ( int row = 0; row < m_table->numRows(); row++ )
     {
@@ -300,7 +301,7 @@ void GDBBreakpointWidget::slotRefreshBP(const QString &filename)
         if (btr)
         {
             FilePosBreakpoint* bp = dynamic_cast<FilePosBreakpoint*>(btr->breakpoint());
-            if (bp && (bp->fileName() == filename))
+            if (bp && (bp->fileName() == filename.path()))
                 emit refreshBPState(*bp);
         }
     }
@@ -651,7 +652,7 @@ void GDBBreakpointWidget::slotRemoveBreakpoint()
 void GDBBreakpointWidget::slotRemoveAllBreakpoints()
 {
   while (m_table->numRows() > 0)
-  {    
+  {
     for ( int row = m_table->numRows()-1; row>=0; row-- )
     {
         BreakpointTableRow* btr = (BreakpointTableRow *) m_table->item(row, Control);
@@ -662,19 +663,22 @@ void GDBBreakpointWidget::slotRemoveAllBreakpoints()
 
 /***************************************************************************/
 
-void GDBBreakpointWidget::slotRowSelected(int row, int col, int, const QPoint &)
+void GDBBreakpointWidget::slotRowSelected(int row, int col, int btn, const QPoint &)
 {
+    if ( btn == Qt::LeftButton )
+	{
 //    kdDebug(9012) << "in slotRowSelected row=" << row << endl;
-    BreakpointTableRow* btr = (BreakpointTableRow *) m_table->item(row, Control);
-    if (btr)
-    {
-        FilePosBreakpoint* bp = dynamic_cast<FilePosBreakpoint*>(btr->breakpoint());
-        if (bp)
-            emit gotoSourcePosition(bp->fileName(), bp->lineNum()-1);
+        BreakpointTableRow* btr = (BreakpointTableRow *) m_table->item(row, Control);
+        if (btr)
+        {
+            FilePosBreakpoint* bp = dynamic_cast<FilePosBreakpoint*>(btr->breakpoint());
+            if (bp)
+                emit gotoSourcePosition(bp->fileName(), bp->lineNum()-1);
 
-        // put the focus back on the clicked item if appropriate
-        if (col == Location || col ==  Condition || col == IgnoreCount)
-            m_table->editCell(row, col, false);
+            // put the focus back on the clicked item if appropriate
+            if (col == Location || col ==  Condition || col == IgnoreCount)
+                m_table->editCell(row, col, false);
+        }
     }
 }
 
@@ -903,6 +907,11 @@ void GDBBreakpointWidget::slotAddBreakpoint( )
 
 /***************************************************************************/
 
+void GDBBreakpointWidget::focusInEvent( QFocusEvent */* e*/ )
+{
+    m_table->setFocus();
+}
+
 }
 
 
