@@ -145,10 +145,11 @@ GDBController::GDBController(VariableTree *varTree, FramestackWidget *frameStack
         config_displayStaticMembers_(false),
         config_asmDemangle_(true),
         config_dbgTerminal_(false),
-        config_gdbPath_()
+        config_gdbPath_(),
+        config_outputRadix_(10)
 {
     gdbSizeofBuf_ = sizeof(gdbOutput_);
-    
+
     configure();
     cmdList_.setAutoDelete(true);
 
@@ -192,9 +193,15 @@ void GDBController::configure()
     bool old_breakOnLoadingLibrary_ = config_breakOnLoadingLibrary_;
     config_breakOnLoadingLibrary_ = DomUtil::readBoolEntry(dom, "/kdevdebugger/general/breakonloadinglibs",true);
 
-    if (( old_displayStatic           != config_displayStaticMembers_   ||
+    int old_outputRadix  = config_outputRadix_;
+    config_outputRadix_   = DomUtil::readIntEntry(dom, "/kdevdebugger/display/outputradix", 10);
+    varTree_->setRadix(config_outputRadix_);
+    
+
+    if (( old_displayStatic             != config_displayStaticMembers_   ||
             old_asmDemangle             != config_asmDemangle_            ||
-            old_breakOnLoadingLibrary_  != config_breakOnLoadingLibrary_ )&&
+            old_breakOnLoadingLibrary_  != config_breakOnLoadingLibrary_  ||
+            old_outputRadix             != config_outputRadix_)           &&
             dbgProcess_)
     {
         bool restart = false;
@@ -232,14 +239,23 @@ void GDBController::configure()
                 queueCmd(new GDBCommand("set stop-on 0", NOTRUNCMD, NOTINFOCMD));
         }
 
-	if (!config_configGdbScript_.isEmpty()) {
-	    queueCmd(new GDBCommand("source " + config_configGdbScript_,
-				    NOTRUNCMD, NOTINFOCMD, 0));
-	}
+        if (old_outputRadix != config_outputRadix_)
+        {
+            queueCmd(new GDBCommand(QCString().sprintf("set output-radix %d",
+                                config_outputRadix_), NOTRUNCMD, NOTINFOCMD));
+
+            //rgruber: after changing the output radix, the watch- and the
+            //local-variables need to be refreshed
+            varTree_->findWatch()->requestWatchVars();
+            queueCmd(new GDBCommand("info args", NOTRUNCMD, INFOCMD, ARGS));
+            queueCmd(new GDBCommand("info local", NOTRUNCMD, INFOCMD, LOCALS));
+        }
+        
+        if (!config_configGdbScript_.isEmpty())
+          queueCmd(new GDBCommand("source " + config_configGdbScript_, NOTRUNCMD, NOTINFOCMD, 0));
 
         if (restart)
             queueCmd(new GDBCommand("continue", RUNCMD, NOTINFOCMD, 0));
-
     }
 }
 
@@ -674,7 +690,7 @@ void GDBController::parseLine(char* buf)
             KMessageBox::error( 0,
                                 i18n("gdb message:\n")+badCore_ + "\n" +
                                 QString(buf)+"\n\n"+
-                                i18n("The symbols gdb resolves maybe suspect"),
+                                i18n("The symbols gdb resolves may be suspect"),
                                 i18n("Mismatched Core File"));
 
         return;
@@ -682,9 +698,13 @@ void GDBController::parseLine(char* buf)
 
     if (strncmp(buf, "No symbol", 9) == 0 ||                    // watch point failed
             strncmp(buf, "Single", 6) == 0 ||                   // Single stepping
-            strncmp(buf, "No source file named", 20) == 0  ||   // breakpoint not set
-            strncmp(buf, "[Switching to Thread", 20) == 0 ||    //
-            strncmp(buf, "Current language:", 17) == 0)         //
+            strncmp(buf, "No source file named", 20) == 0      ||   // breakpoint not set
+            strncmp(buf, "[Switching to Thread", 20) == 0      ||    //
+            strncmp(buf, "[Thread debugging using", 23) == 0   ||
+            strncmp(buf, "Current language:", 17) == 0         ||
+            strncmp(buf, "Error while mapping shared library sections:", 44) == 0  ||
+            strncmp(buf, "Error while reading shared library symbols:", 43) == 0 ||
+            *buf == ':' )
     {
         // We don't change state, because this falls out when a run command
         // starts rather than when a run command stops.
@@ -708,6 +728,7 @@ void GDBController::parseLine(char* buf)
         return;
     }
 
+    
     /// @todo - Only do this at start up
     if (
         strstr(buf, "not in executable format:")                ||
@@ -1117,7 +1138,7 @@ char *GDBController::parse(char *buf)
             parsed = parseCmdBlock(unparsed);
         else
             parsed = parseOther(unparsed);
-        
+
         if (!parsed)
             break;
 
@@ -1289,6 +1310,9 @@ void GDBController::slotStart(const QString& shell, const DomUtil::PairList& run
     else
         queueCmd(new GDBCommand("set print asm-demangle off", NOTRUNCMD, NOTINFOCMD));
 
+    // make sure output radix is always set to users view.
+    queueCmd(new GDBCommand(QCString().sprintf("set output-radix %d",  config_outputRadix_), NOTRUNCMD, NOTINFOCMD));
+       
     // Change the "Working directory" to the correct one
     QCString tmp( "cd " + QFile::encodeName( run_directory ));
     queueCmd(new GDBCommand(tmp, NOTRUNCMD, NOTINFOCMD));
@@ -1329,7 +1353,7 @@ void GDBController::slotStopDebugger()
     kdDebug(9012) << "GDBController::slotStopDebugger() called" << endl;
     if (stateIsOn(s_shuttingDown) || !dbgProcess_)
         return;
-        
+
     setStateOn(s_shuttingDown|s_silent);
     kdDebug(9012) << "GDBController::slotStopDebugger() executing" << endl;
     destroyCmds();
@@ -1354,7 +1378,7 @@ void GDBController::slotStopDebugger()
     }
 
     // If the app is attached then we release it here. This doesn't stop
-    // the app running.        
+    // the app running.
     if (stateIsOn(s_attached))
     {
         kdDebug(9012) << "App is busy" << endl;
@@ -1379,7 +1403,7 @@ void GDBController::slotStopDebugger()
     const char *quit="quit\n";
     if (!dbgProcess_->writeStdin(quit, strlen(quit)))
         kdDebug(9012) << "failed to write 'quit' to gdb" << endl;
-    
+
     emit gdbStdout("(gdb) quit");
     start = QTime::currentTime();
     while (-1)
@@ -1458,38 +1482,38 @@ void GDBController::slotRun()
 
     if (stateIsOn(s_appNotStarted)) {
 
-	if (!config_runShellScript_.isEmpty()) {
-	    // Special for remote debug...
-	    QCString tty(tty_->getSlave().latin1());
-	    QCString options = QCString(" 2>&1 >") + tty + QCString(" <") + tty;
+        if (!config_runShellScript_.isEmpty()) {
+            // Special for remote debug...
+            QCString tty(tty_->getSlave().latin1());
+            QCString options = QCString(" 2>&1 >") + tty + QCString(" <") + tty;
 
-	    KProcess *proc = new KProcess;
+            KProcess *proc = new KProcess;
 
-	    *proc << "sh" << "-c";
-	    *proc << config_runShellScript_ + 
-		" " + application_.latin1() + options;
-	    proc->start(KProcess::DontCare);
-	}
+            *proc << "sh" << "-c";
+            *proc << config_runShellScript_ +
+                " " + application_.latin1() + options;
+            proc->start(KProcess::DontCare);
+        }
 
-	if (!config_runGdbScript_.isEmpty()) {// gdb script at run is requested
+        if (!config_runGdbScript_.isEmpty()) {// gdb script at run is requested
 
-	    // Race notice: wait for the remote gdbserver/executable
-	    // - but that might be an issue for this script to handle...
+            // Race notice: wait for the remote gdbserver/executable
+            // - but that might be an issue for this script to handle...
 
-	    // Future: the shell script should be able to pass info (like pid)
-	    // to the gdb script...
+            // Future: the shell script should be able to pass info (like pid)
+            // to the gdb script...
 
-	    queueCmd(new GDBCommand("source " + config_runGdbScript_,
-				    RUNCMD, NOTINFOCMD, 0));
+            queueCmd(new GDBCommand("source " + config_runGdbScript_,
+                                    RUNCMD, NOTINFOCMD, 0));
 
-	    // Note: script could contain "run" or "continue" 
-	}
-	else {
-	    queueCmd(new GDBCommand("run", RUNCMD, NOTINFOCMD, 0));
-	}
+            // Note: script could contain "run" or "continue"
+        }
+        else {
+            queueCmd(new GDBCommand("run", RUNCMD, NOTINFOCMD, 0));
+        }
     }
     else {
-	queueCmd(new GDBCommand("continue", RUNCMD, NOTINFOCMD, 0));
+        queueCmd(new GDBCommand("continue", RUNCMD, NOTINFOCMD, 0));
     }
 }
 
@@ -1763,7 +1787,10 @@ void GDBController::slotVarItemConstructed(VarItem *item)
 
     // jw - name and value come from "info local", for the type we
     // send a "whatis <varName>" here.
-    queueCmd(new GDBItemCommand(item, QCString("whatis ") + item->fullName().latin1(),
+    //rgr: remove any format modifier
+    QString strName = item->fullName();
+    strName.remove( QRegExp("/[xd] ", FALSE) );
+    queueCmd(new GDBItemCommand(item, QCString("whatis ") + strName.latin1(),
                                 false, WHATIS));
 }
 
@@ -1786,8 +1813,15 @@ void GDBController::slotExpandItem(TrimmableItem *genericItem)
             break;
 
         default:
-            queueCmd(new GDBItemCommand(varItem, QCString("print ") + varItem->fullName().latin1()));
-            break;
+             //rgr: we need to do this in order to move the output modifier
+             //     from the middle to the beginning
+             QString strCmd = varItem->fullName();
+             int iFound = strCmd.find( QRegExp("./[xd] ", FALSE) );
+             if (iFound != -1) {
+               strCmd.prepend( strCmd.mid(iFound+1, 3) );
+               strCmd.replace( QRegExp("./[xd] "), "." );
+             }
+             queueCmd(new GDBItemCommand(varItem, QCString("print ") + strCmd.latin1()));            break;
         }
         return;
     }
@@ -1896,7 +1930,7 @@ void GDBController::slotDbgStdout(KProcess *, char *buf, int buflen)
         // process from, and make it into a c-string so we can use the string fns
 //        kdDebug(9012)   << "Adding holdingZone_ (" << holdingZone_.length()   << ")" << endl
 //                        << holdingZone_ << endl;
-                        
+
         qstrcpy(gdbOutput_+gdbOutputLen_, holdingZone_);
         gdbOutputLen_ += holdingZone_.length();
         *(gdbOutput_+gdbOutputLen_) = 0;
@@ -1904,13 +1938,13 @@ void GDBController::slotDbgStdout(KProcess *, char *buf, int buflen)
 
 //        kdDebug(9012)   << "Output to parse (" << gdbOutputLen_   << ")" << endl
 //                        << gdbOutput_ << endl << "*************" << endl;
-                        
+
         parsing = true;
         char *nowAt = parse(gdbOutput_);
         parsing = false;
 
         if (nowAt)
-        {    
+        {
 //            kdDebug(9012)   << "*** " << nowAt-gdbOutput_ << " bytes have been parsed " << endl;
             Q_ASSERT(nowAt <= gdbOutput_+gdbOutputLen_+1);
             gdbOutputLen_ = strlen(nowAt);
@@ -1921,14 +1955,14 @@ void GDBController::slotDbgStdout(KProcess *, char *buf, int buflen)
             else
                 *gdbOutput_ = 0;
         }
-        
+
 //        kdDebug(9012)   << "Output remaining (" << gdbOutputLen_  << ")" << endl
 //                        << gdbOutput_ << endl << "*************" << endl;
-                        
+
         if (!nowAt && !holdingZone_.length())
             break;
     }
-                        
+
     // check the queue for any commands to send
     executeCmd();
 }
