@@ -63,13 +63,13 @@ JavaDebuggerPart::JavaDebuggerPart(QObject *parent, const char *name, const QStr
                                          "The variable tree allows you to see "
                                          "the variable values as you step "
                                          "through your program using the internal "
-                                         "debugger. Click the RMB on items in "
+                                         "debugger. Click the right mouse button on items in "
                                          "this view to get a popup menu.\n"
                                          "To speed up stepping through your code "
                                          "leave the tree items closed and add the "
                                          "variable(s) to the watch section.\n"
                                          "To change a variable value in your "
-                                         "running app use a watch variable (eg a=5)."));
+                                         "running app use a watch variable (&eg; a=5)."));
     mainWindow()->embedSelectView(variableWidget, i18n("Watch"), i18n("debugger variable-view"));
     mainWindow()->setViewAvailable(variableWidget, false);
 
@@ -78,8 +78,8 @@ JavaDebuggerPart::JavaDebuggerPart(QObject *parent, const char *name, const QStr
     QWhatsThis::add(breakpointWidget, i18n("Breakpoint list\n\n"
                                            "Displays a list of breakpoints with "
                                            "their current status. Clicking on a "
-                                           "breakpoint item with the RMB displays "
-                                           "a popupmenu so you may manipulate the "
+                                           "breakpoint item with the right mouse button displays "
+                                           "a popup menu so you may manipulate the "
                                            "breakpoint. Double clicking will take you "
                                            "to the source in the editor window."));
     mainWindow()->embedOutputView(breakpointWidget, i18n("&Breakpoints"), i18n("debugger breakpoints"));
@@ -487,13 +487,13 @@ void JavaDebuggerPart::slotStatus(const QString &msg, int state)
 void JavaDebuggerPart::slotShowStep(const QString &fileName, int lineNum)
 {
     // Debugger counts lines from 1
-    debugger()->gotoExecutionPoint(fileName, lineNum-1);
+    debugger()->gotoExecutionPoint(KURL( fileName ), lineNum-1);
 }
 
 
 void JavaDebuggerPart::slotGotoSource(const QString &fileName, int lineNum)
 {
-    partController()->editDocument(fileName, lineNum);
+    partController()->editDocument(KURL( fileName ), lineNum);
 }
 
 }
