@@ -146,8 +146,8 @@ JavaSupportPart::JavaSupportPart(QObject *parent, const char *name, const QStrin
 
     connect( core(), SIGNAL(projectOpened()), this, SLOT(projectOpened()) );
     connect( core(), SIGNAL(projectClosed()), this, SLOT(projectClosed()) );
-    connect( partController(), SIGNAL(savedFile(const QString&)),
-             this, SLOT(savedFile(const QString&)) );
+    connect( partController(), SIGNAL(savedFile(const KURL&)),
+             this, SLOT(savedFile(const KURL&)) );
     connect( core(), SIGNAL(contextMenu(QPopupMenu *, const Context *)),
              this, SLOT(contextMenu(QPopupMenu *, const Context *)) );
     connect( partController(), SIGNAL(activePartChanged(KParts::Part*)),
@@ -398,9 +398,9 @@ void JavaSupportPart::changedFilesInProject( const QStringList & fileList )
     }
 }
 
-void JavaSupportPart::savedFile(const QString &fileName)
+void JavaSupportPart::savedFile(const KURL &fileName)
 {
-    Q_UNUSED( fileName );
+    Q_UNUSED( fileName.path() );
 
 #if 0  // not needed anymore
     kdDebug(9013) << "savedFile(): " << fileName.mid ( m_projectDirectory.length() + 1 ) << endl;
