@@ -69,8 +69,8 @@ PHPSupportPart::PHPSupportPart(QObject *parent, const char *name, const QStringL
 
   connect( core(), SIGNAL(projectOpened()), this, SLOT(projectOpened()) );
   connect( core(), SIGNAL(projectClosed()), this, SLOT(projectClosed()) );
-  connect( partController(), SIGNAL(savedFile(const QString&)),
-             this, SLOT(savedFile(const QString&)) );
+  connect( partController(), SIGNAL(savedFile(const KURL&)),
+             this, SLOT(savedFile(const KURL&)) );
   connect( core(), SIGNAL(projectConfigWidget(KDialogBase*)),
 	   this, SLOT(projectConfigWidget(KDialogBase*)) );
 
@@ -102,7 +102,7 @@ PHPSupportPart::PHPSupportPart(QObject *parent, const char *name, const QStringL
   connect(phpExeProc, SIGNAL(processExited(KProcess*)),
 	  this, SLOT(slotPHPExeExited(KProcess*)));
 
-  m_htmlView = new PHPHTMLView();
+  m_htmlView = new PHPHTMLView(this);
   mainWindow()->embedPartView(m_htmlView->view(), i18n("PHP"), "PHP");	// @fixme after stringfreeze - last argument should be i18n() 
   connect(m_htmlView,  SIGNAL(started(KIO::Job*)),
 	  this, SLOT(slotWebJobStarted(KIO::Job*)));
@@ -135,7 +135,7 @@ PHPSupportPart::~PHPSupportPart()
 
     if(m_phpErrorView){
       mainWindow()->removeView( m_phpErrorView );
-      delete( m_phpErrorView );
+      //Seems, that removeView already frees the pointer, so we don't need to free it here
       m_phpErrorView = 0;
     }
 }
@@ -309,7 +309,7 @@ void PHPSupportPart::executeInTerminal(){
       
   QString file;
   if(m_htmlView==0){
-    m_htmlView = new PHPHTMLView();
+    m_htmlView = new PHPHTMLView(this);
     mainWindow()->embedPartView(m_htmlView->view(), i18n("PHP"));
   }
   m_htmlView->show();
@@ -459,13 +459,13 @@ void PHPSupportPart::removedFilesFromProject(const QStringList &fileList)
 }
 
 
-void PHPSupportPart::savedFile(const QString &fileName)
+void PHPSupportPart::savedFile(const KURL &fileName)
 {
     kdDebug(9018) << "savedFile()" << endl;
 
-    if (project()->allFiles().contains(fileName.mid ( project()->projectDirectory().length() + 1 ))) {
-        maybeParse(fileName);
-        emit addedSourceInfo( fileName );
+    if (project()->allFiles().contains(fileName.path().mid ( project()->projectDirectory().length() + 1 ))) {
+        maybeParse(fileName.path());
+        emit addedSourceInfo( fileName.path() );
     }
 }
 
