@@ -30,7 +30,7 @@
 #include <kdebug.h>
 #include <kdialogbase.h>
 #include <kdevgenericfactory.h>
-#include <klineeditdlg.h>
+#include <kinputdialog.h>
 #include <klocale.h>
 #include <qregexp.h>
 
@@ -48,8 +48,8 @@ PythonSupportPart::PythonSupportPart(QObject *parent, const char *name, const QS
 
     connect( core(), SIGNAL(projectOpened()), this, SLOT(projectOpened()) );
     connect( core(), SIGNAL(projectClosed()), this, SLOT(projectClosed()) );
-    connect( partController(), SIGNAL(savedFile(const QString&)),
-             this, SLOT(savedFile(const QString&)) );
+    connect( partController(), SIGNAL(savedFile(const KURL&)),
+             this, SLOT(savedFile(const KURL&)) );
     connect( core(), SIGNAL(projectConfigWidget(KDialogBase*)),
              this, SLOT(projectConfigWidget(KDialogBase*)) );
 
@@ -70,7 +70,7 @@ PythonSupportPart::PythonSupportPart(QObject *parent, const char *name, const QS
     action = new KAction( i18n("Start Python Interpreter"), "exec", 0,
                           this, SLOT(slotStartInterpreter()),
                           actionCollection(), "build_runinterpreter" );
-    action->setToolTip( i18n("Start python interpreter") );
+    action->setToolTip( i18n("Start Python interpreter") );
     action->setWhatsThis(i18n("<b>Start python interpreter</b><p>Starts the Python interpreter without a program"));
 
     action = new KAction( i18n("Python Documentation..."), 0,
@@ -185,13 +185,13 @@ void PythonSupportPart::removedFilesFromProject(const QStringList &fileList)
 }
 
 
-void PythonSupportPart::savedFile(const QString &fileName)
+void PythonSupportPart::savedFile(const KURL &fileName)
 {
     kdDebug(9014) << "savedFile()" << endl;
 
-    if (project()->allFiles().contains(fileName.mid ( project()->projectDirectory().length() + 1 ))) {
-        maybeParse(fileName);
-        emit addedSourceInfo( fileName );
+    if (project()->allFiles().contains(fileName.path().mid ( project()->projectDirectory().length() + 1 ))) {
+        maybeParse(fileName.path());
+	emit addedSourceInfo( fileName.path() );
     }
 }
 
@@ -323,7 +323,7 @@ void PythonSupportPart::slotStartInterpreter()
 void PythonSupportPart::slotExecuteString()
 {
     bool ok;
-    QString cmd = KLineEditDlg::getText(i18n("String to execute"), QString::null, &ok, 0);
+    QString cmd = KInputDialog::getText(i18n("String to Execute"), i18n("String to execute:"), QString::null, &ok, 0);
     if (ok) {
         cmd.prepend("'");
         cmd.append("'");
@@ -335,7 +335,7 @@ void PythonSupportPart::slotExecuteString()
 void PythonSupportPart::slotPydoc()
 {
     bool ok;
-    QString key = KLineEditDlg::getText(i18n("Show Python documentation on keyword:"), "", &ok, 0);
+    QString key = KInputDialog::getText(i18n("Show Python Documentation"), i18n("Show Python documentation on keyword:"), "", &ok, 0);
     if (ok && !key.isEmpty()) {
         QString url = "pydoc:";
         url += key;
