@@ -32,7 +32,8 @@
 
 #include "kdevproject.h"
 
-#include "property.h"
+#include "propertylist.h"
+#include "multiproperty.h"
 
 class BuildFileItem;
 class BuildGroupItem;
@@ -61,12 +62,12 @@ public:
     BuildBaseItem* parent() { return m_parent; }
     const BuildBaseItem* parent() const { return m_parent; }
 
-    const QMap<QString, PropPtr>& attributes() const { return m_attributes; }
-    QMap<QString, PropPtr> *pAttributes() { return &m_attributes; }
+    PropertyLib::PropertyList& attributes() { return m_attributes; }
+    PropertyLib::PropertyList *pAttributes() { return &m_attributes; }
 
-    bool hasAttribute( const QString& name ) const { return m_attributes.contains( name ); }
-    QVariant attribute( const QString& name ) const { return m_attributes[ name ]->value(); }
-    void setAttribute( const QString& name, const QVariant& value ) { m_attributes[ name ]->setValue(value); }
+//    bool hasAttribute( const QString& name ) const { return m_attributes.contains( name ); }
+    QVariant attribute( const QString& name ) { return m_attributes[name]->value(); }
+    void setAttribute( const QString& name, const QVariant& value ) { m_attributes[name]->setValue(value); }
 
     virtual QString path();
 
@@ -76,7 +77,7 @@ protected:
 private:
     int m_type;
     BuildBaseItem* m_parent;
-    QMap<QString, PropPtr> m_attributes;
+    PropertyLib::PropertyList m_attributes;
 
 private:
     BuildBaseItem( const BuildBaseItem& source );
