@@ -22,15 +22,16 @@
 
 #include <qpopupmenu.h>
 #include <kapplication.h>
+#include <kconfig.h>
 #include <ktoolbar.h>
 #include <kmainwindow.h>
 #include <klocale.h>
 #include <kaction.h>
 #include <qstring.h>
 #include <assert.h>
-#include <kdeversion.h>
 #include <kdebug.h>
-#include <kmdidockwidget.h>
+#include <kdockwidget.h>
+#include <kdeversion.h>
 #include "kmdimainfrm.h"
 #include "kmditoolviewaccessor.h"
 #include "kmditoolviewaccessor_p.h"
@@ -54,16 +55,18 @@ namespace
 
 using namespace KMDIPrivate;
 
-ToggleToolViewAction::ToggleToolViewAction( const QString& text, const KShortcut& cut,KMdiDockWidget *dw, KMdiMainFrm *mdiMainFrm,
+
+
+ToggleToolViewAction::ToggleToolViewAction( const QString& text, const KShortcut& cut,KDockWidget *dw, KMdiMainFrm *mdiMainFrm,
 	QObject* parent, const char* name )
         :KToggleAction(text,cut,parent,name),m_dw(dw),m_mdiMainFrm(mdiMainFrm)
 {
-	if (m_dw) {
-		connect(this,SIGNAL(toggled(bool)),this,SLOT(slotToggled(bool)));
-		connect(m_dw->dockManager(),SIGNAL(change()),this,SLOT(anDWChanged()));
-		connect(m_dw,SIGNAL(destroyed()),this,SLOT(slotWidgetDestroyed()));
-		setChecked(m_dw->mayBeHide());
-	}
+  if (m_dw) {
+    connect(this,SIGNAL(toggled(bool)),this,SLOT(slotToggled(bool)));
+    connect(m_dw->dockManager(),SIGNAL(change()),this,SLOT(anDWChanged()));
+    connect(m_dw,SIGNAL(destroyed()),this,SLOT(slotWidgetDestroyed()));
+    setChecked(m_dw->mayBeHide());
+  }
 }
 
 
@@ -74,8 +77,8 @@ void ToggleToolViewAction::anDWChanged()
         if (isChecked() && m_dw->mayBeShow()) setChecked(false);
         else if ((!isChecked()) && m_dw->mayBeHide()) setChecked(true);
         else if (isChecked() && (m_dw->parentDockTabGroup() &&
-            ((static_cast<KMdiDockWidget*>(m_dw->parentDockTabGroup()->
-                        parent()->qt_cast("KDockWidget_Compat::KDockWidget")))->mayBeShow()))) setChecked(false);
+                ((static_cast<KDockWidget*>(m_dw->parentDockTabGroup()->
+                        parent()->qt_cast("KDockWidget")))->mayBeShow()))) setChecked(false);
 }
 
 
@@ -99,7 +102,7 @@ void ToggleToolViewAction::slotWidgetDestroyed()
 }
 
 
-KMDIGUIClient::KMDIGUIClient(KMdiMainFrm* mdiMainFrm,bool showMDIModeAction, const char* name): QObject( mdiMainFrm,name ), 
+KMDIGUIClient::KMDIGUIClient(KMdiMainFrm* mdiMainFrm,bool showMDIModeAction, const char* name): QObject( mdiMainFrm,name ),
 KXMLGUIClient( mdiMainFrm )
 {
    m_mdiMode=KMdi::ChildframeMode;
@@ -121,15 +124,13 @@ KXMLGUIClient( mdiMainFrm )
         setXML( completeDescription, false /*merge*/ );
     }
 
-#if KDE_VERSION > 305	 
     if (actionCollection()->kaccel()==0)
 	    actionCollection()->setWidget(mdiMainFrm);
-#endif		
     m_toolMenu=new KActionMenu(i18n("Tool &Views"),actionCollection(),"kmdi_toolview_menu");
     if (showMDIModeAction) {
 	    m_mdiModeAction=new KSelectAction(i18n("MDI Mode"),0,actionCollection());
 	    QStringList modes;
-	    modes<<i18n("&Toplevel Mode")<<i18n("C&hildframe Mode")<<i18n("Ta&b Page Mode")<<i18n("I&DEAL Mode");
+	    modes<<i18n("&Toplevel Mode")<<i18n("C&hildframe Mode")<<i18n("Ta&b Page Mode")<<i18n("I&DEAl Mode");
 	    m_mdiModeAction->setItems(modes);
 	    connect(m_mdiModeAction,SIGNAL(activated(int)),this,SLOT(changeViewMode(int)));
     } else m_mdiModeAction=0;
@@ -151,13 +152,15 @@ KXMLGUIClient( mdiMainFrm )
 		actionCollection(),"kmdi_prev_toolview"));
     m_gotoToolDockMenu->insert(new KAction(i18n("Next Tool View"),ALT+CTRL+Key_Right,m_mdiMainFrm,SLOT(nextToolViewInDock()),
 		actionCollection(),"kmdi_next_toolview"));
-    
+
+    actionCollection()->readShortcutSettings( "Shortcuts", kapp->config() );
 }
 
 KMDIGUIClient::~KMDIGUIClient()
 {
 
-    for (int i=0;i<m_toolViewActions.count();i++)
+//     actionCollection()->writeShortcutSettings( "KMDI Shortcuts", kapp->config() );
+    for (uint i=0;i<m_toolViewActions.count();i++)
 	    disconnect(m_toolViewActions.at(i),0,this,0);
 
     m_toolViewActions.setAutoDelete( false );
@@ -166,7 +169,6 @@ KMDIGUIClient::~KMDIGUIClient()
     m_documentViewActions.clear();
 }
 
-
 void KMDIGUIClient::changeViewMode(int id) {
 	switch (id) {
 		case 0:	m_mdiMainFrm->switchToToplevelMode();
@@ -189,7 +191,7 @@ void KMDIGUIClient::setupActions()
 
 //    BarActionBuilder builder( actionCollection(), m_mainWindow, m_toolBars );
 
-//    if ( !builder.needsRebuild() ) 
+//    if ( !builder.needsRebuild() )
 //        return;
 
 
@@ -210,8 +212,8 @@ void KMDIGUIClient::setupActions()
       if (m_toolViewActions.count()<3)
 	for (uint i=0;i<m_toolViewActions.count();i++)
 		addList.append(m_toolViewActions.at(i));
-      else
-        addList.append(m_toolMenu);
+	else
+      addList.append(m_toolMenu);
       if (m_mdiMode==KMdi::IDEAlMode) addList.append(m_gotoToolDockMenu);
       if (m_mdiModeAction) addList.append(m_mdiModeAction);
       kdDebug(760)<<"KMDIGUIClient::setupActions: plugActionList"<<endl;
@@ -222,13 +224,28 @@ void KMDIGUIClient::setupActions()
 
 void KMDIGUIClient::addToolView(KMdiToolViewAccessor* mtva) {
 	kdDebug(760)<<"*****void KMDIGUIClient::addToolView(KMdiToolViewAccessor* mtva)*****"<<endl;
+//	kdDebug()<<"name: "<<mtva->wrappedWidget()->name()<<endl;
+	QString aname = QString("kmdi_toolview_") + mtva->wrappedWidget()->name();
+
+	// try to read the action shortcut
+	KShortcut sc;
+	KConfig *cfg = kapp->config();
+	QString _grp = cfg->group();
+	cfg->setGroup("Shortcuts");
+// 	if ( cfg->hasKey( aname ) )
+		sc = KShortcut( cfg->readEntry( aname, "" ) );
+	cfg->setGroup( _grp );
 	KAction *a=new ToggleToolViewAction(i18n("Show %1").arg(mtva->wrappedWidget()->caption()),
-		QString::null,dynamic_cast<KMdiDockWidget*>(mtva->wrapperWidget()),m_mdiMainFrm,actionCollection(),"nothing");
+		/*QString::null*/sc,dynamic_cast<KDockWidget*>(mtva->wrapperWidget()),
+		m_mdiMainFrm,actionCollection(), aname.latin1() );
+#if KDE_IS_VERSION(3,2,90)
+	((ToggleToolViewAction*)a)->setCheckedState(i18n("Hide %1").arg(mtva->wrappedWidget()->caption()));
+#endif
 	connect(a,SIGNAL(destroyed(QObject*)),this,SLOT(actionDeleted(QObject*)));
 	m_toolViewActions.append(a);
 	m_toolMenu->insert(a);
-
 	mtva->d->action=a;
+
 	setupActions();
 }
 
@@ -238,6 +255,7 @@ void KMDIGUIClient::actionDeleted(QObject* a) {
 	setupActions();
 }
 
+
 void KMDIGUIClient::clientAdded( KXMLGUIClient *client )
 {
     if ( client == this )
@@ -270,3 +288,4 @@ void KMDIGUIClient::mdiModeHasBeenChangedTo(KMdi::MdiMode mode) {
 }
 
 
+// kate: space-indent off;
