@@ -1,5 +1,24 @@
+/***************************************************************************
+ *   Copyright (C) 2004 by ian reinhart geiser                             *
+ *   geiseri@kde.org                                                       *
+ *                                                                         *
+ *   This program is free software; you can redistribute it and/or modify  *
+ *   it under the terms of the GNU General Public License as published by  *
+ *   the Free Software Foundation; either version 2 of the License, or     *
+ *   (at your option) any later version.                                   *
+ *                                                                         *
+ *   This program is distributed in the hope that it will be useful,       *
+ *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
+ *   GNU General Public License for more details.                          *
+ *                                                                         *
+ *   You should have received a copy of the GNU General Public License     *
+ *   along with this program; if not, write to the                         *
+ *   Free Software Foundation, Inc.,                                       *
+ *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
+ ***************************************************************************/
+
 #include "specsupport.h"
-#include "specsupport.moc"
 #include "kdevproject.h"
 #include "kdevmakefrontend.h"
 #include "distpart_widget.h"
@@ -7,12 +26,13 @@
 #include <kdebug.h>
 #include <kfiledialog.h>
 #include <klocale.h>
+#include <kprocess.h>
 #include <qfile.h>
 #include <qdir.h>
 #include <qerrormessage.h>
 #include <qregexp.h>
 #include <qpushbutton.h>
-#include <qvbox.h>
+//#include <qvbox.h>
 #include <qgroupbox.h>
 #include <qtabwidget.h>
 #include <qmessagebox.h>
@@ -37,25 +57,24 @@ QString QRegExp_escape(const QString& str )
 #endif
 }
 
-SpecSupport::SpecSupport(DistpartPart * part) : packageBase(part,"Rpm") {
+SpecSupport::SpecSupport(DistpartPart *part) : packageBase(), m_part(part) {
+	dir = "";
 
-    m_part = part;
-
-    srcPackagePushButton = new QPushButton(i18n("Src Package"),area());
-    buildAllPushButton = new QPushButton(i18n("Src/Binary Packages"),area());
-    exportSPECPushButton = new QPushButton(i18n("Export SPEC File"),area());
-    importSPECPushButton = new QPushButton(i18n("Import SPEC File"),area());
-
-
-
-    connect(buildAllPushButton, SIGNAL(clicked()),
-            this, SLOT(slotbuildAllPushButtonPressed()));
-    connect(exportSPECPushButton, SIGNAL(clicked()),
-            this, SLOT(slotexportSPECPushButtonPressed()));
-    connect(importSPECPushButton, SIGNAL(clicked()),
-            this, SLOT(slotimportSPECPushButtonPressed()));
-    connect(srcPackagePushButton, SIGNAL(clicked()),
-            this, SLOT(slotsrcPackagePushButtonPressed()));
+//     srcPackagePushButton = new QPushButton(i18n("Src Package"),area());
+//     buildAllPushButton = new QPushButton(i18n("Src/Binary Packages"),area());
+//     exportSPECPushButton = new QPushButton(i18n("Export SPEC File"),area());
+//     importSPECPushButton = new QPushButton(i18n("Import SPEC File"),area());
+// 
+// 
+// 
+//     connect(buildAllPushButton, SIGNAL(clicked()),
+//             this, SLOT(slotbuildAllPushButtonPressed()));
+//     connect(exportSPECPushButton, SIGNAL(clicked()),
+//             this, SLOT(slotexportSPECPushButtonPressed()));
+//     connect(importSPECPushButton, SIGNAL(clicked()),
+//             this, SLOT(slotimportSPECPushButtonPressed()));
+//     connect(srcPackagePushButton, SIGNAL(clicked()),
+//             this, SLOT(slotsrcPackagePushButtonPressed()));
 
     parseDotRpmmacros();
 }
@@ -70,13 +89,15 @@ void SpecSupport::slotbuildAllPushButtonPressed() {
     QFile file2(*(map.find("_sourcedir")) + "/" + getAppSource());
     if (!file2.exists()) {
 	if (!file1.exists()) {
-	    QMessageBox::critical(this,i18n("Error"),i18n("You need to create a source archive first!"));
+	    QMessageBox::critical(m_part->widget(),i18n("Error"),i18n("You need to create a source archive first."));
 	    return;
 	}
 	else
-	    m_part->makeFrontend()->queueCommand(dir,"cd " + dir + " && cp " + getAppSource() + " " + *(map.find("_sourcedir")));
+	    m_part->makeFrontend()->queueCommand(dir,"cd " + KProcess::quote(dir) + 
+		" && cp " + KProcess::quote(getAppSource()) + " " + KProcess::quote(*(map.find("_sourcedir"))));
     }
-    m_part->makeFrontend()->queueCommand(dir,"cd " + (((it = map.find("_specdir")) != map.end()) ? (*it) : dir) + " && rpmbuild -ba " + m_part->project()->projectName() + ".spec");
+    m_part->makeFrontend()->queueCommand(dir,"cd " + KProcess::quote((((it = map.find("_specdir")) != map.end()) ? (*it) : dir)) +
+		 " && rpmbuild -ba " + m_part->project()->projectName() + ".spec");
 }
 
 //    QPushButton* exportSPECPushButton;
@@ -88,63 +109,7 @@ void SpecSupport::slotexportSPECPushButtonPressed() {
 
     if(file.open(IO_WriteOnly)) {
         QTextStream stream(&file);
-
-        stream << "# This spec file was generated by KDevelop" << "\n"
-        << "# Please report any problem to KDevelop Team <kdevelop-devel@kdevelop.org>" << "\n"
-        << "# Thanks to Matthias Saou for his explanations on http://freshrpms.net/docs/fight.html\n\n";
-
-        stream << "Name: " << getAppName() << "\n";
-        stream << "Version: " << getAppVersion() << "\n";
-        stream << "Release: " << getAppRevision() << "\n";
-        stream << "Vendor: " << getAppVendor() << "\n";
-        stream << "Copyright: " << getAppLicense() << "\n";
-        stream << "Summary: " << getAppSummary() << "\n";
-        stream << "Group: " << getAppGroup() << "\n";
-        stream << "Packager: " << getAppPackager() << "\n";
-        stream << "BuildRoot: " << "%{_tmppath}/%{name}-root" << "\n";
-        stream << "Source: " << getAppSource() << "\n";
-
-        stream << "\n";
-        stream << "%description\n";
-        stream << getAppDescription()<< "\n";
-
-        stream << "\n";
-        stream << "%prep\n";
-        stream << "%setup\n";
-        stream << "CFLAGS=\"$RPM_OPT_FLAGS\" CXXFLAGS=\"$RPM_OPT_FLAGS\" ./configure \\" << "\n";
-        stream << "--target=" << getAppArch() << "\n";
-
-        stream << "\n";
-        stream << "%build\n";
-        stream << "%configure\n";
-        stream << "make\n";
-
-        stream << "\n";
-        stream << "%install\n";
-        stream << "rm -rf %{buildroot}\n";
-        stream << "%makeinstall\n";
-
-        stream << "\n";
-        stream << "%clean\n";
-        stream << "rm -rf %{buildroot}\n";
-
-        stream << "\n";
-        stream << "%post -p /sbin/ldconfig\n";
-
-        stream << "%postun -p /sbin/ldconfig\n";
-
-        stream << "%files\n";
-        stream << "%defattr(-, root, root)\n";
-        stream << "%doc AUTHORS COPYING ChangeLog NEWS README TODO\n";
-        stream << "%{_bindir}/*\n";
-        stream << "%{_libdir}/*.so.*\n";
-        stream << "%{_datadir}/%{name}\n";
-        stream << "%{_mandir}/man8/*\n";
-
-        stream << "%changelog\n";
-        stream << getAppChangelog() << "\n";
-
-
+	stream << generatePackage();
         file.close();
     } else {
         kdDebug() << "TODO : intercept write error in SpecSupport::slotexportSPECPushButtonPressed()";
@@ -160,7 +125,11 @@ QString SpecSupport::getInfo(QString s, QString motif) {
 
 //    QPushButton* importSPECPushButton;
 void SpecSupport::slotimportSPECPushButtonPressed() {
-    QFile file(KFileDialog::getOpenFileName(dir,"*.spec"));
+       QString fileName = KFileDialog::getOpenFileName(dir,"*.spec");
+       if( fileName.isEmpty())
+               return;
+    QFile file(fileName);
+ 
     if(file.open(IO_ReadOnly)) {
         QTextStream stream(&file);
 
@@ -169,7 +138,7 @@ void SpecSupport::slotimportSPECPushButtonPressed() {
             QString info;
             if (!(info = getInfo(s,"Name:")).isEmpty())
                 setAppName(info);
-            else if (!(info = !getInfo(s,"Version:")).isEmpty())
+            else if (!(info = getInfo(s,"Version:")).isEmpty())
                 setAppVersion(info);
             else if (!(info = getInfo(s,"Release:")).isEmpty())
                 setAppRevision(info);
@@ -213,13 +182,15 @@ void SpecSupport::slotsrcPackagePushButtonPressed() {
     QFile file2(*(map.find("_sourcedir")) + "/" + getAppSource());
     if (!file2.exists()) {
 	if (!file1.exists()) {
-	    QMessageBox::critical(this,i18n("Error"),i18n("You need to create a source archive first!"));
+	    QMessageBox::critical(m_part->widget(),i18n("Error"),i18n("You need to create a source archive first."));
 	    return;
 	}
 	else
-	    m_part->makeFrontend()->queueCommand(dir,"cd " + dir + " && cp " + getAppSource() + " " + *(map.find("_sourcedir")));
+	    m_part->makeFrontend()->queueCommand(dir,"cd " + KProcess::quote(dir) + 
+		" && cp " + KProcess::quote(getAppSource()) + " " + KProcess::quote(*(map.find("_sourcedir"))));
     }
-    m_part->makeFrontend()->queueCommand(dir,"cd " + (((it = map.find("_specdir")) != map.end()) ? (*it) : dir) + " && rpmbuild -bs " + m_part->project()->projectName() + ".spec");
+    m_part->makeFrontend()->queueCommand(dir,"cd " + KProcess::quote((((it = map.find("_specdir")) != map.end()) ? (*it) : dir)) +
+		 " && rpmbuild -bs " + m_part->project()->projectName() + ".spec");
 }
 
 void SpecSupport::parseDotRpmmacros() {
@@ -246,7 +217,7 @@ void SpecSupport::parseDotRpmmacros() {
             QRegExp subst("%\\{([^%]*)\\}");
             QString value = re.cap(2).stripWhiteSpace();
 
-            while(subst.search(value) != -1) {			
+            while(subst.search(value) != -1) {
                 value.replace(QRegExp("%\\{"+ QRegExp_escape( subst.cap(1) ) +"\\}"),*map.find(subst.cap(1)));
             }
             map.insert(re.cap(1),value);
@@ -272,3 +243,65 @@ bool SpecSupport::createRpmDirectoryFromMacro(const QString & name) {
     }
     return false;
 }
+
+QString SpecSupport::generatePackage( )
+{
+	QString spec;
+        spec += "# This spec file was generated by KDevelop \n";
+        spec += "# Please report any problem to KDevelop Team <kdevelop-devel@kdevelop.org> \n";
+        spec += "# Thanks to Matthias Saou for his explanations on http://freshrpms.net/docs/fight.html\n\n";
+
+        spec += "Name: " + getAppName() + "\n";
+        spec += "Version: " + getAppVersion() + "\n";
+        spec += "Release: " + getAppRevision() + "\n";
+        spec += "Vendor: " + getAppVendor() + "\n";
+        spec += "Copyright: " + getAppLicense() + "\n";
+        spec += "Summary: " + getAppSummary() + "\n";
+        spec += "Group: " + getAppGroup() + "\n";
+        spec += "Packager: " + getAppPackager() + "\n";
+        spec += "BuildRoot:  %{_tmppath}/%{name}-root \n";
+        spec += "Source: " + getAppSource() + "\n";
+
+        spec += "\n";
+        spec += "%description\n";
+        spec += getAppDescription()+ "\n";
+
+        spec += "\n";
+        spec += "%prep\n";
+        spec += "%setup\n";
+        spec += "CFLAGS=\"$RPM_OPT_FLAGS\" CXXFLAGS=\"$RPM_OPT_FLAGS\" ./configure \\ \n";
+        spec += "--target=" + getAppArch() + "\n";
+	spec += "--disable-debug --enable-debug=no \n";
+
+        spec += "\n";
+        spec += "%build\n";
+        spec += "%configure\n";
+        spec += "make\n";
+
+        spec += "\n";
+        spec += "%install\n";
+        spec += "rm -rf %{buildroot}\n";
+        spec += "%makeinstall\n";
+
+        spec += "\n";
+        spec += "%clean\n";
+        spec += "rm -rf %{buildroot}\n";
+
+        spec += "\n";
+        spec += "%post -p /sbin/ldconfig\n";
+
+        spec += "%postun -p /sbin/ldconfig\n";
+
+        spec += "%files\n";
+        spec += "%defattr(-, root, root)\n";
+        spec += "%doc AUTHORS COPYING ChangeLog NEWS README TODO\n";
+        spec += "%{_bindir}/*\n";
+        spec += "%{_libdir}/*.so.*\n";
+        spec += "%{_datadir}/%{name}\n";
+        spec += "%{_mandir}/man8/*\n";
+
+        spec += "%changelog\n";
+        spec += getAppChangelog() + "\n";
+	
+	return spec;
+}
