@@ -32,6 +32,8 @@
 #include <kprocess.h>
 #include <kstandarddirs.h>
 #include <kmessagebox.h>
+#include <kstdguiitem.h>
+#include <kdeversion.h>
 
 
 DocSearchDialog::DocSearchDialog(QWidget *parent, const char *name)
@@ -80,8 +82,13 @@ DocSearchDialog::DocSearchDialog(QWidget *parent, const char *name)
 
     KButtonBox *buttonbox = new KButtonBox(this);
     buttonbox->addStretch();
+#if KDE_IS_VERSION( 3, 2, 90 )
+    QPushButton *ok_button = buttonbox->addButton(KStdGuiItem::ok());
+    QPushButton *cancel_button = buttonbox->addButton(KStdGuiItem::cancel());
+#else
     QPushButton *ok_button = buttonbox->addButton(i18n("&OK"));
     QPushButton *cancel_button = buttonbox->addButton(i18n("Cancel"));
+#endif
     ok_button->setDefault(true);
     connect( ok_button, SIGNAL(clicked()), this, SLOT(accept()) );
     connect( cancel_button, SIGNAL(clicked()), this, SLOT(reject()) );
@@ -108,7 +115,7 @@ bool DocSearchDialog::performSearch()
         exe = "/usr/lib/cgi-bin/htsearch";
         QFile f(exe);
         if (!f.exists()) {
-	    KMessageBox::error(this, i18n("Cannot find the htsearch executable!"));
+	    KMessageBox::error(this, i18n("Cannot find the htsearch executable."));
             kdDebug() << "Can not find htsearch" << endl;
             return false;
         }
@@ -120,9 +127,9 @@ bool DocSearchDialog::performSearch()
         if(QFile::exists("/var/lib/kdevelop3/helpindex/htdig.conf")) {
             indexdir = "/var/lib/kdevelop3/helpindex";
         }
-        else if(QFile::exists("/var/lib/kdevelop/helpindex/htdig.conf")) {
+	else if(QFile::exists("/var/lib/kdevelop/helpindex/htdig.conf")) {
             indexdir = "/var/lib/kdevelop/helpindex";
-        } else {
+	} else {
             kdDebug() << "Can not find the htdig configuration file" << endl;
             return false;
         }
@@ -153,7 +160,7 @@ bool DocSearchDialog::performSearch()
     searchResult = "";
 
     if (!proc->start(KProcess::NotifyOnExit, KProcess::Stdout)) {
-        KMessageBox::error(this, i18n("Cannot start the htsearch executable!"));
+        KMessageBox::error(this, i18n("Cannot start the htsearch executable."));
         kdDebug() << "process start failed" << endl;
         delete proc;
         return false;
