@@ -30,14 +30,17 @@ QString message(const QCString &key)
     addMessage("PROJECT_NAME", i18n("Project name"));
     addMessage("PROJECT_NUMBER", i18n("Project version"));
     addMessage("OUTPUT_DIRECTORY", i18n("Output path"));
+    addMessage("CREATE_SUBDIRS", i18n("Distribute the generated docs in 10 subdirectories"));
     addMessage("OUTPUT_LANGUAGE", i18n("Output language"));
     addMessage("USE_WINDOWS_ENCODING", i18n("Use MS Windows(tm) font encoding"));
     addMessage("BRIEF_MEMBER_DESC", i18n("Include brief member descriptions"));
     addMessage("REPEAT_BRIEF", i18n("Repeat brief member descriptions"));
+    addMessage("ABBREVIATE_BRIEF", i18n("Strip words in brief description"));
     addMessage("ALWAYS_DETAILED_SEC", i18n("Always include detailed section"));
     addMessage("INLINE_INHERITED_MEMB", i18n("Inline inherited members"));
     addMessage("FULL_PATH_NAMES", i18n("Always use full path names"));
     addMessage("STRIP_FROM_PATH", i18n("Prefix to strip from path names"));
+    addMessage("STRIP_FROM_INC_PATH", i18n("Strip from include path"));
     addMessage("SHORT_NAMES", i18n("Generate short file names"));
     addMessage("JAVADOC_AUTOBRIEF", i18n("Use JavaDoc-style brief descriptions"));
     addMessage("MULTILINE_CPP_IS_BRIEF", i18n("Multiline cpp is brief"));
@@ -56,8 +59,9 @@ QString message(const QCString &key)
     addMessage("Build", i18n("Build"));
     addMessage("EXTRACT_ALL", i18n("Extract undocumented entities"));
     addMessage("EXTRACT_PRIVATE", i18n("Extract private entities"));
-    addMessage("EXTRACT_STATIC", i18n("Extract static entitites"));
+    addMessage("EXTRACT_STATIC", i18n("Extract static entities"));
     addMessage("EXTRACT_LOCAL_CLASSES", i18n("Extract local classes"));
+    addMessage("EXTRACT_LOCAL_METHODS", i18n("Extract local methods"));
     addMessage("HIDE_UNDOC_MEMBERS", i18n("Hide undocumented members"));
     addMessage("HIDE_UNDOC_CLASSES", i18n("Hide undocumented classes"));
     addMessage("HIDE_FRIEND_COMPOUNDS", i18n("Hide friend compounds"));
@@ -68,6 +72,8 @@ QString message(const QCString &key)
     addMessage("SHOW_INCLUDE_FILES", i18n("Show included files"));
     addMessage("INLINE_INFO", i18n("Make inline functions"));
     addMessage("SORT_MEMBER_DOCS", i18n("Sort member documentation alphabetically"));
+    addMessage("SORT_BY_SCOPE_NAME", i18n("Sort the class list by fully-qualified names"));
+    addMessage("SORT_BRIEF_DOCS", i18n("Sort brief documentation alphabetically"));
     addMessage("ENABLED_SECTIONS", i18n("Enable conditional sections"));
     addMessage("GENERATE_TODOLIST", i18n("Generate TODO-list"));
     addMessage("GENERATE_TESTLIST", i18n("Generate Test-list"));
@@ -82,7 +88,7 @@ QString message(const QCString &key)
     addMessage("Messages", i18n("Messages"));
     addMessage("QUIET", i18n("Suppress output"));
     addMessage("WARNINGS", i18n("Show warnings"));
-    addMessage("WARN_IF_UNDOCUMENTED", i18n("Warn about undocumented entitites"));
+    addMessage("WARN_IF_UNDOCUMENTED", i18n("Warn about undocumented entities"));
     addMessage("WARN_IF_DOC_ERROR", i18n("Warn if error in documents"));
     addMessage("WARN_FORMAT", i18n("Warnings format"));
     addMessage("WARN_LOGFILE", i18n("Write warnings to"));
@@ -190,6 +196,7 @@ QString message(const QCString &key)
     addMessage("XML_OUTPUT", i18n("XML output directory"));
     addMessage("XML_SCHEMA", i18n("XML schema"));
     addMessage("XML_DTD", i18n("XML DTD file"));
+    addMessage("XML_PROGRAMLISTING", i18n("Dump program listings to the XML output"));
 
     //---------------------------------------------------------------------------
     // configuration options for the AutoGen Definitions output
@@ -275,7 +282,7 @@ QString message(const QCString &key)
 
     return key;
   }
-  
+
   return messages[key];
 }
 
