@@ -24,6 +24,8 @@
 #include <kcombobox.h>
 #include <klocale.h>
 #include <kdebug.h>
+#include <kmessagebox.h>
+
 
 namespace FileCreate {
 
@@ -99,7 +101,7 @@ namespace FileCreate {
 
   KURL NewFileChooser::url() const {
 
-    KURL result = m_urlreq->url();
+    KURL result ( m_urlreq->url() );
     result.cd( m_filename->text() );
     return result;
   }
@@ -137,5 +139,22 @@ namespace FileCreate {
     m_filename->setText(name);
   }
 
+  void NewFileChooser::setInProjectMode( bool m )
+  {
+    m_addToProject->setEnabled(m);
+    m_addToProject->setChecked(m);
+  }
+
+	void NewFileChooser::accept()
+	{
+		QFileInfo file( url().path() );
+		if ( file.exists() )
+		{
+			KMessageBox::sorry( 0, i18n("A file with this name already exists."), i18n("File Exists") );
+			return;
+		}
+		KDialogBase::accept();
+	}
 
 }
+
