@@ -25,6 +25,9 @@
 #include <kstdaction.h>
 #include <kaction.h>
 #include <kapplication.h>
+#include <kactionclasses.h>
+#include <kpopupmenu.h>
+#include <kiconloader.h>
 
 #include "kdevcore.h"
 #include "kdevmainwindow.h"
@@ -55,25 +58,28 @@ K_EXPORT_COMPONENT_FACTORY( libkdevfilecreate, FileCreateFactory( &data ) )
 using namespace FileCreate;
 
 FileCreatePart::FileCreatePart(QObject *parent, const char *name, const QStringList & )
-    : KDevCreateFile("FileCreate", "filecreate", parent, name ? name : "FileCreatePart"), m_selectedWidget(-1), m_useSideTab(true)
+    : KDevCreateFile("FileCreate", "wizard", parent, name ? name : "FileCreatePart"), m_selectedWidget(-1), m_useSideTab(true), m_subPopups(0)
 {
   setInstance(FileCreateFactory::instance());
   setXMLFile("kdevpart_filecreate.rc");
 
   connect( core(), SIGNAL(projectOpened()), this, SLOT(slotProjectOpened()) );
+  connect( core(), SIGNAL(projectClosed()), this, SLOT(slotProjectClosed()) );
   
 	_configProxy = new ConfigWidgetProxy( core() );
-	_configProxy->createProjectConfigPage( i18n("New File Wizard"), PROJECTSETTINGSPAGE );
-	_configProxy->createGlobalConfigPage( i18n("New File Wizard"), GLOBALSETTINGSPAGE );
+	_configProxy->createProjectConfigPage( i18n("New File Wizard"), PROJECTSETTINGSPAGE, icon() );
+	_configProxy->createGlobalConfigPage( i18n("New File Wizard"), GLOBALSETTINGSPAGE, icon() );
 	connect( _configProxy, SIGNAL(insertConfigWidget(const KDialogBase*, QWidget*, unsigned int )), 
 		this, SLOT(insertConfigWidget(const KDialogBase*, QWidget*, unsigned int )) );
 
 
-  KAction * newAction = KStdAction::openNew(this, SLOT(slotNewFile()), actionCollection(), "file_new");
+  KToolBarPopupAction * newAction = new KToolBarPopupAction( i18n("&New"), "file_new", CTRL+Qt::Key_N, this, SLOT(slotNewFile()), actionCollection(), "file_new");
   newAction->setWhatsThis( i18n("<b>New file</b><p>Creates a new file. Also adds it the project if the <b>Add to project</b> checkbox is turned on.") );
   newAction->setToolTip( i18n("Create a new file") );
-
-  m_filetypes.setAutoDelete(true);
+  m_newPopupMenu = newAction->popupMenu();
+  connect(m_newPopupMenu, SIGNAL(aboutToShow()), this, SLOT(slotAboutToShowNewPopupMenu()));
+  
+//  m_filetypes.setAutoDelete(true);
 
   m_availableWidgets[0] = new FriendlyWidget(this);
   m_availableWidgets[1] = new ListWidget(this);
@@ -83,11 +89,14 @@ FileCreatePart::FileCreatePart(QObject *parent, const char *name, const QStringL
   /// having to change the source, as this is not considered 'user-friendly'
   /// these days, I'm led to believe.
   selectWidget(1);
+  
+  QTimer::singleShot( 0, this, SLOT(slotGlobalInitialize()) );
 }
 
 
 FileCreatePart::~FileCreatePart()
 {
+/*
   for(int c=0;c<m_numWidgets;c++){
     if (TypeChooser* chooser = m_availableWidgets[c]) {
 
@@ -97,7 +106,11 @@ FileCreatePart::~FileCreatePart()
        delete chooser;
     }
   }
+*/  
   delete _configProxy;
+  
+  m_newPopupMenu->clear();
+  delete m_subPopups;
 }
 
 void FileCreatePart::insertConfigWidget( const KDialogBase * dlg, QWidget * page, unsigned int pagenumber )
@@ -159,6 +172,66 @@ void FileCreatePart::refresh() {
   if (typeChooserWidget()) typeChooserWidget()->refresh();
 }
 
+void FileCreatePart::slotAboutToShowNewPopupMenu()
+{
+	KIconLoader * m_iconLoader = KGlobal::iconLoader();
+	m_newPopupMenu->clear();
+	delete m_subPopups;
+	m_subPopups = NULL;
+	int id = 0;
+	FileType * filetype = m_filetypes.first();
+	for(; filetype; filetype=m_filetypes.next())
+	{
+		if (filetype->enabled())
+		{
+			if (filetype->subtypes().count()==0)
+			{
+				QPixmap iconPix = m_iconLoader->loadIcon(
+					filetype->icon(), KIcon::Desktop, KIcon::SizeSmall,
+					KIcon::DefaultState, NULL, true);
+				m_newPopupMenu->insertItem(iconPix, filetype->name(), this,
+					SLOT(slotNewFilePopup(int)), 0, ++id );
+				m_newPopupMenu->setItemParameter( id, (int)filetype );
+			} else
+			{
+				KPopupMenu* subMenu = NULL;
+				QPtrList<FileType> subtypes = filetype->subtypes();
+				for(FileType * subtype = subtypes.first(); subtype; subtype=subtypes.next())
+				{
+					if (subtype->enabled()){
+						if( !subMenu )
+							subMenu = new KPopupMenu(0,0);
+						QPixmap iconPix = m_iconLoader->loadIcon(
+							subtype->icon(), KIcon::Desktop, KIcon::SizeSmall,
+							KIcon::DefaultState, NULL, true);
+						subMenu->insertItem(iconPix, subtype->name(), this,
+							SLOT(slotNewFilePopup(int)), 0, ++id );
+						subMenu->setItemParameter( id, (int)filetype );
+					}
+				}
+				if( subMenu )
+				{
+					if( !m_subPopups )
+					{
+						m_subPopups = new QPtrList<KPopupMenu>;
+						m_subPopups->setAutoDelete(true);
+					}
+					m_subPopups->append( subMenu );
+					m_newPopupMenu->insertItem( filetype->name(), subMenu );
+				}
+			}
+
+		}
+
+	}
+}
+
+void FileCreatePart::slotNewFilePopup( int pFileType )
+{
+	const FileType* filetype = (const FileType*) pFileType;
+	slotFiletypeSelected( filetype );
+}
+
 void FileCreatePart::slotNewFile() {
   KDevCreateFile::CreatedFile createdFile = createNewFile();
   openCreatedFile(createdFile);
@@ -183,6 +256,7 @@ void FileCreatePart::addFileType(const QString & filename) {
 void FileCreatePart::slotProjectClosed() {
   m_filetypes.clear();
   refresh();
+  QTimer::singleShot( 0, this, SLOT(slotGlobalInitialize()) );
 }
 
 void FileCreatePart::slotFiletypeSelected(const FileType * filetype) {
@@ -192,13 +266,14 @@ void FileCreatePart::slotFiletypeSelected(const FileType * filetype) {
                                                           QString::null,
                                                           filetype->subtypeRef());
 
-  openCreatedFile(createdFile);
+  if (project())
+    openCreatedFile(createdFile);
 
-  mainWindow()->lowerView( typeChooserWidgetAsQWidget() );
+//  mainWindow()->lowerView( typeChooserWidgetAsQWidget() );
 }
 
 void FileCreatePart::openCreatedFile(const KDevCreateFile::CreatedFile & createdFile) {
-  if (createdFile.status == KDevCreateFile::CreatedFile::STATUS_OK) {
+	if (createdFile.status == KDevCreateFile::CreatedFile::STATUS_OK && project() ) {
     KURL uu(project()->projectDirectory() + createdFile.dir + "/" + createdFile.filename );
     partController()->editDocument ( uu );
   }
@@ -309,7 +384,18 @@ FileType * FileCreatePart::getEnabledType(const QString & ex, const QString subt
 KDevCreateFile::CreatedFile FileCreatePart::createNewFile(QString ext, QString dir, QString name, QString subtype)
 {
   KDevCreateFile::CreatedFile result;
-  KURL projectURL( project()->projectDirectory() );
+  
+  KURL projectURL;
+  if ( !project() )
+  {
+    //result.status = KDevCreateFile::CreatedFile::STATUS_NOTCREATED;
+    //return result;
+  }
+  else
+  {
+    projectURL = project()->projectDirectory();
+  }
+
   KURL selectedURL;
 
   NewFileChooser dialog;
@@ -321,9 +407,13 @@ KDevCreateFile::CreatedFile FileCreatePart::createNewFile(QString ext, QString d
   } else {
     kdDebug(9034) << "could not find filetype" << endl;
   }
+  if (!project())
+    dialog.setInProjectMode(false);
 
   if (!dir.isNull())
     dialog.setDirectory(dir);
+  else if (!project())
+    dialog.setDirectory(QDir::currentDirPath());
   else
   {
     QString activeDir = project()->activeDirectory();
@@ -357,69 +447,45 @@ KDevCreateFile::CreatedFile FileCreatePart::createNewFile(QString ext, QString d
     subtype = selectedFileType->subtypeRef();
   }
 
+  QString fullPath = selectedURL.path();
+  // add appropriate extension, if not already there
+  if (!ext.isNull() & ext!="" & !fullPath.endsWith("." + ext)) fullPath+="." + ext;
+
+  QString filename = URLUtil::filename(fullPath);
+  kdDebug(9034) << "full path = " << fullPath << endl;
+
+  // add in subtype, if specified
+  if (!subtype.isEmpty())
+      ext += "-" + subtype;
+
+  // create file from template
+  if (!FileTemplate::exists(this, ext) ||
+      !FileTemplate::copy(this, ext, fullPath) ) {
+      // no template, create a blank file instead
+      QFile f(fullPath);
+      f.open( IO_WriteOnly );
+      f.close();
+  }
   if (dialog.addToProject())
   {
     // work out the path relative to the project directory
-    QString relToProj = URLUtil::relativePath(projectURL, selectedURL, URLUtil::SLASH_PREFIX );
-
-    // add appropriate extension, if not already there
-    if (!ext.isNull() & ext!="" & !relToProj.endsWith("." + ext)) relToProj+="." + ext;
-
-    QString filename = URLUtil::filename(relToProj);
-
-    kdDebug(9034) << "relative to proj dir = " << relToProj << endl;
-    kdDebug(9034) << "filename = " << filename << endl;
-
-    // add in subtype, if specified
-    if (!subtype.isEmpty())
-        ext += "-" + subtype;
-
-    // create file from template, and add it to the project
-    if (!FileTemplate::exists(this, ext) ||
-        !FileTemplate::copy(this, ext, project()->projectDirectory() + relToProj) ) {
-        // no template, create a blank file instead
-        QFile f(project()->projectDirectory() + relToProj);
-        f.open( IO_WriteOnly );
-        f.close();
-    }
-
+//    QString relToProj = URLUtil::relativePath(projectURL, selectedURL, URLUtil::SLASH_PREFIX );
+    QString relToProj = URLUtil::relativePath(projectURL.path(), fullPath, URLUtil::SLASH_PREFIX );
     project()->addFile(relToProj.mid(1));
-
-    // tell the caller what we did
-    result.filename = filename;
-    result.dir = URLUtil::directory(relToProj);
-    result.status = KDevCreateFile::CreatedFile::STATUS_OK;
   }
-  else //this is for non-project files
+  else
   {
-    QString fullPath = selectedURL.path();
-    // add appropriate extension, if not already there
-    if (!ext.isNull() & ext!="" & !fullPath.endsWith("." + ext)) fullPath+="." + ext;
-
-    QString filename = URLUtil::filename(fullPath);
-
-    kdDebug(9034) << "full path = " << fullPath << endl;
-    kdDebug(9034) << "filename = " << filename << endl;
-
-    // add in subtype, if specified
-    if (!subtype.isEmpty())
-        ext += "-" + subtype;
-
-    // create file from template, and add it to the project
-    if (!FileTemplate::exists(this, ext) ||
-        !FileTemplate::copy(this, ext, fullPath) ) {
-        // no template, create a blank file instead
-        QFile f(fullPath);
-        f.open( IO_WriteOnly );
-        f.close();
-    }
     KURL url;
     url.setPath(fullPath);
     partController()->editDocument(url);
-    result.filename = filename;
-    result.dir = URLUtil::directory(fullPath);
-    result.status = KDevCreateFile::CreatedFile::STATUS_OK;
   }
+  
+  QString fileName = URLUtil::filename(fullPath);
+  kdDebug(9034) << "file name = " << filename << endl;
+  
+  result.filename = fileName;
+  result.dir = URLUtil::directory(fullPath);
+  result.status = KDevCreateFile::CreatedFile::STATUS_OK;
 
   return result;
 }
@@ -435,24 +501,11 @@ void FileCreatePart::slotNoteFiletype(const FileType * filetype) {
 
 void FileCreatePart::slotInitialize( )
 {
-  // read in global template information
-  QString globalXMLFile = ::locate("data", "kdevfilecreate/template-info.xml");
-  kdDebug(9034) << "Found global template info info " << globalXMLFile << endl;
-  QDomDocument globalDom;
-  if (!globalXMLFile.isNull() &&
-      DomUtil::openDOMFile(globalDom,globalXMLFile)) {
-    kdDebug(9034) << "Reading global template info..." << endl;
-//    kapp->processEvents();
-    readTypes(globalDom, m_filetypes, false);
-
-    // use side tab or not?
-    /// @todo this is a very Bad Way to do this. Must remember to move this setting to user's kdeveloprc config file
-    QDomElement useSideTab = DomUtil::elementByPath(globalDom,"/kdevfilecreate/sidetab");
-    if (!useSideTab.isNull() && useSideTab.attribute("active")=="no") {
-        m_useSideTab = false;
-    }
-  }
-
+  m_filetypes.clear();
+  refresh();
+  
+  //read global configuration
+  slotGlobalInitialize();
 
   // read in which global templates are to be used for this project
   QDomElement useGlobalTypes =
@@ -489,7 +542,7 @@ void FileCreatePart::slotInitialize( )
   }
 
   // read in the list of file types for this project
-  if ( readTypes( *projectDom(), m_filetypes, true )==0  ) {
+  if ( project() && readTypes( *projectDom(), m_filetypes, true )==0  ) {
     // default by scanning the templates directory if no template info
     // found in project file
     QDir templDir( project()->projectDirectory() + "/templates/" );
@@ -519,4 +572,32 @@ void FileCreatePart::slotInitialize( )
   refresh();
 }
 
+void FileCreatePart::slotGlobalInitialize( )
+{
+  // read in global template information
+  QString globalXMLFile = ::locate("data", "kdevfilecreate/template-info.xml");
+  kdDebug(9034) << "Found global template info info " << globalXMLFile << endl;
+  QDomDocument globalDom;
+  if (!globalXMLFile.isNull() &&
+      DomUtil::openDOMFile(globalDom,globalXMLFile)) {
+    kdDebug(9034) << "Reading global template info..." << endl;
+//    kapp->processEvents();
+    readTypes(globalDom, m_filetypes, false);
+
+    // use side tab or not?
+    /// @todo this is a very Bad Way to do this. Must remember to move this setting to user's kdeveloprc config file
+    QDomElement useSideTab = DomUtil::elementByPath(globalDom,"/kdevfilecreate/sidetab");
+    if (!useSideTab.isNull() && useSideTab.attribute("active")=="no") {
+        m_useSideTab = false;
+
+		setShowSideTab(m_useSideTab); // not the cleanest thing to do.. but c'mon, look at the rest of this code.. ;)
+    }
+  }
+  
+  // refresh view
+  refresh();
+}
+
 #include "filecreate_part.moc"
+
+	// kate: indent-width 4; replace-tabs off; tab-width 4; space-indent off;
