@@ -17,7 +17,7 @@
    Boston, MA 02111-1307, USA.
 */
 
-// $Id: kbookmarkhandler.cpp,v 1.3 2003/12/08 17:10:00 dagerbo Exp $
+// $Id: kbookmarkhandler.cpp,v 1.4 2004/02/22 23:53:43 mueller Exp $
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -72,7 +72,7 @@ void KBookmarkHandler::slotNewBookmark( const QString& text,
                                             const QString& additionalInfo )
 {
     Q_UNUSED( text );
-    *m_importStream << "<bookmark icon=\"" << KMimeType::iconForURL( url );
+    *m_importStream << "<bookmark icon=\"" << KMimeType::iconForURL( KURL(  url ) );
     *m_importStream << "\" href=\"" << QString::fromUtf8(url) << "\">\n";
     *m_importStream << "<title>" << (additionalInfo.isEmpty() ? QString::fromUtf8(url) : additionalInfo) << "</title>\n</bookmark>\n";
 }
