@@ -24,13 +24,14 @@
 class KConfig;
 class KURLRequester;
 class QPushButton;
+class GrepViewPart;
 
 class GrepDialog : public QDialog
 {
     Q_OBJECT
 
 public:
-    GrepDialog(QWidget *parent=0, const char *name=0);
+    GrepDialog( GrepViewPart * part, QWidget *parent=0, const char *name=0 );
     ~GrepDialog();
 
     void setPattern(const QString &pattern)
@@ -50,10 +51,10 @@ public:
 	{ return recursive_box->isChecked(); }
     void show();
 
-#ifdef IGNORE_SCM_DIRS
     bool ignoreSCMDirsFlag() const
         { return ignore_scm_box->isChecked(); }
-#endif
+    bool caseSensitiveFlag() const
+        { return case_sens_box->isChecked(); }
 
 signals:
     void searchClicked();
@@ -62,6 +63,8 @@ private slots:
     void templateActivated(int index);
     void slotSearchClicked();
     void slotPatternChanged( const QString &);
+	void slotSynchDirectory();
+
 private:
     QLineEdit *template_edit;
     QComboBox *pattern_combo, *files_combo;
@@ -69,11 +72,12 @@ private:
     KURLRequester * url_requester;
 
     QCheckBox *recursive_box;
-#ifdef IGNORE_SCM_DIRS
     QCheckBox *ignore_scm_box;
-#endif
+    QCheckBox *case_sens_box;
     KConfig* config;
     QPushButton *search_button;
+	QPushButton *synch_button;
+	GrepViewPart * m_part;
 };
 
 
