@@ -152,8 +152,9 @@ MakeWidget::MakeWidget(MakeViewPart *part)
 	, m_errorFilter( m_continuationFilter )
 	, m_continuationFilter( m_actionFilter )
 	, m_actionFilter( m_otherFilter )
+  , m_pendingItem(0)
 	, m_paragraphs(0)
-    , m_lastErrorSelected(-1)
+  , m_lastErrorSelected(-1)
 	, m_part(part)
 	, m_vertScrolling(false)
 	, m_horizScrolling(false)
@@ -161,6 +162,15 @@ MakeWidget::MakeWidget(MakeViewPart *part)
 {
 	updateSettingsFromConfig();
 
+/*	if ( m_compilerOutputLevel == eFull )
+	{
+		setTextFormat( Qt::LogText );
+	}
+	else
+	{*/
+		setTextFormat( Qt::RichText );
+//	}
+	
 	if ( m_bLineWrapping )
 		setWordWrap(WidgetWidth);
 	setWrapPolicy(Anywhere);
@@ -201,8 +211,8 @@ MakeWidget::MakeWidget(MakeViewPart *part)
 	connect( horizontalScrollBar(), SIGNAL(sliderReleased()),
 	         this, SLOT(horizScrollingOff()) );
 
-	connect( m_part->partController(), SIGNAL(loadedFile(const QString&)),
-	         this, SLOT(slotDocumentOpened(const QString&)) );
+	connect( m_part->partController(), SIGNAL(loadedFile(const KURL&)),
+	         this, SLOT(slotDocumentOpened(const KURL&)) );
 }
 
 MakeWidget::~MakeWidget()
@@ -303,18 +313,30 @@ void MakeWidget::copy()
 
 	QString selection;
 	for(int i = parafrom; i<=parato; i++)
-		selection += text(i) + "\n";
+	   selection += text(i) + "\n";
 
-	selection.remove(0, indexfrom);
-	int removeend = text(parato).length() - indexto;
+   	   
+	if(m_compilerOutputLevel == eShort || 
+	   m_compilerOutputLevel == eVeryShort )
+	{
+	   QRegExp regexp("<.*>");
+	   regexp.setMinimal(true);
+	   selection.remove(regexp);
+	}
+	else
+	{ //FIXME: Selections should be precise in the eShort and eVeryShort modes, too.
+	  selection.remove(0, indexfrom);
+	  int removeend = text(parato).length() - indexto;
 
-	selection.remove((selection.length()-1) - removeend, removeend);
-
-#if QT_VERSION >= 0x030100
+	  selection.remove((selection.length()-1) -  removeend, removeend);	   
+	}		
+	   
+	selection.replace("&lt;","<");
+	selection.replace("&gt;",">");
+	selection.replace("&quot;","\"");
+	selection.replace("&amp;","&");	
+	   
 	kapp->clipboard()->setText(selection, QClipboard::Clipboard);
-#else
-	kapp->clipboard()->setText(selection);
-#endif
 }
 
 void MakeWidget::nextError()
@@ -440,7 +462,8 @@ QString MakeWidget::guessFileName( const QString& fName, int parag ) const
 
     // GNU make resolves symlinks. if "name" is a real path to a file the
     // project know by symlink path, we need to return the symlink path
-    QStringList projectFiles = m_part->project()->allFiles();
+//    QStringList projectFiles = m_part->project()->allFiles();
+    QStringList projectFiles = m_part->project()->symlinkProjectFiles();
     QStringList::iterator it = projectFiles.begin();
     while ( it != projectFiles.end() )
     {
@@ -468,9 +491,9 @@ void MakeWidget::searchItem(int parag)
 			uint line, col;
 			item->m_cursor->position(&line, &col);
 			kdDebug() << "Cursor new position: " << col << endl;
-			m_part->partController()->editDocument(guessFileName(item->fileName, parag), line, col);
+			m_part->partController()->editDocument(KURL( guessFileName(item->fileName, parag) ), line, col);
 		} else {
-			m_part->partController()->editDocument(guessFileName(item->fileName, parag), item->lineNum);
+			m_part->partController()->editDocument(KURL( guessFileName(item->fileName, parag) ), item->lineNum);
 		}
 		m_part->mainWindow()->statusBar()->message( item->m_error, 10000 );
 		m_part->mainWindow()->lowerView(this);
@@ -511,6 +534,7 @@ void MakeWidget::slotProcessExited(KProcess *)
 
 	MakeItem* item = new ExitStatusItem( childproc->normalExit(), childproc->exitStatus() );
 	insertItem( item );
+  displayPendingItem();
 
 	m_part->mainWindow()->statusBar()->message( QString("%1: %2").arg(currentCommand).arg(item->m_text), 3000);
 	m_part->core()->running(m_part, false);
@@ -558,52 +582,70 @@ void MakeWidget::slotExitedDirectory( ExitingDirectoryItem* item )
 	delete dir;
 }
 
+void MakeWidget::displayPendingItem()
+{
+  if (!m_pendingItem) return;
+  // this handles the case of ImmDisplay|Append
+  // We call displayPendingItem once in insertItem
+  // and the appends are handled directly in
+  // appendToLastLine
+  if (!m_items.empty() 
+      && m_items.last() == m_pendingItem) return;
+
+  m_items.push_back(m_pendingItem);
+
+  if ( m_bCompiling && !m_pendingItem->visible( m_compilerOutputLevel ) )
+    return;
+
+  SelectionPreserver preserveSelection( *this, !m_vertScrolling && !m_horizScrolling );
+  m_paragraphToItem.insert( m_paragraphs++, m_pendingItem );
+  append( m_pendingItem->formattedText( m_compilerOutputLevel, brightBg() ) );
+}
+
 bool MakeWidget::appendToLastLine( const QString& text )
 {
-#if QT_VERSION >= 0x030100
-	if ( m_items.count() == 0 )
-#else
-	if ( m_items.size() == 0 )
-#endif
-		return false;
-#if QT_VERSION >= 0x030100
-	MakeItem* item = m_items[m_items.count() - 1];
-#else
-	MakeItem* item = m_items[m_items.size() - 1];
-#endif
-	if ( !item->append( text ) )
+	if ( !m_pendingItem ) return false;
+	if ( !m_pendingItem->append( text ) )
+  {
+    displayPendingItem();
+    m_pendingItem = 0;
 		return false;
+  }
 
-	SelectionPreserver preserveSelection( *this, !m_vertScrolling && !m_horizScrolling );
-
-	removeParagraph( paragraphs() - 1 );
-	append( item->formattedText( m_compilerOutputLevel, brightBg() ) );
-
-
+  int mode = m_pendingItem -> displayMode();
+  if ((mode & MakeItem::Append) && (mode & MakeItem::ImmDisplay))
+  {
+    removeParagraph(paragraphs() - 1);
+    SelectionPreserver preserveSelection( *this, !m_vertScrolling && !m_horizScrolling );
+    append( m_pendingItem->formattedText( m_compilerOutputLevel, brightBg() ) );
+  }
 
 	return true;
 }
 
-void MakeWidget::insertItem( MakeItem* item )
+void MakeWidget::insertItem( MakeItem* new_item )
 {
-	ErrorItem* e = dynamic_cast<ErrorItem*>(item);
+	ErrorItem* e = dynamic_cast<ErrorItem*>(new_item);
 	if (e)
 		createCursor(e, 0L);
 
-	m_items.push_back( item );
+  displayPendingItem();
+  m_pendingItem = new_item;
 
-	if ( m_bCompiling && !item->visible( m_compilerOutputLevel ) )
-		return;
+  if (!new_item) return;
 
-	SelectionPreserver preserveSelection( *this, !m_vertScrolling && !m_horizScrolling );
-
-	m_paragraphToItem.insert( m_paragraphs++, item );
-	append( item->formattedText( m_compilerOutputLevel, brightBg() ) );
+  int mode = new_item -> displayMode();
+  if (mode & MakeItem::ImmDisplay)
+  {
+    displayPendingItem();
+    if (!(mode & MakeItem::Append))
+      m_pendingItem = 0;
+  }
 }
 
-void MakeWidget::slotDocumentOpened( const QString & filename )
+void MakeWidget::slotDocumentOpened( const KURL & filename )
 {
-	KParts::Part* part = m_part->partController()->findOpenDocument(filename);
+	KParts::Part* part = m_part->partController()->partForURL(filename);
 	KTextEditor::Document* doc = dynamic_cast<KTextEditor::Document*>(part);
 
 	if (!doc) {
@@ -618,7 +660,7 @@ void MakeWidget::slotDocumentOpened( const QString & filename )
 
 		if (!e || e->m_cursor) continue;
 
-		if (filename.endsWith(e->fileName))
+		if (filename.path().endsWith(e->fileName))
 			createCursor(e, doc);
 	}
 }
@@ -631,7 +673,7 @@ void MakeWidget::createCursor(ErrorItem* e, KTextEditor::Document* doc)
 	// try to get a KTextEditor::Cursor, so that we can retain position in
 	// a document even when it is edited
 	if (!doc)
-		doc = dynamic_cast<KTextEditor::Document*>(m_part->partController()->findOpenDocument(guessFileName(e->fileName, m_paragraphs + 1)));
+		doc = dynamic_cast<KTextEditor::Document*>(m_part->partController()->partForURL(KURL( guessFileName(e->fileName, m_paragraphs + 1 ))));
 
 	if (doc) {
 		KTextEditor::EditInterface* edit = dynamic_cast<KTextEditor::EditInterface*>(doc);
@@ -731,9 +773,9 @@ void MakeWidget::refill()
 
 }
 
-void MakeWidget::slotVeryShortCompilerOutput() { setCompilerOutputLevel(eVeryShort); }
-void MakeWidget::slotShortCompilerOutput() { setCompilerOutputLevel(eShort); }
-void MakeWidget::slotFullCompilerOutput() { setCompilerOutputLevel(eFull); }
+void MakeWidget::slotVeryShortCompilerOutput() { setTextFormat( Qt::RichText ); setCompilerOutputLevel(eVeryShort); }
+void MakeWidget::slotShortCompilerOutput() { setTextFormat( Qt::RichText ); setCompilerOutputLevel(eShort); }
+void MakeWidget::slotFullCompilerOutput() { setTextFormat( Qt::RichText ); setCompilerOutputLevel(eFull);  }
 
 void MakeWidget::setCompilerOutputLevel(EOutputLevel level)
 {
@@ -768,11 +810,7 @@ void MakeWidget::updateSettingsFromConfig()
 bool MakeWidget::scanErrorForward( int parag )
 {
 	for ( int it = parag + 1;
-#if QT_VERSION >= 0x030100
 	      it < (int)m_items.count();
-#else
-	      it < m_items.size();
-#endif
 	      ++it )
 	{
 		ErrorItem* item = dynamic_cast<ErrorItem*>( m_paragraphToItem[it] );
