@@ -30,6 +30,8 @@ class MakeViewPart;
 class MakeItem;
 class KProcess;
 class ProcessLineMaker;
+class KURL;
+
 namespace KTextEditor { class Document; }
 
 class MakeWidget : public QTextEdit
@@ -72,7 +74,7 @@ private slots:
     void slotEnteredDirectory( EnteringDirectoryItem* );
     void slotExitedDirectory( ExitingDirectoryItem* );
     void insertItem( MakeItem* );
-    void slotDocumentOpened(const QString& filename);
+    void slotDocumentOpened(const KURL& filename);
     void slotDocumentClosed(QObject* doc);
 
 private:
@@ -93,6 +95,8 @@ private:
     MakeActionFilter              m_actionFilter;
     OtherFilter                   m_otherFilter;
 
+    void setPendingItem(MakeItem* new_item);
+    void displayPendingItem();
 	bool appendToLastLine( const QString& text );
 	void setCompilerOutputLevel(EOutputLevel level);
 
@@ -102,6 +106,7 @@ private:
     KProcess *childproc;
     ProcessLineMaker* procLineMaker;
     QPtrStack<QString> dirstack;
+    MakeItem* m_pendingItem;
     QValueVector<MakeItem*> m_items;
     QIntDict<MakeItem> m_paragraphToItem;
     long m_paragraphs;
