@@ -70,8 +70,8 @@ ReplaceWidget::ReplaceWidget(ReplacePart *part)
     _cancel->setEnabled( false );
     _replace->setEnabled( false );
 
-    buttonlayout->addWidget( _cancel );
     buttonlayout->addWidget( _replace );
+    buttonlayout->addWidget( _cancel );
 
     _listview = new ReplaceView( this );
     layout->addWidget( _listview );
@@ -130,7 +130,7 @@ void ReplaceWidget::clear()
 
 void ReplaceWidget::editDocument( QString const & file, int line )
 {
-    m_part->partController()->editDocument( file, line );
+    m_part->partController()->editDocument( KURL( file ), line );
 }
 
 void ReplaceWidget::stopButtonClicked( KDevPlugin * which )
@@ -399,6 +399,11 @@ bool ReplaceWidget::shouldTerminate()
     return b;
 }
 
+void ReplaceWidget::focusInEvent( QFocusEvent * /* e*/ )
+{
+    _listview->setFocus();
+}
+
 //END Helpers
 
 #include "replace_widget.moc"
