@@ -7,13 +7,14 @@
 #include <kmainwindow.h>
 #include <kconfig.h>
 #include <kdeversion.h>
-
+#include <kstandarddirs.h>
+#include <kglobal.h>
 
 #include "toplevel.h"
 #include "partcontroller.h"
 #include "api.h"
 #include "projectmanager.h"
-
+#include "kdevlicense.h"
 
 #include "core.h"
 
@@ -50,24 +51,17 @@ bool Core::queryClose()
   // save the the project to open it automaticly on startup if needed
   KConfig* config = kapp->config();
   config->setGroup("General Options");
-#if defined(KDE_IS_VERSION)
-# if KDE_IS_VERSION(3,1,3)
-#  ifndef _KDE_3_1_3_
-#   define _KDE_3_1_3_
-#  endif
-# endif
-#endif
-#if defined(_KDE_3_1_3_)
   config->writePathEntry("Last Project",ProjectManager::getInstance()->projectFile().url());
-#else
-  config->writeEntry("Last Project",ProjectManager::getInstance()->projectFile().url());
-#endif
-
-  if ( ProjectManager::getInstance()->projectLoaded()
-   && !ProjectManager::getInstance()->closeProject() )
+  
+  if ( !PartController::getInstance()->querySaveFiles() )
+	  return false;
+  
+  if ( !ProjectManager::getInstance()->closeProject( true ) )
       return false;
+  
   if ( !PartController::getInstance()->readyToClose() )
       return false;
+  
   return true;
 }
 
@@ -86,7 +80,31 @@ void Core::fillContextMenu(QPopupMenu *popup, const Context *context)
 
 void Core::openProject(const QString& projectFileName)
 {
-  ProjectManager::getInstance()->loadProject(projectFileName);
+  ProjectManager::getInstance()->loadProject(KURL( projectFileName ));
+}
+
+QDict< KDevLicense > Core::licenses()
+{
+	return m_licenses;
+}
+
+void Core::loadLicenses()
+{
+	// kdDebug(9010) << "======================== Entering loadLicenses" << endl;
+	KStandardDirs* dirs = KGlobal::dirs();
+	dirs->addResourceType( "licenses", KStandardDirs::kde_default( "data" ) + "kdevelop/licenses/" );
+	QStringList licNames = dirs->findAllResources( "licenses", QString::null, false, true );
+	
+	QStringList::Iterator it;
+	for (it = licNames.begin(); it != licNames.end(); ++it)
+	{
+		QString licPath( dirs->findResource( "licenses", *it ) );
+		// kdDebug(9000) << "Loading license file: " << licPath << endl;
+		QString licName = licPath.mid( licPath.findRev('/') + 1 );
+		KDevLicense* lic = new KDevLicense( licName, licPath );
+		m_licenses.insert( licName, lic );
+	}
+	// kdDebug(9000) << "======================== Done loadLicenses" << endl;
 }
 
 namespace MainWindowUtils{
