@@ -11,11 +11,11 @@
 
 #include <qfileinfo.h>
 
+#include "splashscreen.h"
 #include "toplevel.h"
 #include "plugincontroller.h"
 #include "partcontroller.h"
 #include "core.h"
-#include "splashscreen.h"
 #include "projectmanager.h"
 
 static KCmdLineOptions options[] =
@@ -27,11 +27,11 @@ static KCmdLineOptions options[] =
 
 int main(int argc, char *argv[])
 {
-  static const char description[] = I18N_NOOP("The KDevelop Integrated Development Environment.");
+  static const char description[] = I18N_NOOP("The KDevelop Integrated Development Environment");
   KAboutData aboutData("kdevelop", I18N_NOOP("KDevelop"),
                        VERSION, description, KAboutData::License_GPL,
                        I18N_NOOP("(c) 1999-2004, The KDevelop developers"), "", "http://www.kdevelop.org");
-  aboutData.addAuthor("Alexander Dymo", I18N_NOOP("Release coordinator, Overall improvements, Pascal support, C++ support, New File and Documentation parts"), "cloudtemple@mksat.net");
+  aboutData.addAuthor("Alexander Dymo", I18N_NOOP("Release coordinator, Overall improvements, Pascal support, C++ support, New File and Documentation parts"), "adymo@mksat.net");
   aboutData.addAuthor("Amilcar do Carmo Lucas", I18N_NOOP("Release coordinator, API documentation, Doxygen and autoproject patches"), "amilcar@ida.ing.tu-bs.de");
   aboutData.addAuthor("Bernd Gehrmann", I18N_NOOP("Initial idea, basic architecture, much initial source code"), "bernd@kdevelop.org");
   aboutData.addAuthor("Caleb Tennis", I18N_NOOP("KTabBar, bugfixes"), "caleb@aei-tech.com");
@@ -49,7 +49,7 @@ int main(int argc, char *argv[])
   aboutData.addAuthor("Jakob Simon-Gaarde", I18N_NOOP("QMake projectmanager"), "jsgaarde@tdcspace.dk");
   aboutData.addAuthor("F@lk Brettschneider", I18N_NOOP("MDI modes, QEditor, bugfixes"), "falkbr@kdevelop.org");
   aboutData.addAuthor("Mario Scalas", I18N_NOOP("PartExplorer, redesign of CvsPart, patches, bugs(fixes)"), "mario.scalas@libero.it");
-  aboutData.addAuthor("Jens Dagerbo", I18N_NOOP("Replace plugin, Bookmarks plugin, Overall improvements and patches"), "jens.dagerbo@swipnet.se");
+  aboutData.addAuthor("Jens Dagerbo", I18N_NOOP("Replace, Bookmarks, FileList and CTags2 plugins. Overall improvements and patches"), "jens.dagerbo@swipnet.se");
   aboutData.addAuthor("Julian Rockey", I18N_NOOP("Filecreate part and other bits and patches"), "linux@jrockey.com");
   aboutData.addCredit("Ajay Guleria", I18N_NOOP("ClearCase support"), "ajay_guleria@yahoo.com");
   aboutData.addCredit("Marek Janukowicz", I18N_NOOP("Ruby support"), "child@t17.ds.pwr.wroc.pl");
@@ -68,9 +68,10 @@ int main(int argc, char *argv[])
   aboutData.addCredit("Luc Willems", I18N_NOOP("Help with Perl support"), "Willems.luc@pandora.be");
   aboutData.addCredit("Marcel Turino", I18N_NOOP("Documentation index view"), "M.Turino@gmx.de");
   aboutData.addCredit("Yann Hodique", I18N_NOOP("Patches"), "Yann.Hodique@lifl.fr");
-  aboutData.addCredit("Tobias Gl\303\244\303\237er" , I18N_NOOP("QMake projectmanager patches"), "tobi.web@gmx.de");
+  aboutData.addCredit("Tobias Gl\303\244\303\237er" , I18N_NOOP("Documentation Finder,  qmake projectmanager patches, usability improvements, bugfixes ... "), "tobi.web@gmx.de");
   aboutData.addCredit("Andreas Koepfle" , I18N_NOOP("QMake project manager patches"), "koepfle@ti.uni-mannheim.de");
   aboutData.addCredit("Sascha Cunz" , I18N_NOOP("Cleanup and bugfixes for qEditor, AutoMake and much other stuff"), "mail@sacu.de");
+  aboutData.addCredit("Robert Gruber" , I18N_NOOP("SnippetPart, debugger and usability patches"), "rgruber@users.sourceforge.net");
 
   KCmdLineArgs::init(argc, argv, &aboutData);
   KCmdLineArgs::addCmdLineOptions( options );
@@ -78,25 +79,28 @@ int main(int argc, char *argv[])
 
   KApplication app;
 
-  SplashScreen *splash = new SplashScreen;
-
+  TopLevel::mode = TopLevel::IDEMode;
+ 
+  QPixmap pm;
+  pm.load(locate("appdata", "pics/kdevelop-splash.png"));
+  SplashScreen * splash = new SplashScreen( pm );
+  
   app.processEvents();
 
-  QObject::connect(PluginController::getInstance(), SIGNAL(loadingPlugin(const QString &)),
-		   splash, SLOT(showMessage(const QString &)));
-
-  splash->showMessage( i18n( "Loading Settings" ) );
+  splash->message( i18n( "Loading Settings" ) );
   TopLevel::getInstance()->loadSettings();
 
-  PluginController::getInstance()->loadInitialPlugins();
-
-  splash->showMessage( i18n( "Starting GUI" ) );
+  splash->message( i18n( "Starting GUI" ) );
   TopLevel::getInstance()->main()->show();
 
+  QObject::connect(PluginController::getInstance(), SIGNAL(loadingPlugin(const QString &)), 
+    splash, SLOT(message(const QString &)));
+  splash->show();
+  
+  PluginController::getInstance()->loadInitialPlugins();
+  
   Core::getInstance()->doEmitCoreInitialized();
 
-  splash->showMessage( i18n( "Loading Project" ) );
-
   delete splash;
 
   for( int i=0; i<args->count(); ++i ){
