@@ -37,27 +37,26 @@
 #include <kbugreport.h>
 #include <kurlrequester.h>
 #include <kpopupmenu.h>
+#include <kiconloader.h>
 
 #include <ktexteditor/document.h>
 #include <ktexteditor/view.h>
 #include <ktexteditor/configinterface.h>
 #include <kparts/partmanager.h>
-#include <kdevpartcontroller.h>
 #include <kdeversion.h>
 #include <kdebug.h>
-#include "partcontroller.h"
-
-#if (KDE_VERSION > 305)
 #include <knotifydialog.h>
-#endif
+
 
 #include <config.h>
 
+#include "partcontroller.h"
 #include "projectmanager.h"
 #include "core.h"
 #include "settingswidget.h"
 #include "api.h"
 #include "kdevmakefrontend.h"
+#include "toplevel.h"
 
 #include "mainwindowshare.h"
 
@@ -94,7 +93,7 @@ void MainWindowShare::init()
 
 void MainWindowShare::slotActionStatusText( const QString &text )
 {
-    kdDebug(9000) << "MainWindowShare::slotActionStatusText() - " << text << endl;
+//    kdDebug(9000) << "MainWindowShare::slotActionStatusText() - " << text << endl;
 
     if ( ! m_pMainWnd ) return;
 
@@ -145,43 +144,17 @@ void MainWindowShare::createActions()
   action->setToolTip(beautifyToolTip(action->text()));
   action->setWhatsThis(QString("<b>%1</b><p>%2").arg(beautifyToolTip(action->text())).arg(i18n("Lets you configure toolbars.")));
 
-#if (KDE_VERSION > 305)
-
   action = KStdAction::configureNotifications(
                 this, SLOT(slotConfigureNotifications()),
                 m_pMainWnd->actionCollection(), "settings_configure_notifications" );
   action->setToolTip(beautifyToolTip(action->text()));
   action->setWhatsThis(QString("<b>%1</b><p>%2").arg(beautifyToolTip(action->text())).arg(i18n("Lets you configure system notifications.")));
-#endif
 
   action = KStdAction::preferences(this, SLOT(slotSettings()),
                 m_pMainWnd->actionCollection(), "settings_configure" );
   action->setToolTip(beautifyToolTip(action->text()));
   action->setWhatsThis(QString("<b>%1</b><p>%2").arg(beautifyToolTip(action->text())).arg(i18n("Lets you customize KDevelop.")));
 
-
-#if (KDE_VERSION <= 305)
-  m_toggleMainToolbar = KStdAction::showToolbar(this, SLOT(slotToggleMainToolbar()), m_pMainWnd->actionCollection(), "settings_main_toolbar");
-  m_toggleMainToolbar->setText(i18n("Show &Main Toolbar"));
-  m_toggleMainToolbar->setToolTip( i18n("Show Main Toolbar") );
-  m_toggleMainToolbar->setWhatsThis(i18n("<b>Show Main Toolbar</b><p>Hides or shows the main toolbar."));
-
-  m_toggleBuildToolbar = KStdAction::showToolbar(this, SLOT(slotToggleBuildToolbar()),m_pMainWnd->actionCollection(), "settings_build_toolbar");
-  m_toggleBuildToolbar->setText(i18n("Show &Build Toolbar"));
-  m_toggleBuildToolbar->setToolTip( i18n("Show Build Toolbar") );
-  m_toggleBuildToolbar->setWhatsThis(i18n("<b>Show Build Toolbar</b><p>Hides or shows the build toolbar."));
-
-  m_toggleViewToolbar = KStdAction::showToolbar(this, SLOT(slotToggleViewToolbar()),m_pMainWnd->actionCollection(), "settings_view_toolbar");
-  m_toggleViewToolbar->setText(i18n("Show &View Toolbar"));
-  m_toggleViewToolbar->setToolTip( i18n("Show View Toolbar") );
-  m_toggleViewToolbar->setWhatsThis(i18n("<b>Show View Toolbar</b><p>Hides or shows the view toolbar."));
-
-  m_toggleBrowserToolbar = KStdAction::showToolbar(this, SLOT(slotToggleBrowserToolbar()),m_pMainWnd->actionCollection(), "settings_browser_toolbar");
-  m_toggleBrowserToolbar->setText(i18n("Show &Browser Toolbar"));
-  m_toggleBrowserToolbar->setToolTip( i18n("Show Browser Toolbar") );
-  m_toggleBrowserToolbar->setWhatsThis(i18n("<b>Show Browser Toolbar</b><p>Hides or shows the browser toolbar."));
-#endif
-
   m_toggleStatusbar = KStdAction::showToolbar(this, SLOT(slotToggleStatusbar()),m_pMainWnd->actionCollection(), "settings_statusbar");
   m_toggleStatusbar->setText(i18n("Show &Statusbar"));
   m_toggleStatusbar->setToolTip( i18n("Show statusbar") );
@@ -318,38 +291,42 @@ void MainWindowShare::slotShowMenuBar()
 
 void MainWindowShare::slotConfigureNotifications()
 {
-#if (KDE_VERSION > 305)
     KNotifyDialog::configure(m_pMainWnd, "Notification Configuration Dialog");
-#endif
 }
 
 void MainWindowShare::slotSettings()
 {
-    KDialogBase dlg(KDialogBase::TreeList, i18n("Configure KDevelop"),
-                    KDialogBase::Ok|KDialogBase::Cancel, KDialogBase::Ok, m_pMainWnd,
+    KDialogBase dlg(KDialogBase::IconList, i18n("Configure KDevelop"),
+                    KDialogBase::Help|KDialogBase::Ok|KDialogBase::Cancel, KDialogBase::Ok, m_pMainWnd,
                     "customization dialog");
 
-    QVBox *vbox = dlg.addVBoxPage(i18n("General"));
-    SettingsWidget *gsw = new SettingsWidget(vbox, "general settings widget");
-
-    gsw->projects_url->setMode((int)KFile::Directory);
-
+    SettingsWidget *gsw;
     KConfig* config = kapp->config();
-    config->setGroup("General Options");
-    gsw->lastProjectCheckbox->setChecked(config->readBoolEntry("Read Last Project On Startup",true));
-    config->setGroup("MakeOutputView");
-    gsw->setMessageFont(config->readFontEntry("Messages Font"));
-    gsw->lineWrappingCheckBox->setChecked(config->readBoolEntry("LineWrapping",true));
-    gsw->dirNavigMsgCheckBox->setChecked(config->readBoolEntry("ShowDirNavigMsg",false));
-    gsw->compilerOutputButtonGroup->setRadioButtonExclusive(true);
-    gsw->compilerOutputButtonGroup->setButton(config->readNumEntry("CompilerOutputLevel",0));
-    config->setGroup("General Options");
-    gsw->setApplicationFont(config->readFontEntry("Application Font"));
-    gsw->changeMessageFontButton->setText(gsw->messageFont().family());
-    gsw->changeMessageFontButton->setFont(gsw->messageFont());
-    gsw->changeApplicationFontButton->setText(gsw->applicationFont().family());
-    gsw->changeApplicationFontButton->setFont(gsw->applicationFont());
-    gsw->projects_url->setURL(config->readPathEntry("DefaultProjectsDir", QDir::homeDirPath()+"/"));
+    if (TopLevel::mode != TopLevel::AssistantMode)
+    {
+        dlg.setHelp("setup");
+        QVBox *vbox = dlg.addVBoxPage(i18n("General"), i18n("General"), DesktopIcon("kdevelop") );
+        gsw = new SettingsWidget(vbox, "general settings widget");
+
+        gsw->projects_url->setMode((int)KFile::Directory);
+
+        config->setGroup("General Options");
+        gsw->lastProjectCheckbox->setChecked(config->readBoolEntry("Read Last Project On Startup",true));
+        config->setGroup("MakeOutputView");
+        gsw->setMessageFont(config->readFontEntry("Messages Font"));
+        gsw->lineWrappingCheckBox->setChecked(config->readBoolEntry("LineWrapping",true));
+        gsw->dirNavigMsgCheckBox->setChecked(config->readBoolEntry("ShowDirNavigMsg",false));
+        gsw->compilerOutputButtonGroup->setRadioButtonExclusive(true);
+        gsw->compilerOutputButtonGroup->setButton(config->readNumEntry("CompilerOutputLevel",0));
+        config->setGroup("General Options");
+        gsw->setApplicationFont(config->readFontEntry("Application Font"));
+        gsw->changeMessageFontButton->setText(gsw->messageFont().family());
+        gsw->changeMessageFontButton->setFont(gsw->messageFont());
+        gsw->changeApplicationFontButton->setText(gsw->applicationFont().family());
+        gsw->changeApplicationFontButton->setFont(gsw->applicationFont());
+        gsw->projects_url->setURL(config->readPathEntry("DefaultProjectsDir", QDir::homeDirPath()+"/"));
+        gsw->embedDesignerCheckBox->setChecked(config->readBoolEntry("Embed KDevDesigner", true));
+    }
 
     config->setGroup("Global Settings Dialog");
     int height = config->readNumEntry( "Height", 600 );
@@ -364,30 +341,23 @@ void MainWindowShare::slotSettings()
     config->writeEntry( "Height", dlg.size().height() );
     config->writeEntry( "Width", dlg.size().width() );
 
-    config->setGroup("General Options");
-    config->writeEntry("Read Last Project On Startup",gsw->lastProjectCheckbox->isChecked());
-#if defined(KDE_IS_VERSION)
-# if KDE_IS_VERSION(3,1,3)
-#  ifndef _KDE_3_1_3_
-#   define _KDE_3_1_3_
-#  endif
-# endif
-#endif
-#if defined(_KDE_3_1_3_)
-    config->writePathEntry("DefaultProjectsDir", gsw->projects_url->url());
-#else
-    config->writeEntry("DefaultProjectsDir", gsw->projects_url->url());
-#endif
-    config->writeEntry("Application Font", gsw->applicationFont());
-    config->setGroup("MakeOutputView");
-    config->writeEntry("Messages Font",gsw->messageFont());
-    config->writeEntry("LineWrapping",gsw->lineWrappingCheckBox->isChecked());
-    config->writeEntry("ShowDirNavigMsg",gsw->dirNavigMsgCheckBox->isChecked());
-    QButton* pSelButton = gsw->compilerOutputButtonGroup->selected();
-    config->writeEntry("CompilerOutputLevel",gsw->compilerOutputButtonGroup->id(pSelButton)); // id must be in sync with the enum!
-    config->sync();
-    if( API::getInstance()->makeFrontend() )
-        API::getInstance()->makeFrontend()->updateSettingsFromConfig();
+    if (TopLevel::mode != TopLevel::AssistantMode)
+    {
+        config->setGroup("General Options");
+        config->writeEntry("Embed KDevDesigner", gsw->embedDesignerCheckBox->isChecked());
+        config->writeEntry("Read Last Project On Startup",gsw->lastProjectCheckbox->isChecked());
+        config->writePathEntry("DefaultProjectsDir", gsw->projects_url->url());
+        config->writeEntry("Application Font", gsw->applicationFont());
+        config->setGroup("MakeOutputView");
+        config->writeEntry("Messages Font",gsw->messageFont());
+        config->writeEntry("LineWrapping",gsw->lineWrappingCheckBox->isChecked());
+        config->writeEntry("ShowDirNavigMsg",gsw->dirNavigMsgCheckBox->isChecked());
+        QButton* pSelButton = gsw->compilerOutputButtonGroup->selected();
+        config->writeEntry("CompilerOutputLevel",gsw->compilerOutputButtonGroup->id(pSelButton)); // id must be in sync with the enum!
+        config->sync();
+        if( API::getInstance()->makeFrontend() )
+            API::getInstance()->makeFrontend()->updateSettingsFromConfig();
+    }
 }
 
 void MainWindowShare::slotConfigureEditors()
@@ -447,6 +417,20 @@ void MainWindowShare::slotGUICreated( KParts::Part * part )
         kdDebug(9000) << " *** found \"set_confdlg\" action - unplugging" << endl;
         action->unplugAll();
     }
+	
+	if ( KAction * action = part->action("file_save") )
+	{
+		kdDebug(9000) << " *** found \"file_save\" action - disconnecting" << endl;
+		disconnect( action, SIGNAL(activated()), 0, 0 );
+		connect( action, SIGNAL(activated()), PartController::getInstance(), SLOT(slotSave()) );
+	}
+
+	if ( KAction * action = part->action("file_reload") )
+	{
+		kdDebug(9000) << " *** found \"file_reload\" action - disconnecting" << endl;
+		disconnect( action, SIGNAL(activated()), 0, 0 );
+		connect( action, SIGNAL(activated()), PartController::getInstance(), SLOT(slotReload()) );
+	}
 }
 
 // called when OK ar Apply is clicked in the EditToolbar Dialog
@@ -456,7 +440,7 @@ void MainWindowShare::slotNewToolbarConfig()
 
   m_pMainWnd->applyMainWindowSettings( KGlobal::config(), "Mainwindow" );
 
-  PartController::getInstance()->reinstallPopups();
+//   PartController::getInstance()->reinstallPopups();
 }
 
 void MainWindowShare::slotKeyBindings()
