@@ -5,6 +5,7 @@
 #include <qptrlist.h>
 #include <qvbox.h>
 #include <qsize.h>
+#include <qtimer.h>
 
 class QDomDocument;
 
@@ -24,6 +25,9 @@ class QDomDocument;
 #include <kstandarddirs.h>
 #include <kio/netaccess.h>
 #include <ktempfile.h>
+#include <kmenubar.h>
+#include <kstatusbar.h>
+#include <kiconloader.h>
 
 #include "kdevproject.h"
 #include "kdevlanguagesupport.h"
@@ -45,19 +49,6 @@ class QDomDocument;
 
 #include "projectmanager.h"
 
-
-class ProjectInfo
-{
-public:
-  KURL         m_projectURL;
-  QDomDocument m_document;
-  QString      m_projectPlugin, m_language, m_activeLanguage;
-  QStringList  m_ignoreParts, m_loadParts, m_keywords, m_secondaryLanguages;
-  QDict<KDevPlugin> m_localParts;
-
-  QString sessionFile() const;
-};
-
 QString ProjectInfo::sessionFile() const
 {
     QString sf = m_projectURL.path(-1);
@@ -106,7 +97,7 @@ void ProjectManager::createActions( KActionCollection* ac )
   action->setWhatsThis(i18n("<b>Open project</b><p>Opens a KDevelop3 or KDevelop2 project."));
 
   m_openRecentProjectAction =
-    new KRecentFilesAction(i18n("Open &Recent Project..."), 0,
+    new KRecentFilesAction(i18n("Open &Recent Project"), 0,
                           this, SLOT(loadProject(const KURL &)),
                           ac, "project_open_recent");
   m_openRecentProjectAction->setToolTip(i18n("Open recent project"));
@@ -137,7 +128,9 @@ void ProjectManager::createActions( KActionCollection* ac )
 
 void ProjectManager::slotOpenProject()
 {
-  QString defaultProjectsDir = kapp->config()->readPathEntry("DefaultProjectsDir", QDir::homeDirPath()+"/");
+	KConfig *config = kapp->config();
+	config->setGroup("General Options");
+	QString defaultProjectsDir = config->readPathEntry("DefaultProjectsDir", QDir::homeDirPath()+"/");
 
   KURL url = KFileDialog::getOpenURL(defaultProjectsDir,
 		i18n("*.kdevelop|KDevelop 3 Project Files\n"
@@ -155,15 +148,15 @@ void ProjectManager::slotOpenProject()
 
 void ProjectManager::slotProjectOptions()
 {
-  KDialogBase dlg(KDialogBase::TreeList, i18n("Project Options"),
+	KDialogBase dlg(KDialogBase::IconList, i18n("Project Options"),
                   KDialogBase::Ok|KDialogBase::Cancel, KDialogBase::Ok, TopLevel::getInstance()->main(),
                   "project options dialog");
 
-    QVBox *box = dlg.addVBoxPage(i18n("General"));
+	QVBox *box = dlg.addVBoxPage( i18n("General"), i18n("General"), DesktopIcon("kdevelop") );
     GeneralInfoWidget *g = new GeneralInfoWidget(*API::getInstance()->projectDom(), box, "general informations widget");
     connect (&dlg, SIGNAL(okClicked()), g, SLOT(accept()));
 
-  QVBox *vbox = dlg.addVBoxPage(i18n("Plugins"));
+  QVBox *vbox = dlg.addVBoxPage( i18n("Plugins"), i18n("Plugins"), DesktopIcon("kdf") );
   PartSelectWidget *w = new PartSelectWidget(*API::getInstance()->projectDom(), vbox, "part selection widget");
   vbox = dlg.addVBoxPage(i18n("Languages"));
   LanguageSelectWidget *lw = new LanguageSelectWidget(*API::getInstance()->projectDom(), vbox, "language selection widget");
@@ -176,14 +169,14 @@ void ProjectManager::slotProjectOptions()
   config->setGroup("Project Settings Dialog");
   int height = config->readNumEntry( "Height", 600 );
   int width = config->readNumEntry( "Width", 800 );
-  
+
   dlg.resize( width, height );
-  
+
   Core::getInstance()->doEmitProjectConfigWidget(&dlg);
   dlg.exec();
 
   saveProjectFile();
-  
+
   config->setGroup("Project Settings Dialog");
   config->writeEntry( "Height", dlg.size().height() );
   config->writeEntry( "Width", dlg.size().width() );
@@ -204,7 +197,8 @@ void ProjectManager::switchLanguage(const QString& lang)
   // make sure there is a project loaded
   if ( !m_info ) return;
 
-  unloadLocalParts();
+//  PluginController::getInstance()->unloadAllLocalParts();
+  PluginController::getInstance()->unloadPlugins( m_info->m_loadParts );
   unloadLanguageSupport();
   m_info->m_loadParts.clear();
   loadLanguageSupport(lang);
@@ -223,18 +217,7 @@ void ProjectManager::saveSettings()
   if (projectLoaded())
   {
     config->setGroup("General Options");
-#if defined(KDE_IS_VERSION)
-# if KDE_IS_VERSION(3,1,3)
-#  ifndef _KDE_3_1_3_
-#   define _KDE_3_1_3_
-#  endif
-# endif
-#endif
-#if defined(_KDE_3_1_3_)
     config->writePathEntry("Last Project", ProjectManager::getInstance()->projectFile().url());
-#else
-    config->writeEntry("Last Project", ProjectManager::getInstance()->projectFile().url());
-#endif
   }
 
   m_openRecentProjectAction->saveEntries(config, "RecentProjects");
@@ -250,74 +233,84 @@ void ProjectManager::loadDefaultProject()
   {
       loadProject(KURL(project));
   }
-  kapp->processEvents();
 }
 
 bool ProjectManager::loadProject(const KURL &url)
 {
-  if (url.isMalformed())
+  if (!url.isValid())
     return false;
 
   // reopen the already opened project?
   if( url.path() == projectFile().path() )
   {
     if (KMessageBox::questionYesNo(TopLevel::getInstance()->main(),
-        i18n("Are you sure you want to reload the current project?")) == KMessageBox::No)
+        i18n("Are you sure you want to reopen the current project?")) == KMessageBox::No)
       return false;
   }
 
+  TopLevel::getInstance()->main()->menuBar()->setEnabled( false );
+  kapp->setOverrideCursor( waitCursor );
+
   if( projectLoaded() && !closeProject() )
   {
-    m_openRecentProjectAction->setCurrentItem( -1 );
-    return false;
+	m_openRecentProjectAction->setCurrentItem( -1 );
+	TopLevel::getInstance()->main()->menuBar()->setEnabled( true );
+	kapp->restoreOverrideCursor();
+	return false;
   }
 
   m_info = new ProjectInfo;
   m_info->m_projectURL = url;
 
+  QTimer::singleShot( 0, this, SLOT(slotLoadProject()) );
+
+  // no one cares about this value
+  return true;
+}
+
+void ProjectManager::slotLoadProject( )
+{
   if( !loadProjectFile() )
   {
+    m_openRecentProjectAction->removeURL(m_info->m_projectURL);
     delete m_info; m_info = 0;
-    m_openRecentProjectAction->removeURL(url);
     saveSettings();
-    return false;
+	TopLevel::getInstance()->main()->menuBar()->setEnabled( true );
+	kapp->restoreOverrideCursor();
+    return;
   }
 
   getGeneralInfo();
 
   updateActiveLangMenu();
-  loadCreateFileSupport();
 
   if( !loadLanguageSupport(m_info->m_language) ) {
-    unloadCreateFileSupport();
     delete m_info; m_info = 0;
-    return false;
+	TopLevel::getInstance()->main()->menuBar()->setEnabled( true );
+	kapp->restoreOverrideCursor();
+    return;
   }
 
   if( !loadProjectPart() ) {
-    unloadCreateFileSupport();
     unloadLanguageSupport();
     delete m_info; m_info = 0;
-    return false;
-}
+	TopLevel::getInstance()->main()->menuBar()->setEnabled( true );
+	kapp->restoreOverrideCursor();
+    return;
+  }
 
+  TopLevel::getInstance()->statusBar()->message( i18n("Loading project plugins...") );
   loadLocalParts();
 
-//  Core::getInstance()->doEmitProjectOpened();
-
   // shall we try to load a session file from network?? Probably not.
-  if (m_info->m_projectURL.isLocalFile()) {
-    const QDict<KDevPlugin>& globalParts = PluginController::getInstance()->globalParts();
-    QDict<KDevPlugin> allParts = m_info->m_localParts;
-    QDictIterator<KDevPlugin> it(globalParts);
-    for (; it.current(); ++it) {
-      allParts.insert(it.currentKey(), it.current());
-    }
-    // first restore the project session stored in a .kdevses file
-    if (!m_pProjectSession->restoreFromFile(m_info->sessionFile(), allParts)) {
-      kdWarning() << i18n("error during restoring of the KDevelop session !") << endl;
-    }
-  }
+	if (m_info->m_projectURL.isLocalFile())
+	{
+		// first restore the project session stored in a .kdevses file
+		if (!m_pProjectSession->restoreFromFile(m_info->sessionFile(), PluginController::getInstance()->loadedPlugins() ))
+		{
+			kdWarning() << i18n("error during restoring of the KDevelop session !") << endl;
+		}
+	}
 
   m_openRecentProjectAction->addURL(projectFile());
 
@@ -326,35 +319,35 @@ bool ProjectManager::loadProject(const KURL &url)
 
   Core::getInstance()->doEmitProjectOpened();
 
-  return true;
+  TopLevel::getInstance()->main()->menuBar()->setEnabled( true );
+  kapp->restoreOverrideCursor();
+
+  TopLevel::getInstance()->statusBar()->message( i18n("Project loaded."), 3000 );
+
+  return;
 }
 
-bool ProjectManager::closeProject()
+
+bool ProjectManager::closeProject( bool exiting )
 {
   if( !projectLoaded() )
-    return false;
-
-  Q_ASSERT( API::getInstance()->project() );
+    return true;
 
   // save the session if it is a local file
-  if (m_info->m_projectURL.isLocalFile()) {
-    const QDict<KDevPlugin>& globalParts = PluginController::getInstance()->globalParts();
-    QDict<KDevPlugin> allParts = m_info->m_localParts;
-    QDictIterator<KDevPlugin> it(globalParts);
-    for (; it.current(); ++it) {
-      allParts.insert(it.currentKey(), it.current());
-    }
-    m_pProjectSession->saveToFile(m_info->sessionFile(), allParts);
-  }
-  if ( !PartController::getInstance()->closeAllWindows() )
+	if (m_info->m_projectURL.isLocalFile())
+	{
+		m_pProjectSession->saveToFile(m_info->sessionFile(), PluginController::getInstance()->loadedPlugins() );
+	}
+
+  if ( !PartController::getInstance()->querySaveFiles() )
     return false;
-  
+
   Core::getInstance()->doEmitProjectClosed();
 
   TopLevel::getInstance()->prepareToCloseViews();
 
-  unloadLocalParts();
-  unloadCreateFileSupport();
+//  PluginController::getInstance()->unloadAllLocalParts();
+  PluginController::getInstance()->unloadPlugins( m_info->m_loadParts );
   unloadLanguageSupport();
   unloadProjectPart();
 
@@ -370,8 +363,11 @@ bool ProjectManager::closeProject()
   m_closeProjectAction->setEnabled(false);
   m_projectOptionsAction->setEnabled(false);
   m_activeLanguage->setEnabled(false);
-  
-  PartController::getInstance()->slotCloseAllWindows();
+
+  if ( !exiting )
+  {
+    PartController::getInstance()->slotCloseAllWindows();
+  }
 
   return true;
 }
@@ -379,7 +375,7 @@ bool ProjectManager::closeProject()
 bool ProjectManager::loadProjectFile()
 {
   QString path;
-  if (!KIO::NetAccess::download(m_info->m_projectURL, path)) {
+  if (!KIO::NetAccess::download(m_info->m_projectURL, path, 0)) {
     KMessageBox::sorry(TopLevel::getInstance()->main(),
         i18n("Could not read project file: %1").arg(m_info->m_projectURL.prettyURL()));
     return false;
@@ -445,7 +441,7 @@ bool ProjectManager::saveProjectFile()
     }
     API::getInstance()->projectDom()->save(*(fout.textStream()), 2);
     fout.close();
-    KIO::NetAccess::upload(fout.name(), m_info->m_projectURL);
+    KIO::NetAccess::upload(fout.name(), m_info->m_projectURL, 0);
   }
 
   return true;
@@ -538,8 +534,10 @@ bool ProjectManager::loadLanguageSupport(const QString& lang)
   kdDebug(9000) << "Looking for language support for " << lang << endl;
 
   if (lang == m_info->m_activeLanguage)
-    // language already loaded...
+  {
+    kdDebug(9000) << "Language support already loaded" << endl;
     return true;
+  }
 
   KTrader::OfferList languageSupportOffers =
     KTrader::self()->query(QString::fromLatin1("KDevelop/LanguageSupport"),
@@ -571,6 +569,7 @@ bool ProjectManager::loadLanguageSupport(const QString& lang)
   m_info->m_activeLanguage = lang;
   m_activeLanguage->setCurrentItem(m_activeLanguage->items().findIndex(lang));
 
+  kdDebug(9000) << "Language support for " << lang << " successfully loaded." << endl;
   return true;
 }
 
@@ -578,131 +577,25 @@ void ProjectManager::unloadLanguageSupport()
 {
   KDevLanguageSupport *langSupport = API::getInstance()->languageSupport();
   if( !langSupport ) return;
+  kdDebug(9000) << "Language support for " << langSupport->name() << " unloading..." << endl;
   PluginController::getInstance()->removePart( langSupport );
   delete langSupport;
   API::getInstance()->setLanguageSupport(0);
 }
 
-bool ProjectManager::loadCreateFileSupport() {
-  kdDebug(9000) << "Looing for CreateFile support" << endl;
-  KTrader::OfferList createFileOffers =
-    KTrader::self()->query(QString::fromLatin1("KDevelop/CreateFile"), QString::fromLatin1("[X-KDevelop-Version] == %1").arg(KDEVELOP_PLUGIN_VERSION));
-
-  if (createFileOffers.isEmpty()) {
-    kdDebug(9000) << "No offers found" << endl;
-    API::getInstance()->setCreateFile(0);
-    return false;
-  }
-
-  KService::Ptr createFileService = *createFileOffers.begin();
-  KDevCreateFile *crfileSupport =
-    KParts::ComponentFactory::createInstanceFromService<KDevCreateFile>(createFileService,
-                                                                        API::getInstance(),
-                                                                        0,
-                                                                        PluginController::argumentsFromService(createFileService) );
-  API::getInstance()->setCreateFile(crfileSupport);
-  if (!crfileSupport) {
-    kdDebug(9000) << "Could not load CreateFile plugin" << endl;
-    return false;
-  }
-  PluginController::getInstance()->integratePart( crfileSupport );
-  kdDebug(9000) << "CreateFile support loaded OK" << endl;
-  return true;
-
-
-}
-
-void ProjectManager::unloadCreateFileSupport() {
-  KDevCreateFile *crfileSupport = API::getInstance()->createFile();
-  if (!crfileSupport) return;
-  PluginController::getInstance()->removePart(crfileSupport);
-  delete crfileSupport;
-  API::getInstance()->setCreateFile(0);
-}
-
 void ProjectManager::loadLocalParts()
 {
-  // Make sure to refresh load/ignore lists
-  getGeneralInfo();
+	// Make sure to refresh load/ignore lists
+	getGeneralInfo();
 
-  KTrader::OfferList localOffers = PluginController::pluginServices( "Project" );
-  for (KTrader::OfferList::ConstIterator it = localOffers.begin(); it != localOffers.end(); ++it)
-  {
-    QString name = (*it)->name();
-    kdDebug(9000) << "-----------------------------> load part " << name << endl;
-
-    // Unload it if it is marked as ignored and loaded
-    if (m_info->m_ignoreParts.contains(name)) {
-      KDevPlugin* part = m_info->m_localParts[name];
-      if( part ) {
-        PluginController::getInstance()->removePart( part );
-        m_info->m_localParts.remove( name );
-        part->deleteLater();
-      }
-      continue;
-    }
-
-    // Check if it is already loaded
-    if( m_info->m_localParts[ name ] != 0 )
-      continue;
-
-    if( m_info->m_loadParts.contains( name ) ||
-        checkNewService( *it ) )
-    {
-      KDevPlugin *part = PluginController::loadPlugin( *it );
-      if ( !part ) continue;
-
-      PluginController::getInstance()->integratePart( part );
-      m_info->m_localParts.insert( name, part );
-    }
-// do NOT do processEvents() here, it will delete the unloading plugins before they're ready!
-//    kapp->processEvents();
-  }
-}
-
-void ProjectManager::unloadLocalParts()
-{
-  for( QDictIterator<KDevPlugin> it( m_info->m_localParts ); !it.isEmpty(); )
-  {
-    KDevPlugin* part = it.current();
-    PluginController::getInstance()->removePart( part );
-    m_info->m_localParts.remove( it.currentKey() );
-    delete part;
-  }
-}
-
-bool ProjectManager::checkNewService(const KService::Ptr &service)
-{
-  QVariant var = service->property("X-KDevelop-ProgrammingLanguages");
-  QStringList langlist = var.asStringList();
-
-  // empty means it supports all languages
-  if( !langlist.isEmpty() && !langlist.contains(m_info->m_activeLanguage) ) {
-    m_info->m_ignoreParts << service->name();
-    return false;
-  }
-
-  // the language is ok, now check if the keywords match
-  QStringList serviceKeywords = service->keywords();
-  for ( QStringList::Iterator is = serviceKeywords.begin();
-        is != serviceKeywords.end(); ++is )
-  {
-    if ( !m_info->m_keywords.contains(*is) ) {
-      // no match
-      kdDebug(9000) << "ignoreParts because Keyword doesn't match: " << service->name() << endl;
-      m_info->m_ignoreParts << service->name();
-      return false;
-    }
-  }
-
-  m_info->m_loadParts << service->name();
-  return true;
+	PluginController::getInstance()->unloadPlugins( m_info->m_ignoreParts );
+	PluginController::getInstance()->loadLocalParts( m_info, m_info->m_loadParts, m_info->m_ignoreParts );
 }
 
 KURL ProjectManager::projectFile() const
 {
   if (!m_info)
-    return QString::null;
+    return KURL();
   return m_info->m_projectURL;
 }
 
@@ -718,14 +611,14 @@ ProjectSession* ProjectManager::projectSession() const
 
 bool ProjectManager::loadKDevelop2Project( const KURL & url )
 {
-    if( url.isMalformed() || !url.isLocalFile() ){
+    if( !url.isValid() || !url.isLocalFile() ){
         KMessageBox::sorry(0, i18n("Invalid URL."));
         return false;
     }
 
     QString cmd = KGlobal::dirs()->findExe( "kdevprj2kdevelop" );
     if (cmd.isEmpty()) {
-        KMessageBox::sorry(0, i18n("You don't have 'kdevprj2kdevelop' installed."));
+        KMessageBox::sorry(0, i18n("You do not have 'kdevprj2kdevelop' installed."));
         return false;
     }
 
