@@ -4,6 +4,7 @@
 
 #include <qstring.h>
 #include <qobject.h>
+#include <qdict.h>
 
 
 #include <kxmlguiclient.h>
@@ -15,6 +16,20 @@ class KService;
 class ProjectInfo;
 class ProjectSession;
 class KRecentFilesAction;
+class KDevPlugin;
+
+
+class ProjectInfo
+{
+public:
+  KURL         m_projectURL;
+  QDomDocument m_document;
+  QString      m_projectPlugin, m_language, m_activeLanguage;
+  QStringList  m_ignoreParts, m_loadParts, m_keywords, m_secondaryLanguages;
+
+  QString sessionFile() const;
+};
+
 
 class ProjectManager : public QObject, public KXMLGUIClient
 {
@@ -43,24 +58,24 @@ public:
 public slots:
   bool loadProject( const KURL& url);
   bool loadKDevelop2Project( const KURL& url);
-  bool closeProject();
+  bool closeProject( bool exiting = false );
 
 private slots:
   void slotOpenProject();
   void slotProjectOptions();
+  
+  void slotLoadProject();
 
   void loadLocalParts();
-  void unloadLocalParts();
 
   void updateActiveLangMenu();
   void switchLanguage(const QString& lang);
-
+  
 private:
   ProjectManager();
 
   void setupActions();
   void getGeneralInfo();
-  bool checkNewService(const KService::Ptr &service);
 
   bool loadProjectFile();
   bool saveProjectFile();
@@ -71,9 +86,6 @@ private:
   bool loadLanguageSupport(const QString& lang);
   void unloadLanguageSupport();
 
-  bool loadCreateFileSupport();
-  void unloadCreateFileSupport();
-
   ProjectInfo *m_info;
 
   KAction *m_closeProjectAction, *m_projectOptionsAction;
