@@ -18,6 +18,7 @@
 #include <qdom.h>
 #include <qptrlist.h>
 #include <qfile.h>
+#include <qtimer.h>
 
 #include <kparts/part.h>
 #include <kurl.h>
@@ -66,7 +67,7 @@ void ProjectSession::initXMLTree()
 }
 
 //---------------------------------------------------------------------------
-bool ProjectSession::restoreFromFile(const QString& sessionFileName, const QDict<KDevPlugin>& projectPlugins)
+bool ProjectSession::restoreFromFile( const QString & sessionFileName, const QValueList< KDevPlugin * > plugins )
 {
   bool bFileOpenOK = true;
 
@@ -101,19 +102,22 @@ bool ProjectSession::restoreFromFile(const QString& sessionFileName, const QDict
     recreateDocs(session);
   }
 
-  // now also let the project-related plugins load their session stuff
-  QDomElement pluginListEl = session.namedItem("pluginList").toElement();
-  QDictIterator<KDevPlugin> it(projectPlugins);
-  for ( ; it.current(); ++it) {
-    KDevPlugin* pPlugin = it.current();
-    Q_ASSERT(pPlugin->instance());
-    QString pluginName = pPlugin->instance()->instanceName();
-    QDomElement pluginEl = pluginListEl.namedItem(pluginName).toElement();
-    if (!pluginEl.isNull()) {
-      // now plugin, load what you find!
-      pPlugin->restorePartialProjectSession(&pluginEl);
-    }
-  }
+	// now also let the plugins load their session stuff
+	QDomElement pluginListEl = session.namedItem("pluginList").toElement();
+	QValueList<KDevPlugin*>::ConstIterator it = plugins.begin();
+	while( it != plugins.end() )
+	{
+		KDevPlugin* pPlugin = (*it);
+		QString pluginName = pPlugin->instance()->instanceName();
+		QDomElement pluginEl = pluginListEl.namedItem(pluginName).toElement();
+		if (!pluginEl.isNull()) {
+			// now plugin, load what you find!
+			pPlugin->restorePartialProjectSession(&pluginEl);
+		}
+		++it;
+	}
+  
+	QTimer::singleShot( 0, this, SLOT(loadDocument()) );
 
   return true;
 }
@@ -143,7 +147,8 @@ void ProjectSession::recreateDocs(QDomElement& el)
     if (!docName.isEmpty() /* && URL::exists(docName)*/) {
       KURL url(docName);
       // create the views of this document, the first view creation will also create the document
-      recreateViews(url, docEl);
+      kdDebug() << k_funcinfo << "Doc to be activated? " << (nDoc == nNrOfDocs - 1) << endl;
+	  recreateViews(url, docEl, (nDoc == nNrOfDocs - 1));
     }
   }
 
@@ -156,10 +161,27 @@ void ProjectSession::recreateDocs(QDomElement& el)
 }
 
 //---------------------------------------------------------------------------
-void ProjectSession::recreateViews(KURL& url, QDomElement docEl)
+void ProjectSession::recreateViews(KURL& url, QDomElement docEl, bool activate)
 {
   // read information about the views
   int nNrOfViews = docEl.attribute( "NumberOfViews", "0").toInt();
+  
+  // we should restore every view, but right now we only support a single view per document
+  // so use this simple method for now
+
+	if ( nNrOfViews > 0 )
+	{
+		QDomElement viewEl = docEl.firstChild().toElement();
+		DocumentData dd;
+		dd.type = viewEl.attribute("Type");
+		dd.line = viewEl.attribute("line", "0").toInt();
+		dd.url = url;
+		dd.activate = activate;
+		
+		_docDataList << dd;
+	}  
+  
+/*  
   // loop over all views of this document
   int nView = 0;
 
@@ -186,7 +208,7 @@ void ProjectSession::recreateViews(KURL& url, QDomElement docEl)
       PartController::getInstance()->editDocument(url, line);
     }
     else {
-      PartController::getInstance()->showDocument(url, context);
+      PartController::getInstance()->showDocument(url);
     }
     QDomElement viewPropertiesEl = viewEl.namedItem("AdditionalSettings").toElement();
     if (!viewPropertiesEl.isNull()) {
@@ -201,11 +223,11 @@ void ProjectSession::recreateViews(KURL& url, QDomElement docEl)
 ////    }
 ////    pFocusedView->setFocus();
 ////  }
-
+*/
 }
 
 //---------------------------------------------------------------------------
-bool ProjectSession::saveToFile(const QString& sessionFileName, const QDict<KDevPlugin>& projectPlugins)
+bool ProjectSession::saveToFile( const QString & sessionFileName, const QValueList< KDevPlugin * > plugins )
 {
 
   QString section, keyword;
@@ -241,6 +263,47 @@ bool ProjectSession::saveToFile(const QString& sessionFileName, const QDict<KDev
     }
   }
 
+	QPtrListIterator<KParts::Part> it( *PartController::getInstance()->parts() );
+	for ( ; it.current(); ++it ) 
+	{
+	
+		KParts::ReadOnlyPart* pReadOnlyPart = dynamic_cast<KParts::ReadOnlyPart*>(it.current());
+		if (!pReadOnlyPart)
+			continue; 
+	
+		QString url = pReadOnlyPart->url().url();
+	
+		docIdStr.setNum(nDocs);
+		QDomElement docEl = domdoc.createElement("Doc" + docIdStr);
+		docEl.setAttribute( "URL", url);
+		docsAndViewsEl.appendChild( docEl);
+		nDocs++;
+		docEl.setAttribute( "NumberOfViews", 1);
+		
+		QDomElement viewEl = domdoc.createElement( "View0");
+		docEl.appendChild( viewEl);
+		
+		if ( dynamic_cast<DocumentationPart*>(pReadOnlyPart) )
+		{
+			viewEl.setAttribute("Type", "Documentation");
+		}
+		else if ( pReadOnlyPart->inherits("KTextEditor::Document") )
+		{
+			viewEl.setAttribute("Type", "Source");
+			KTextEditor::ViewCursorInterface *iface = dynamic_cast<KTextEditor::ViewCursorInterface*>(pReadOnlyPart->widget());
+			if (iface) {
+				unsigned int line, col;
+				iface->cursorPosition(&line, &col);
+				viewEl.setAttribute( "line", line );
+			}
+		}
+		else
+		{
+			viewEl.setAttribute("Type", "Other");
+		}
+	}
+  
+/*
   QPtrListIterator<KParts::Part> it( *PartController::getInstance()->parts() );
   for ( ; it.current(); ++it ) {
 ////    QString partName = it.current()->name();
@@ -297,7 +360,7 @@ bool ProjectSession::saveToFile(const QString& sessionFileName, const QDict<KDev
       docEl.setAttribute( "context", pDocuPart->context() );
     }
   }
-
+*/
   docsAndViewsEl.setAttribute("NumberOfDocuments", nDocs);
 
 
@@ -318,19 +381,23 @@ bool ProjectSession::saveToFile(const QString& sessionFileName, const QDict<KDev
     }
   }
 
-  QDictIterator<KDevPlugin> pluginIter(projectPlugins);
-  for ( ; pluginIter.current(); ++pluginIter) {
-    KDevPlugin* pPlugin = pluginIter.current();
-    Q_ASSERT(pPlugin->instance());
-    QString pluginName = pPlugin->instance()->instanceName();
-    QDomElement pluginEl = domdoc.createElement(pluginName);
-    // now plugin, save what you have!
-    pPlugin->savePartialProjectSession(&pluginEl);
-    // if the plugin wrote anything, accept it for the session, otherwise forget it
-    if (pluginEl.hasChildNodes() || pluginEl.hasAttributes()) {
-      pluginListEl.appendChild(pluginEl);
-    }
-  }
+	QValueList<KDevPlugin*>::ConstIterator itt = plugins.begin();
+	while( itt != plugins.end() )
+	{
+		KDevPlugin* pPlugin = (*itt);
+		QString pluginName = pPlugin->instance()->instanceName();
+		QDomElement pluginEl = domdoc.createElement(pluginName);
+		
+		// now plugin, save what you have!
+		pPlugin->savePartialProjectSession(&pluginEl);
+		
+		// if the plugin wrote anything, accept itt for the session, otherwise forget itt
+		if (pluginEl.hasChildNodes() || pluginEl.hasAttributes()) 
+		{
+			pluginListEl.appendChild(pluginEl);
+		}
+		++itt;
+	}
 
   // Write it out to the session file on disc
   QFile f(sessionFileName);
@@ -343,3 +410,31 @@ bool ProjectSession::saveToFile(const QString& sessionFileName, const QDict<KDev
 
   return true;
 }
+
+
+void ProjectSession::loadDocument( )
+{
+	if ( !_docDataList.isEmpty() )
+	{
+		DocumentData & dd = _docDataList.first();
+		if ( dd.type == "Source" )
+		{
+			PartController::getInstance()->editDocumentInternal( dd.url, dd.line, -1, dd.activate );
+		}
+		else if ( dd.type == "Documentation" )
+		{
+			// FIXME needs to be deferred if !activate ?
+			PartController::getInstance()->showDocument( dd.url, true );
+		}
+		else
+		{
+			// FIXME needs to be deferred if !activate ?
+			PartController::getInstance()->editDocument( dd.url );
+		}		
+		_docDataList.pop_front();
+		
+		loadDocument();
+		//QTimer::singleShot( 0, this, SLOT(loadDocument()) );
+	}
+}
+
