@@ -5,12 +5,10 @@
 #include "toplevel.h"
 #include "core.h"
 
-
-#include "mainwindow.h"
-
+#include "newmainwindow.h"
 
 KDevMainWindow *TopLevel::s_instance = 0;
-
+TopLevel::Mode TopLevel::mode = TopLevel::IDEMode;
 
 bool TopLevel::mainWindowValid()
 {
@@ -21,7 +19,13 @@ KDevMainWindow *TopLevel::getInstance()
 {
   if (!s_instance)
   {
-    MainWindow *mainWindow = new MainWindow;
+
+	KConfig *config = kapp->config();
+	config->setGroup("UI");
+	int mdimode = config->readNumEntry("MDIMode", KMdi::IDEAlMode);
+    
+	NewMainWindow *mainWindow = new NewMainWindow( 0, "MainWindow", (KMdi::MdiMode)mdimode );
+
     s_instance = mainWindow;
 
     mainWindow->init();
