@@ -18,6 +18,8 @@ public:
   static bool mainWindowValid();
   static void invalidateInstance(KDevMainWindow *instance);             //!< Signal that the object has been (or is about to be) destroyed
 
+  enum Mode { IDEMode, AssistantMode };
+  static Mode mode;
 
 private:
 
