@@ -126,9 +126,7 @@ CvsPart::CvsPart( QObject *parent, const char *name, const QStringList & )
     actionAddToIgnoreList( 0 ), actionRemoveFromIgnoreList( 0 )
 {
     setInstance( CvsFactory::instance() );
-
-    setXMLFile( "kdevcvspart.rc" );
-
+    
     init();
 }
 
@@ -161,6 +159,7 @@ void CvsPart::init()
 
     m_widget = new CvsWidget( this );
     m_widget->setIcon( SmallIcon("db") );
+    m_widget->setCaption(i18n("CVS Output"));
     mainWindow()->embedOutputView( m_widget, i18n("CVS"), i18n("CVS output") ); // i18n("CVS") ?!?? ;)
     QWhatsThis::add(m_widget, i18n("<b>CVS</b><p>Concurrent Versions System operations window. Shows results of cvs command execution."));
 }
@@ -212,8 +211,8 @@ void CvsPart::setupActions()
     actionAddToIgnoreList->setWhatsThis(i18n("<b>Ignore this file when doing CVS operation</b><p>Puts the name of this file onto a .cvsignore list."));
     actionRemoveFromIgnoreList = new KAction( i18n("Do Not Ignore This File When Doing CVS Operation"), 0,
         this, SLOT(slotActionRemoveFromIgnoreList()), actionCollection(), "cvs_donot_ignore" );
-    actionRemoveFromIgnoreList->setToolTip(i18n("Do not ignore this file when soing CVS operation"));
-    actionRemoveFromIgnoreList->setWhatsThis(i18n("<b>Do not ignore this file when soing CVS operation</b><p>Removes the name of this file from a .cvsignore list."));
+    actionRemoveFromIgnoreList->setToolTip(i18n("Do not ignore this file when doing CVS operation"));
+    actionRemoveFromIgnoreList->setWhatsThis(i18n("<b>Do not ignore this file when doing CVS operation</b><p>Removes the name of this file from a .cvsignore list."));
 }
 
 ///////////////////////////////////////////////////////////////////////////////
@@ -263,7 +262,7 @@ bool CvsPart::prepareOperation( CvsOperation op )
     if (urls.count() <= 0) // who knows? ;)
     {
         kdDebug(9000) << "CvsPart::prepareOperation(): No valid document URL selected!!!" << endl;
-        KMessageBox::sorry( 0, i18n("None of the file(s) you selected seems to be valid for repository.") );
+        KMessageBox::sorry( 0, i18n("None of the file(s) you selected seem to be valid for repository.") );
         return false;
     }
     URLUtil::dump( urls );
@@ -331,6 +330,12 @@ void CvsPart::createNewProject( const QString& dirName )
 
 void CvsPart::contextMenu( QPopupMenu *popup, const Context *context )
 {
+
+// If the current project doesn't support CVS, we don't
+// want to confuse the user with a CVS popup menu.
+if(!project() || !isValidDirectory(project()->projectDirectory()))
+  return;
+
     if (context->hasType( Context::FileContext ))
     {
         kdDebug(9000) << "CvsPart::contextMenu()" << endl;
@@ -1019,7 +1024,7 @@ void CvsPart::slotRemovedFilesFromProject(const QStringList &fileToRemove)
     kdDebug( 9000 ) << "====> CvsPart::slotRemovedFilesFromProject( const QStringList &)" << endl;
 
     int s = KMessageBox::questionYesNo( 0,
-        i18n("Do you want them to be removed from CVS repository too?\nWarning: They will be removed from disk too!"),
+        i18n("Do you want them to be removed from CVS repository too?\nWarning: They will be removed from disk too."),
         i18n("CVS - Files Removed From Project"),
         KStdGuiItem::yes(),
         KStdGuiItem::no(),
@@ -1041,7 +1046,7 @@ void CvsPart::slotProjectOpened()
     kdDebug(9000) << "CvsPart::slotProjectOpened() here!" << endl;
 
     // Avoid bothering the user if this project has no support for CVS
-    if (!isValidDirectory( project()->projectDirectory() ))
+    if (!project() || !isValidDirectory( project()->projectDirectory() ))
     {
         kdDebug(9006) << "Project has no CVS Support: too bad!! :-(" << endl;
         return;
@@ -1071,7 +1076,7 @@ void CvsPart::slotProjectClosed()
     kdDebug(9000) << "CvsPart::slotProjectClosed() here!" << endl;
 
     // Avoid bothering the user if this project has no support for CVS
-    if (!isValidDirectory( project()->projectDirectory() ))
+    if (!project() || !isValidDirectory( project()->projectDirectory() ))
     {
         kdDebug(9006) << "Project has no CVS Support: too bad!! :-(" << endl;
         return;
@@ -1086,10 +1091,11 @@ void CvsPart::slotProjectClosed()
 
 bool CvsPart::isValidDirectory( const QString &dirPath ) const
 {
-    QDir cvsdir( dirPath );
-    QString entriesFileName = dirPath + QDir::separator() + "Entries";
-    QString rootFileName = dirPath + QDir::separator()  + "Entries";
-    QString repoFileName = dirPath + QDir::separator()  + "Repository";
+    QString cvs = "/CVS/";
+    QDir cvsdir( dirPath + cvs );
+    QString entriesFileName = dirPath + cvs + "Entries";
+    QString rootFileName = dirPath + cvs + "Root";
+    QString repoFileName = dirPath + cvs + "Repository";
 
     return cvsdir.exists() &&
         QFile::exists( entriesFileName ) &&
