@@ -79,8 +79,8 @@ K_EXPORT_COMPONENT_FACTORY( libkdevcvsservice, CvsFactory( &data ) )
 ///////////////////////////////////////////////////////////////////////////////
 
 CvsServicePart::CvsServicePart( QObject *parent, const char *name, const QStringList & )
-    : KDevVersionControl( "KDevCvsServicePart", "kdevcvsservicepart", parent,
-        name ? name : "CvsService" ),
+	: KDevVersionControl( "KDevCvsServicePart", "cervisia", parent,
+						  name ? name : "CvsService" ),
     actionCommit( 0 ), actionDiff( 0 ), actionLog( 0 ), actionAdd( 0 ),
     actionAddBinary( 0 ), actionRemove( 0 ), actionUpdate( 0 ),
     actionRemoveSticky( 0 ),
@@ -91,8 +91,6 @@ CvsServicePart::CvsServicePart( QObject *parent, const char *name, const QString
 {
     setInstance( CvsFactory::instance() );
 
-    setXMLFile( "kdevcvsservicepart.rc" );
-
     init();
 
     /// \FIXME (at all costs!), Ok, this is a crime but for now CvsServicePart is the only implementation
@@ -114,9 +112,8 @@ void CvsServicePart::init()
 {
     setupActions();
 
-    // Here we change the implementation
-    /// \FIXME factory pattern here? :-/
     m_impl = new CvsServicePartImpl( this );
+    // Re-route our implementation signal for when check-out finishes to the standard signal
     connect( m_impl, SIGNAL(checkoutFinished(QString)), SIGNAL(finishedFetching(QString)) );
 
     // Load / store project configuration every time project is opened/closed
@@ -133,6 +130,7 @@ void CvsServicePart::init()
 
     m_impl->m_widget->setIcon( UserIcon( "kdev_cvs", KIcon::DefaultState, CvsFactory::instance()) );
     QWhatsThis::add( m_impl->processWidget(), i18n("<b>CVS</b><p>Concurrent Versions System operations window. Shows output of Cervisia CVS Service.") );
+    m_impl->processWidget()->setCaption(i18n("CvsService Output"));
     mainWindow()->embedOutputView( m_impl->processWidget(), i18n("CvsService"), i18n("cvs output") );
 }
 
@@ -218,8 +216,7 @@ void CvsServicePart::setupActions()
 
 bool CvsServicePart::fetchFromRepository()
 {
-    m_impl->checkout();
-    return true;
+    return m_impl->checkout();
 }
 
 ///////////////////////////////////////////////////////////////////////////////
@@ -257,7 +254,7 @@ void CvsServicePart::createNewProject( const QString &dirName )
 
 void CvsServicePart::projectConfigWidget( KDialogBase *dlg )
 {
-    QVBox *vbox = dlg->addVBoxPage( i18n("CvsService") );
+	QVBox *vbox = dlg->addVBoxPage( i18n("CvsService"), i18n("CvsService"), BarIcon( icon(), KIcon::SizeMedium) );
     CvsOptionsWidget *w = new CvsOptionsWidget( (QWidget *)vbox, "cvs config widget" );
     connect( dlg, SIGNAL(okClicked()), w, SLOT(accept()) );
 }
@@ -274,6 +271,11 @@ QWidget* CvsServicePart::newProjectWidget( QWidget *parent )
 
 void CvsServicePart::contextMenu( QPopupMenu *popup, const Context *context )
 {
+  // If the current project doesn't support CVS, we don't
+  // want to confuse the user with a CVS popup menu.
+  if(!project() || !isValidDirectory(project()->projectDirectory()))
+    return;
+
     kdDebug(9006) << "contextMenu()" << endl;
     if (context->hasType( Context::FileContext ) ||
         context->hasType( Context::EditorContext ))
@@ -289,7 +291,8 @@ void CvsServicePart::contextMenu( QPopupMenu *popup, const Context *context )
         {
             kdDebug(9006) << "Requested for an EditorContext" << endl;
             const EditorContext *editorContext = static_cast<const EditorContext*>( context );
-            m_urls << editorContext->url();
+//            m_urls << editorContext->url(); // this can't be right?
+            m_urls = editorContext->url();
         }
         // THis stuff should end up into prepareOperation()
         URLUtil::dump( m_urls );
@@ -297,7 +300,8 @@ void CvsServicePart::contextMenu( QPopupMenu *popup, const Context *context )
                 return;
 
         KPopupMenu *subMenu = new KPopupMenu( popup );
-        popup->insertSeparator();
+        if (context->hasType( Context::FileContext ))
+            popup->insertSeparator();
 
         int id = subMenu->insertItem( actionCommit->text(), this, SLOT(slotCommit()) );
         subMenu->setWhatsThis(id, i18n("<b>Commit file(s)</b><p>Commits file to repository if modified."));
