@@ -16,6 +16,7 @@
 #include <kapplication.h>
 #include <kmessagebox.h>
 #include <kdebug.h>
+#include <kdeversion.h>
 #include <klocale.h>
 #include <kprocess.h>
 #include <kstandarddirs.h>
@@ -131,7 +132,7 @@ bool CvsServicePartImpl::prepareOperation( const KURL::List &someUrls, CvsOperat
         if (KMessageBox::warningYesNo( 0,
             i18n("Another CVS operation is executing: do you want to cancel it \n"
                 "and start this new one?"),
-            i18n("CVS: Operation already pending ")) == KMessageBox::Yes)
+            i18n("CVS: Operation Already Pending ")) == KMessageBox::Yes)
         {
             m_widget->cancelJob();
         }
@@ -146,7 +147,7 @@ bool CvsServicePartImpl::prepareOperation( const KURL::List &someUrls, CvsOperat
     if (urls.count() <= 0) // who knows? ;)
     {
         kdDebug(9006) << "CvsServicePartImpl::prepareOperation(): No valid document URL selected!!!" << endl;
-        KMessageBox::sorry( 0, i18n("None of the file(s) you selected seems to be valid for repository.") );
+        KMessageBox::sorry( 0, i18n("None of the file(s) you selected seem to be valid for repository.") );
         return false;
     }
 
@@ -353,7 +354,7 @@ void CvsServicePartImpl::logout()
 
 ///////////////////////////////////////////////////////////////////////////////
 
-void CvsServicePartImpl::checkout()
+bool CvsServicePartImpl::checkout()
 {
     kdDebug() << "CvsServicePartImpl::checkout()" << endl;
 
@@ -361,21 +362,28 @@ void CvsServicePartImpl::checkout()
 
     if ( dlg.exec() == QDialog::Accepted )
     {
-        DCOPRef job = m_cvsService->checkout( dlg.workDir(), dlg.serverPath(),
+#if KDE_IS_VERSION(3,2,90)
+        DCOPRef job = m_cvsService->checkout( dlg.workDir(), dlg.serverPath(),	
+            dlg.module(), dlg.tag(), dlg.pruneDirs(), "", false
+        );
+#else    
+        DCOPRef job = m_cvsService->checkout( dlg.workDir(), dlg.serverPath(),	
             dlg.module(), dlg.tag(), dlg.pruneDirs()
         );
-        if (!m_cvsService->ok())
-        {
+#endif	
+        if (!m_cvsService->ok()) {
             KMessageBox::sorry( mainWindow()->main(), i18n( "Unable to checkout" ) );
-            return;
-        }
-        // Save the path for later retrieval since slotCheckoutFinished(bool,int)
-        // will use it for return the info to the caller.
-        modulePath = dlg.workDir() + QDir::separator() + dlg.module();
+        } else {
+        	// Save the path for later retrieval since slotCheckoutFinished(bool,int)
+        	// will use it for return the info to the caller.
+			modulePath = dlg.workDir() + dlg.module();
 
-        m_scheduler->schedule( job );
-        connect( processWidget(), SIGNAL(jobFinished(bool,int)), this, SLOT(slotCheckoutFinished(bool,int)) );
+        	m_scheduler->schedule( job );
+        	connect( processWidget(), SIGNAL(jobFinished(bool,int)), this, SLOT(slotCheckoutFinished(bool,int)) );
+			return true;
+		}
     }
+	return false;
 }
 
 ///////////////////////////////////////////////////////////////////////////////
@@ -392,10 +400,10 @@ void CvsServicePartImpl::commit( const KURL::List& urlList )
     if (dlg.exec() == QDialog::Rejected)
         return;
 
-//    CvsOptions *options = CvsOptions::instance();
+    CvsOptions *options = CvsOptions::instance();
     QString logString = dlg.logMessage().join( "\n" );
 
-    DCOPRef cvsJob = m_cvsService->commit( fileList(), logString, false );
+    DCOPRef cvsJob = m_cvsService->commit( fileList(), logString, options->recursiveWhenCommitRemove() );
     if (!m_cvsService->ok())
     {
         kdDebug( 9006 ) << "Commit of " << fileList().join( ", " ) << " failed!!!" << endl;
@@ -544,7 +552,7 @@ void CvsServicePartImpl::diff( const KURL::List& urlList )
                 dlg.revB(), options->diffOptions(), options->contextLines() );
     if (!m_cvsService->ok())
     {
-        KMessageBox::sorry( 0, i18n("Sorry, cannot diff!"),
+        KMessageBox::sorry( 0, i18n("Sorry, cannot diff."),
             i18n("Error During Diff") );
         return;
     }
@@ -634,8 +642,15 @@ void CvsServicePartImpl::createNewProject( const QString &dirName,
     CvsOptions *options = CvsOptions::instance();
     options->setCvsRshEnvVar( cvsRsh );
     options->setLocation( location );
+/*
+	//virtual DCOPRef import( const QString& workingDir, const QString& repository, const QString& module, const QString& ignoreList, const QString& comment, const
+    QString filesToIgnore;
+	DCOPRef cvsJob = m_cvsService->import( dirName, location, module, filesToIgnore, message, vendor, release, false );
 
-    QString rsh_preamble;
+    m_scheduler->schedule( cvsJob );
+    connect( processWidget(), SIGNAL(jobFinished(bool,int)), this, SLOT(slotCheckoutFinished(bool,int)) );
+*/
+	QString rsh_preamble;
     if ( !options->cvsRshEnvVar().isEmpty() )
         rsh_preamble = "CVS_RSH=" + KShellProcess::quote( options->cvsRshEnvVar() );
 
@@ -745,7 +760,7 @@ void CvsServicePartImpl::removedFilesFromProject(const QStringList &filesToRemov
         return;
 
     int s = KMessageBox::questionYesNo( 0,
-        i18n("Do you want them to be removed from CVS repository too?\nWarning: They will be removed from disk too!"),
+        i18n("Do you want them to be removed from CVS repository too?\nWarning: They will be removed from disk too."),
         i18n("CVS - Files Removed From Project"),
         KStdGuiItem::yes(),
         KStdGuiItem::no(),
@@ -851,7 +866,7 @@ void CvsServicePartImpl::slotCheckoutFinished( bool exitStatus, int )
     kdDebug() << "CvsServicePartImpl::slotCheckoutFinished(): job ended with status == "
         << exitStatus << endl;
     // Return a null string if the operation was not succesfull
-    if (exitStatus)
+    if (!exitStatus)
         modulePath = QString::null;
 
     kdDebug() << "   I'll emit modulePath == " << modulePath << endl;
@@ -861,7 +876,7 @@ void CvsServicePartImpl::slotCheckoutFinished( bool exitStatus, int )
 
 ///////////////////////////////////////////////////////////////////////////////
 
-void CvsServicePartImpl::slotJobFinished( bool exitStatus, int exitCode )
+void CvsServicePartImpl::slotJobFinished( bool /*exitStatus*/, int exitCode )
 {
     // Return a null string if the operation was not succesfull
     kdDebug() << "CvsServicePartImpl::slotJobFinished(): job ended with code == "
