@@ -28,6 +28,7 @@
 #include "kdevmainwindow.h"
 #include "subversion_core.h"
 #include "subversion_part.h"
+#include "subversion_widget.h"
 #include "subversionoptionswidgetimpl.h"
 #include "subversionprojectwidget.h"
 #include "urlutil.h"
@@ -52,7 +53,6 @@ K_EXPORT_COMPONENT_FACTORY( libkdevsubversion, subversionFactory( &data ) )
 subversionPart::subversionPart(QObject *parent, const char *name, const QStringList& )
 	: KDevVersionControl("KDevsubversionPart", "kdevsubversionpart", parent, name ? name : "Subversion" ) {
 	setInstance(subversionFactory::instance());
-	setXMLFile("kdevpart_subversion.rc");
 	m_projWidget = 0;
 
 	m_impl = new subversionCore( this );
@@ -87,6 +87,7 @@ subversionPart::subversionPart(QObject *parent, const char *name, const QStringL
 	connect( core(), SIGNAL(projectOpened()), this, SLOT(slotProjectOpened()) );
 	connect( core(), SIGNAL(projectClosed()), this, SLOT(slotProjectClosed()) );
 
+	m_impl->processWidget()->setCaption(i18n( "Subversion Output" ));
 	mainWindow()->embedOutputView( (QWidget*)m_impl->processWidget(), i18n( "Subversion" ), i18n( "Subversion messages" ) );
     QWhatsThis::add((QWidget*)m_impl->processWidget(), i18n("<b>Subversion</b><p>Subversion operations window."));
 	setVersionControl( this );
@@ -152,7 +153,7 @@ void subversionPart::projectConfigWidget( KDialogBase *dlg ) {
 void subversionPart::createNewProject( const QString& dirname ) {
 	if ( !m_projWidget ) return;
 
-	m_impl->createNewProject( dirname, m_projWidget->importURL->url(), m_projWidget->yes->isChecked() );
+	m_impl->createNewProject( dirname, KURL( m_projWidget->importURL->url() ), m_projWidget->yes->isChecked() );
 
 }
 
@@ -166,10 +167,20 @@ KDevVCSFileInfoProvider * subversionPart::fileInfoProvider() const {
 }
 
 bool subversionPart::isValidDirectory( const QString& dirPath) {
-	return true;
+    QString svn = "/.svn/";
+    QDir svndir( dirPath + svn );
+    QString entriesFileName = dirPath + svn + "entries";
+
+    return svndir.exists() &&
+        QFile::exists( entriesFileName );
 }
 
 void subversionPart::contextMenu( QPopupMenu *popup, const Context *context ) {
+// If the current project doesn't support SVN, we don't
+// want to confuse the user with a SVN popup menu.
+if(!project() || !isValidDirectory(project()->projectDirectory()))
+  return;
+  
 	kdDebug() << "contextMenu()" << endl;
 	if (context->hasType( Context::FileContext ) ||
 			context->hasType( Context::EditorContext ))
@@ -193,7 +204,8 @@ void subversionPart::contextMenu( QPopupMenu *popup, const Context *context ) {
 			return;
 
 		KPopupMenu *subMenu = new KPopupMenu( popup );
-		popup->insertSeparator();
+                if (context->hasType( Context::FileContext ))
+		    popup->insertSeparator();
 
 		int id = subMenu->insertItem( actionCommit->text(), this, SLOT(slotCommit()) );
 		// CvsService let to do log and diff operations only on one file (or directory) at time
